/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

/* using ShadowStackFrameworkGCTransformer */
#define MALLOC_ZERO_FILLED 0
#define PYPY_SIGINT_INTERRUPT_EVENT 1

#define _CFFI_INTERNAL
#define _DEFAULT_SOURCE 1
#include <src/thread.h>
#include <sys/mman.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <src/signals.h>
#include <signal.h>
#include <sys/time.h>
#include <Python.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <utime.h>
#include <sys/times.h>
#include <sys/resource.h>
#include <sched.h>
#include <grp.h>
#include <dirent.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/utsname.h>
#include <pty.h>
#include <sys/sysmacros.h>
#include <dlfcn.h>
#include <time.h>
#include <sys/select.h>
#include <sys/timeb.h>
#include <src/dtoa.h>
#include <locale.h>
#include <limits.h>
#include <ctype.h>
#include <wchar.h>
#include <langinfo.h>
#include <libintl.h>
#include <sys/statvfs.h>
#include <ffi.h>
#include <stdarg.h>
#include <structmember.h>
#include <marshal.h>
#include <string.h>
#include <assert.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <poll.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <net/if.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>
#include <expat.h>
#include <parse_c_type.h>
#include <pwd.h>
#include <bzlib.h>
#include <src/cjkcodecs/multibytecodec.h>
#include <rjitlog.h>
#include <sys/prctl.h>
#include <sys/epoll.h>
#include <stddef.h>
#include <semaphore.h>
#include <zlib.h>
#include <termios.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/operator/tscmp.h>
#include <sys/file.h>
#include <sys/syscall.h>
#include <linux/random.h>
#define RPY_WITH_GIL
RPY_EXTERN int get_errno (void);
RPY_EXTERN void set_errno (int v);
#define PYPY_NO_OP()
RPY_EXPORTED char *_pypy_init_home(void);
RPY_EXPORTED void _pypy_init_free(char*);
RPY_EXTERN void * get__pypy_rawrefcount_w_marker_deallocating (void);
RPY_EXTERN void set__pypy_rawrefcount_w_marker_deallocating (void * v);
RPY_EXTERN int get_Py_DebugFlag (void);
RPY_EXTERN void set_Py_DebugFlag (int v);
RPY_EXTERN int get_Py_Py3kWarningFlag (void);
RPY_EXTERN void set_Py_Py3kWarningFlag (int v);
RPY_EXTERN int get_Py_DivisionWarningFlag (void);
RPY_EXTERN void set_Py_DivisionWarningFlag (int v);
RPY_EXTERN int get__Py_QnewFlag (void);
RPY_EXTERN void set__Py_QnewFlag (int v);
RPY_EXTERN int get_Py_InspectFlag (void);
RPY_EXTERN void set_Py_InspectFlag (int v);
RPY_EXTERN int get_Py_InteractiveFlag (void);
RPY_EXTERN void set_Py_InteractiveFlag (int v);
RPY_EXTERN int get_Py_OptimizeFlag (void);
RPY_EXTERN void set_Py_OptimizeFlag (int v);
RPY_EXTERN int get_Py_DontWriteBytecodeFlag (void);
RPY_EXTERN void set_Py_DontWriteBytecodeFlag (int v);
RPY_EXTERN int get_Py_NoUserSiteDirectory (void);
RPY_EXTERN void set_Py_NoUserSiteDirectory (int v);
RPY_EXTERN int get_Py_NoSiteFlag (void);
RPY_EXTERN void set_Py_NoSiteFlag (int v);
RPY_EXTERN int get_Py_IgnoreEnvironmentFlag (void);
RPY_EXTERN void set_Py_IgnoreEnvironmentFlag (int v);
RPY_EXTERN int get_Py_TabcheckFlag (void);
RPY_EXTERN void set_Py_TabcheckFlag (int v);
RPY_EXTERN int get_Py_VerboseFlag (void);
RPY_EXTERN void set_Py_VerboseFlag (int v);
RPY_EXTERN int get_Py_UnicodeFlag (void);
RPY_EXTERN void set_Py_UnicodeFlag (int v);
RPY_EXTERN int get_Py_BytesWarningFlag (void);
RPY_EXTERN void set_Py_BytesWarningFlag (int v);
RPY_EXTERN int get_Py_HashRandomizationFlag (void);
RPY_EXTERN void set_Py_HashRandomizationFlag (int v);
RPY_EXTERN PyObject *pypy_static_pyobjs[];
#define PyArray_Type PyPyArray_Type
RPY_EXPORTED PyTypeObject PyArray_Type;
#define PyBaseObject_Type PyPyBaseObject_Type
RPY_EXPORTED PyTypeObject PyBaseObject_Type;
#define PyBaseString_Type PyPyBaseString_Type
RPY_EXPORTED PyTypeObject PyBaseString_Type;
#define PyBool_Type PyPyBool_Type
RPY_EXPORTED PyTypeObject PyBool_Type;
#define PyBufferable_Type PyPyBufferable_Type
RPY_EXPORTED PyTypeObject PyBufferable_Type;
#define PyByteArray_Type PyPyByteArray_Type
RPY_EXPORTED PyTypeObject PyByteArray_Type;
#define PyCFunction_Type PyPyCFunction_Type
RPY_EXPORTED PyTypeObject PyCFunction_Type;
#define PyCell_Type PyPyCell_Type
RPY_EXPORTED PyTypeObject PyCell_Type;
#define PyClassMethodDescr_Type PyPyClassMethodDescr_Type
RPY_EXPORTED PyTypeObject PyClassMethodDescr_Type;
#define PyClass_Type PyPyClass_Type
RPY_EXPORTED PyTypeObject PyClass_Type;
#define PyComplex_Type PyPyComplex_Type
RPY_EXPORTED PyTypeObject PyComplex_Type;
#define PyDictProxy_Type PyPyDictProxy_Type
RPY_EXPORTED PyTypeObject PyDictProxy_Type;
#define PyDict_Type PyPyDict_Type
RPY_EXPORTED PyTypeObject PyDict_Type;
RPY_EXPORTED PyTypeObject _PyExc_ArithmeticError;
RPY_EXPORTED PyTypeObject _PyExc_AssertionError;
RPY_EXPORTED PyTypeObject _PyExc_AttributeError;
RPY_EXPORTED PyTypeObject _PyExc_BaseException;
RPY_EXPORTED PyTypeObject _PyExc_BufferError;
RPY_EXPORTED PyTypeObject _PyExc_BytesWarning;
RPY_EXPORTED PyTypeObject _PyExc_DeprecationWarning;
RPY_EXPORTED PyTypeObject _PyExc_EOFError;
RPY_EXPORTED PyTypeObject _PyExc_EnvironmentError;
RPY_EXPORTED PyTypeObject _PyExc_Exception;
RPY_EXPORTED PyTypeObject _PyExc_FloatingPointError;
RPY_EXPORTED PyTypeObject _PyExc_FutureWarning;
RPY_EXPORTED PyTypeObject _PyExc_GeneratorExit;
RPY_EXPORTED PyTypeObject _PyExc_IOError;
RPY_EXPORTED PyTypeObject _PyExc_ImportError;
RPY_EXPORTED PyTypeObject _PyExc_ImportWarning;
RPY_EXPORTED PyTypeObject _PyExc_IndentationError;
RPY_EXPORTED PyTypeObject _PyExc_IndexError;
RPY_EXPORTED PyTypeObject _PyExc_KeyError;
RPY_EXPORTED PyTypeObject _PyExc_KeyboardInterrupt;
RPY_EXPORTED PyTypeObject _PyExc_LookupError;
RPY_EXPORTED PyTypeObject _PyExc_MemoryError;
RPY_EXPORTED PyTypeObject _PyExc_NameError;
RPY_EXPORTED PyTypeObject _PyExc_NotImplementedError;
RPY_EXPORTED PyTypeObject _PyExc_OSError;
RPY_EXPORTED PyTypeObject _PyExc_OverflowError;
RPY_EXPORTED PyTypeObject _PyExc_PendingDeprecationWarning;
RPY_EXPORTED PyTypeObject _PyExc_ReferenceError;
RPY_EXPORTED PyTypeObject _PyExc_RuntimeError;
RPY_EXPORTED PyTypeObject _PyExc_RuntimeWarning;
RPY_EXPORTED PyTypeObject _PyExc_StandardError;
RPY_EXPORTED PyTypeObject _PyExc_StopIteration;
RPY_EXPORTED PyTypeObject _PyExc_SyntaxError;
RPY_EXPORTED PyTypeObject _PyExc_SyntaxWarning;
RPY_EXPORTED PyTypeObject _PyExc_SystemError;
RPY_EXPORTED PyTypeObject _PyExc_SystemExit;
RPY_EXPORTED PyTypeObject _PyExc_TabError;
RPY_EXPORTED PyTypeObject _PyExc_TypeError;
RPY_EXPORTED PyTypeObject _PyExc_UnboundLocalError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeDecodeError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeEncodeError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeTranslateError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeWarning;
RPY_EXPORTED PyTypeObject _PyExc_UserWarning;
RPY_EXPORTED PyTypeObject _PyExc_ValueError;
RPY_EXPORTED PyTypeObject _PyExc_Warning;
RPY_EXPORTED PyTypeObject _PyExc_ZeroDivisionError;
#define PyFloat_Type PyPyFloat_Type
RPY_EXPORTED PyTypeObject PyFloat_Type;
#define PyFrozenSet_Type PyPyFrozenSet_Type
RPY_EXPORTED PyTypeObject PyFrozenSet_Type;
#define PyGetSetDescr_Type PyPyGetSetDescr_Type
RPY_EXPORTED PyTypeObject PyGetSetDescr_Type;
#define PyInt_Type PyPyInt_Type
RPY_EXPORTED PyTypeObject PyInt_Type;
#define PyList_Type PyPyList_Type
RPY_EXPORTED PyTypeObject PyList_Type;
#define PyLong_Type PyPyLong_Type
RPY_EXPORTED PyTypeObject PyLong_Type;
#define PyMemberDescr_Type PyPyMemberDescr_Type
RPY_EXPORTED PyTypeObject PyMemberDescr_Type;
#define PyMemoryView_Type PyPyMemoryView_Type
RPY_EXPORTED PyTypeObject PyMemoryView_Type;
#define PyMethodDescr_Type PyPyMethodDescr_Type
RPY_EXPORTED PyTypeObject PyMethodDescr_Type;
#define PyModule_Type PyPyModule_Type
RPY_EXPORTED PyTypeObject PyModule_Type;
#define PyNone_Type PyPyNone_Type
RPY_EXPORTED PyTypeObject PyNone_Type;
#define PyNotImplemented_Type PyPyNotImplemented_Type
RPY_EXPORTED PyTypeObject PyNotImplemented_Type;
#define PyProperty_Type PyPyProperty_Type
RPY_EXPORTED PyTypeObject PyProperty_Type;
#define PySet_Type PyPySet_Type
RPY_EXPORTED PyTypeObject PySet_Type;
#define PySlice_Type PyPySlice_Type
RPY_EXPORTED PyTypeObject PySlice_Type;
#define PyStaticMethod_Type PyPyStaticMethod_Type
RPY_EXPORTED PyTypeObject PyStaticMethod_Type;
#define PyString_Type PyPyString_Type
RPY_EXPORTED PyTypeObject PyString_Type;
#define PyTuple_Type PyPyTuple_Type
RPY_EXPORTED PyTypeObject PyTuple_Type;
#define PyType_Type PyPyType_Type
RPY_EXPORTED PyTypeObject PyType_Type;
#define PyUnicode_Type PyPyUnicode_Type
RPY_EXPORTED PyTypeObject PyUnicode_Type;
#define PyWrapperDescr_Type PyPyWrapperDescr_Type
RPY_EXPORTED PyTypeObject PyWrapperDescr_Type;
#define _Py_EllipsisObject _PyPy_EllipsisObject
RPY_EXPORTED PyObject _Py_EllipsisObject;
#define _Py_NoneStruct _PyPy_NoneStruct
RPY_EXPORTED PyObject _Py_NoneStruct;
#define _Py_NotImplementedStruct _PyPy_NotImplementedStruct
RPY_EXPORTED PyObject _Py_NotImplementedStruct;
#define _Py_TrueStruct _PyPy_TrueStruct
RPY_EXPORTED PyIntObject _Py_TrueStruct;
#define _Py_ZeroStruct _PyPy_ZeroStruct
RPY_EXPORTED PyIntObject _Py_ZeroStruct;

RPY_EXTERN PyObject ** get_pypy_static_pyobjs (void);

static float pypy__uint2singlefloat(unsigned int x) {
    float ff;
    assert(sizeof(float) == 4 && sizeof(unsigned int) == 4);
    memcpy(&ff, &x, 4);
    return ff;
}
static unsigned int pypy__singlefloat2uint(float x) {
    unsigned int ii;
    assert(sizeof(float) == 4 && sizeof(unsigned int) == 4);
    memcpy(&ii, &x, 4);
    return ii;
}

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <poll.h>
#include <sys/select.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <errno.h>
#include <limits.h>
#include <net/if.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>

#ifdef AF_NETLINK
#include <linux/netlink.h>
#endif


#define pypy__is_nonnull_longdouble(x)  ((x) != 0.0)

RPY_EXTERN char ** get_environ (void);
RPY_EXTERN void set_environ (char ** v);
#define RPYTHON_JITLOG


/* If we have an old Linux kernel (or compile with old system headers),
   the following two macros are not defined.  But we would still like
   a pypy translated on such a system to run on a more modern system. */
#ifndef PR_SET_PTRACER
#  define PR_SET_PTRACER 0x59616d61
#endif
#ifndef PR_SET_PTRACER_ANY
#  define PR_SET_PTRACER_ANY ((unsigned long)-1)
#endif
static void pypy__allow_attach(void) {
    prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY);
}

RPY_EXTERN
int pypy_epoll_ctl(int, int, int, uint32_t);RPY_EXTERN
int pypy_epoll_wait(int, uint32_t*, int*, int, int);

static unsigned long pypy__rotateLeft(unsigned long x, long n) {
    unsigned int x1 = x;    /* arithmetic directly on int */
    int n1 = n;
    return (x1 << n1) | (x1 >> (32-n1));
}


static void *pypy__cffi_fetch_var(void *fetch_addr) {
    return ((void*(*)(void))fetch_addr)();
}

RPY_EXTERN int rpy_curses_setupterm(char *, int, int *);
RPY_EXTERN char *rpy_curses_tigetstr(char *);
RPY_EXTERN char *rpy_curses_tparm(char *, int, int, int, int, int, int, int, int, int);
#include <Python.h>
extern int Py_DontWriteBytecodeFlag;
int get_Py_DontWriteBytecodeFlag () { return Py_DontWriteBytecodeFlag; }
void set_Py_DontWriteBytecodeFlag (int v) { Py_DontWriteBytecodeFlag = v; }
