/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <fcntl.h>
#include <sys/file.h>
#include <sys/ioctl.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef DN_ACCESS
	dump("defined", 1);
	if ((DN_ACCESS) <= 0) {
	    long long x = (long long)(DN_ACCESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_ACCESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef DN_ATTRIB
	dump("defined", 1);
	if ((DN_ATTRIB) <= 0) {
	    long long x = (long long)(DN_ATTRIB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_ATTRIB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef DN_CREATE
	dump("defined", 1);
	if ((DN_CREATE) <= 0) {
	    long long x = (long long)(DN_CREATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_CREATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef DN_DELETE
	dump("defined", 1);
	if ((DN_DELETE) <= 0) {
	    long long x = (long long)(DN_DELETE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_DELETE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef DN_MODIFY
	dump("defined", 1);
	if ((DN_MODIFY) <= 0) {
	    long long x = (long long)(DN_MODIFY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_MODIFY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef DN_MULTISHOT
	dump("defined", 1);
	if ((DN_MULTISHOT) <= 0) {
	    long long x = (long long)(DN_MULTISHOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_MULTISHOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef DN_RENAME
	dump("defined", 1);
	if ((DN_RENAME) <= 0) {
	    long long x = (long long)(DN_RENAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_RENAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef FD_CLOEXEC
	dump("defined", 1);
	if ((FD_CLOEXEC) <= 0) {
	    long long x = (long long)(FD_CLOEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CLOEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef F_DUPFD
	dump("defined", 1);
	if ((F_DUPFD) <= 0) {
	    long long x = (long long)(F_DUPFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_DUPFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef F_EXLCK
	dump("defined", 1);
	if ((F_EXLCK) <= 0) {
	    long long x = (long long)(F_EXLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_EXLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef F_GETFD
	dump("defined", 1);
	if ((F_GETFD) <= 0) {
	    long long x = (long long)(F_GETFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef F_GETFL
	dump("defined", 1);
	if ((F_GETFL) <= 0) {
	    long long x = (long long)(F_GETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef F_GETLEASE
	dump("defined", 1);
	if ((F_GETLEASE) <= 0) {
	    long long x = (long long)(F_GETLEASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETLEASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef F_GETLK
	dump("defined", 1);
	if ((F_GETLK) <= 0) {
	    long long x = (long long)(F_GETLK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETLK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef F_GETLK64
	dump("defined", 1);
	if ((F_GETLK64) <= 0) {
	    long long x = (long long)(F_GETLK64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETLK64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef F_GETOWN
	dump("defined", 1);
	if ((F_GETOWN) <= 0) {
	    long long x = (long long)(F_GETOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef F_GETSIG
	dump("defined", 1);
	if ((F_GETSIG) <= 0) {
	    long long x = (long long)(F_GETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef F_NOTIFY
	dump("defined", 1);
	if ((F_NOTIFY) <= 0) {
	    long long x = (long long)(F_NOTIFY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_NOTIFY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef F_RDLCK
	dump("defined", 1);
	if ((F_RDLCK) <= 0) {
	    long long x = (long long)(F_RDLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_RDLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef F_SETFD
	dump("defined", 1);
	if ((F_SETFD) <= 0) {
	    long long x = (long long)(F_SETFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef F_SETFL
	dump("defined", 1);
	if ((F_SETFL) <= 0) {
	    long long x = (long long)(F_SETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef F_SETLEASE
	dump("defined", 1);
	if ((F_SETLEASE) <= 0) {
	    long long x = (long long)(F_SETLEASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLEASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
#ifdef F_SETLK
	dump("defined", 1);
	if ((F_SETLK) <= 0) {
	    long long x = (long long)(F_SETLK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_23(void) {
#ifdef F_SETLK64
	dump("defined", 1);
	if ((F_SETLK64) <= 0) {
	    long long x = (long long)(F_SETLK64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLK64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_24(void) {
#ifdef F_SETLKW
	dump("defined", 1);
	if ((F_SETLKW) <= 0) {
	    long long x = (long long)(F_SETLKW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLKW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_25(void) {
#ifdef F_SETLKW64
	dump("defined", 1);
	if ((F_SETLKW64) <= 0) {
	    long long x = (long long)(F_SETLKW64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLKW64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef F_SETOWN
	dump("defined", 1);
	if ((F_SETOWN) <= 0) {
	    long long x = (long long)(F_SETOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_27(void) {
#ifdef F_SETSIG
	dump("defined", 1);
	if ((F_SETSIG) <= 0) {
	    long long x = (long long)(F_SETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef F_SHLCK
	dump("defined", 1);
	if ((F_SHLCK) <= 0) {
	    long long x = (long long)(F_SHLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SHLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef F_UNLCK
	dump("defined", 1);
	if ((F_UNLCK) <= 0) {
	    long long x = (long long)(F_UNLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_UNLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef F_WRLCK
	dump("defined", 1);
	if ((F_WRLCK) <= 0) {
	    long long x = (long long)(F_WRLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_WRLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef I_ATMARK
	dump("defined", 1);
	if ((I_ATMARK) <= 0) {
	    long long x = (long long)(I_ATMARK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_ATMARK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
#ifdef I_CANPUT
	dump("defined", 1);
	if ((I_CANPUT) <= 0) {
	    long long x = (long long)(I_CANPUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_CANPUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_33(void) {
#ifdef I_CKBAND
	dump("defined", 1);
	if ((I_CKBAND) <= 0) {
	    long long x = (long long)(I_CKBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_CKBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
#ifdef I_FDINSERT
	dump("defined", 1);
	if ((I_FDINSERT) <= 0) {
	    long long x = (long long)(I_FDINSERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FDINSERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_35(void) {
#ifdef I_FIND
	dump("defined", 1);
	if ((I_FIND) <= 0) {
	    long long x = (long long)(I_FIND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FIND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_36(void) {
#ifdef I_FLUSH
	dump("defined", 1);
	if ((I_FLUSH) <= 0) {
	    long long x = (long long)(I_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_37(void) {
#ifdef I_FLUSHBAND
	dump("defined", 1);
	if ((I_FLUSHBAND) <= 0) {
	    long long x = (long long)(I_FLUSHBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FLUSHBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_38(void) {
#ifdef I_GETBAND
	dump("defined", 1);
	if ((I_GETBAND) <= 0) {
	    long long x = (long long)(I_GETBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GETBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_39(void) {
#ifdef I_GETCLTIME
	dump("defined", 1);
	if ((I_GETCLTIME) <= 0) {
	    long long x = (long long)(I_GETCLTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GETCLTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_40(void) {
#ifdef I_GETSIG
	dump("defined", 1);
	if ((I_GETSIG) <= 0) {
	    long long x = (long long)(I_GETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_41(void) {
#ifdef I_GRDOPT
	dump("defined", 1);
	if ((I_GRDOPT) <= 0) {
	    long long x = (long long)(I_GRDOPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GRDOPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_42(void) {
#ifdef I_LINK
	dump("defined", 1);
	if ((I_LINK) <= 0) {
	    long long x = (long long)(I_LINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_LINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_43(void) {
#ifdef I_LIST
	dump("defined", 1);
	if ((I_LIST) <= 0) {
	    long long x = (long long)(I_LIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_LIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_44(void) {
#ifdef I_LOOK
	dump("defined", 1);
	if ((I_LOOK) <= 0) {
	    long long x = (long long)(I_LOOK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_LOOK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_45(void) {
#ifdef I_NREAD
	dump("defined", 1);
	if ((I_NREAD) <= 0) {
	    long long x = (long long)(I_NREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_NREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_46(void) {
#ifdef I_PEEK
	dump("defined", 1);
	if ((I_PEEK) <= 0) {
	    long long x = (long long)(I_PEEK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PEEK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_47(void) {
#ifdef I_PLINK
	dump("defined", 1);
	if ((I_PLINK) <= 0) {
	    long long x = (long long)(I_PLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_48(void) {
#ifdef I_POP
	dump("defined", 1);
	if ((I_POP) <= 0) {
	    long long x = (long long)(I_POP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_POP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_49(void) {
#ifdef I_PUNLINK
	dump("defined", 1);
	if ((I_PUNLINK) <= 0) {
	    long long x = (long long)(I_PUNLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PUNLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_50(void) {
#ifdef I_PUSH
	dump("defined", 1);
	if ((I_PUSH) <= 0) {
	    long long x = (long long)(I_PUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
#ifdef I_RECVFD
	dump("defined", 1);
	if ((I_RECVFD) <= 0) {
	    long long x = (long long)(I_RECVFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_RECVFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_52(void) {
#ifdef I_SENDFD
	dump("defined", 1);
	if ((I_SENDFD) <= 0) {
	    long long x = (long long)(I_SENDFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SENDFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_53(void) {
#ifdef I_SETCLTIME
	dump("defined", 1);
	if ((I_SETCLTIME) <= 0) {
	    long long x = (long long)(I_SETCLTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SETCLTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_54(void) {
#ifdef I_SETSIG
	dump("defined", 1);
	if ((I_SETSIG) <= 0) {
	    long long x = (long long)(I_SETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_55(void) {
#ifdef I_SRDOPT
	dump("defined", 1);
	if ((I_SRDOPT) <= 0) {
	    long long x = (long long)(I_SRDOPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SRDOPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_56(void) {
#ifdef I_STR
	dump("defined", 1);
	if ((I_STR) <= 0) {
	    long long x = (long long)(I_STR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_STR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_57(void) {
#ifdef I_SWROPT
	dump("defined", 1);
	if ((I_SWROPT) <= 0) {
	    long long x = (long long)(I_SWROPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SWROPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_58(void) {
#ifdef I_UNLINK
	dump("defined", 1);
	if ((I_UNLINK) <= 0) {
	    long long x = (long long)(I_UNLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_UNLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_59(void) {
#ifdef LOCK_EX
	dump("defined", 1);
	if ((LOCK_EX) <= 0) {
	    long long x = (long long)(LOCK_EX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_EX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_60(void) {
#ifdef LOCK_MAND
	dump("defined", 1);
	if ((LOCK_MAND) <= 0) {
	    long long x = (long long)(LOCK_MAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_MAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_61(void) {
#ifdef LOCK_NB
	dump("defined", 1);
	if ((LOCK_NB) <= 0) {
	    long long x = (long long)(LOCK_NB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_NB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_62(void) {
#ifdef LOCK_READ
	dump("defined", 1);
	if ((LOCK_READ) <= 0) {
	    long long x = (long long)(LOCK_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_READ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_63(void) {
#ifdef LOCK_RW
	dump("defined", 1);
	if ((LOCK_RW) <= 0) {
	    long long x = (long long)(LOCK_RW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_RW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_64(void) {
#ifdef LOCK_SH
	dump("defined", 1);
	if ((LOCK_SH) <= 0) {
	    long long x = (long long)(LOCK_SH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_SH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_65(void) {
#ifdef LOCK_UN
	dump("defined", 1);
	if ((LOCK_UN) <= 0) {
	    long long x = (long long)(LOCK_UN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_UN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_66(void) {
#ifdef LOCK_WRITE
	dump("defined", 1);
	if ((LOCK_WRITE) <= 0) {
	    long long x = (long long)(LOCK_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_WRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_67(void) {
	typedef struct flock platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs l_start", offsetof(platcheck_t, l_start));
	dump("fldsize l_start",   sizeof(s.l_start));
	s.l_start = 0; s.l_start = ~s.l_start;
	dump("fldunsigned l_start", s.l_start > 0);
	dump("fldofs l_len", offsetof(platcheck_t, l_len));
	dump("fldsize l_len",   sizeof(s.l_len));
	s.l_len = 0; s.l_len = ~s.l_len;
	dump("fldunsigned l_len", s.l_len > 0);
	dump("fldofs l_pid", offsetof(platcheck_t, l_pid));
	dump("fldsize l_pid",   sizeof(s.l_pid));
	s.l_pid = 0; s.l_pid = ~s.l_pid;
	dump("fldunsigned l_pid", s.l_pid > 0);
	dump("fldofs l_type", offsetof(platcheck_t, l_type));
	dump("fldsize l_type",   sizeof(s.l_type));
	s.l_type = 0; s.l_type = ~s.l_type;
	dump("fldunsigned l_type", s.l_type > 0);
	dump("fldofs l_whence", offsetof(platcheck_t, l_whence));
	dump("fldsize l_whence",   sizeof(s.l_whence));
	s.l_whence = 0; s.l_whence = ~s.l_whence;
	dump("fldunsigned l_whence", s.l_whence > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	return 0;
}
