/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>

/* See doc/misc/parse_c_type.rst in the source of CFFI for more information */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};



#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef struct _cffi_global_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs address", offsetof(platcheck_t, address));
	dump("fldsize address",   sizeof(s.address));
	dump("fldofs type_op", offsetof(platcheck_t, type_op));
	dump("fldsize type_op",   sizeof(s.type_op));
	dump("fldofs size_or_direct_fn", offsetof(platcheck_t, size_or_direct_fn));
	dump("fldsize size_or_direct_fn",   sizeof(s.size_or_direct_fn));
}

void dump_section_1(void) {
	typedef struct _cffi_getconst_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs value", offsetof(platcheck_t, value));
	dump("fldsize value",   sizeof(s.value));
	s.value = 0; s.value = ~s.value;
	dump("fldunsigned value", s.value > 0);
	dump("fldofs ctx", offsetof(platcheck_t, ctx));
	dump("fldsize ctx",   sizeof(s.ctx));
	dump("fldofs gindex", offsetof(platcheck_t, gindex));
	dump("fldsize gindex",   sizeof(s.gindex));
}

void dump_section_2(void) {
	typedef struct _cffi_type_context_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs types", offsetof(platcheck_t, types));
	dump("fldsize types",   sizeof(s.types));
	dump("fldofs globals", offsetof(platcheck_t, globals));
	dump("fldsize globals",   sizeof(s.globals));
	dump("fldofs fields", offsetof(platcheck_t, fields));
	dump("fldsize fields",   sizeof(s.fields));
	dump("fldofs struct_unions", offsetof(platcheck_t, struct_unions));
	dump("fldsize struct_unions",   sizeof(s.struct_unions));
	dump("fldofs enums", offsetof(platcheck_t, enums));
	dump("fldsize enums",   sizeof(s.enums));
	dump("fldofs typenames", offsetof(platcheck_t, typenames));
	dump("fldsize typenames",   sizeof(s.typenames));
	dump("fldofs num_globals", offsetof(platcheck_t, num_globals));
	dump("fldsize num_globals",   sizeof(s.num_globals));
	dump("fldofs num_struct_unions", offsetof(platcheck_t, num_struct_unions));
	dump("fldsize num_struct_unions",   sizeof(s.num_struct_unions));
	dump("fldofs num_enums", offsetof(platcheck_t, num_enums));
	dump("fldsize num_enums",   sizeof(s.num_enums));
	dump("fldofs num_typenames", offsetof(platcheck_t, num_typenames));
	dump("fldsize num_typenames",   sizeof(s.num_typenames));
	dump("fldofs includes", offsetof(platcheck_t, includes));
	dump("fldsize includes",   sizeof(s.includes));
	dump("fldofs num_types", offsetof(platcheck_t, num_types));
	dump("fldsize num_types",   sizeof(s.num_types));
	dump("fldofs flags", offsetof(platcheck_t, flags));
	dump("fldsize flags",   sizeof(s.flags));
}

void dump_section_3(void) {
	typedef struct _cffi_struct_union_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type_index", offsetof(platcheck_t, type_index));
	dump("fldsize type_index",   sizeof(s.type_index));
	dump("fldofs flags", offsetof(platcheck_t, flags));
	dump("fldsize flags",   sizeof(s.flags));
	dump("fldofs size", offsetof(platcheck_t, size));
	dump("fldsize size",   sizeof(s.size));
	s.size = 0; s.size = ~s.size;
	dump("fldunsigned size", s.size > 0);
	dump("fldofs alignment", offsetof(platcheck_t, alignment));
	dump("fldsize alignment",   sizeof(s.alignment));
	dump("fldofs first_field_index", offsetof(platcheck_t, first_field_index));
	dump("fldsize first_field_index",   sizeof(s.first_field_index));
	dump("fldofs num_fields", offsetof(platcheck_t, num_fields));
	dump("fldsize num_fields",   sizeof(s.num_fields));
}

void dump_section_4(void) {
	typedef struct _cffi_field_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs field_offset", offsetof(platcheck_t, field_offset));
	dump("fldsize field_offset",   sizeof(s.field_offset));
	s.field_offset = 0; s.field_offset = ~s.field_offset;
	dump("fldunsigned field_offset", s.field_offset > 0);
	dump("fldofs field_size", offsetof(platcheck_t, field_size));
	dump("fldsize field_size",   sizeof(s.field_size));
	s.field_size = 0; s.field_size = ~s.field_size;
	dump("fldunsigned field_size", s.field_size > 0);
	dump("fldofs field_type_op", offsetof(platcheck_t, field_type_op));
	dump("fldsize field_type_op",   sizeof(s.field_type_op));
}

void dump_section_5(void) {
	typedef struct _cffi_enum_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type_index", offsetof(platcheck_t, type_index));
	dump("fldsize type_index",   sizeof(s.type_index));
	dump("fldofs type_prim", offsetof(platcheck_t, type_prim));
	dump("fldsize type_prim",   sizeof(s.type_prim));
	dump("fldofs enumerators", offsetof(platcheck_t, enumerators));
	dump("fldsize enumerators",   sizeof(s.enumerators));
}

void dump_section_6(void) {
	typedef struct _cffi_typename_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type_index", offsetof(platcheck_t, type_index));
	dump("fldsize type_index",   sizeof(s.type_index));
}

void dump_section_7(void) {
	typedef struct _cffi_parse_info_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ctx", offsetof(platcheck_t, ctx));
	dump("fldsize ctx",   sizeof(s.ctx));
	dump("fldofs output", offsetof(platcheck_t, output));
	dump("fldsize output",   sizeof(s.output));
	dump("fldofs output_size", offsetof(platcheck_t, output_size));
	dump("fldsize output_size",   sizeof(s.output_size));
	s.output_size = 0; s.output_size = ~s.output_size;
	dump("fldunsigned output_size", s.output_size > 0);
	dump("fldofs error_location", offsetof(platcheck_t, error_location));
	dump("fldsize error_location",   sizeof(s.error_location));
	s.error_location = 0; s.error_location = ~s.error_location;
	dump("fldunsigned error_location", s.error_location > 0);
	dump("fldofs error_message", offsetof(platcheck_t, error_message));
	dump("fldsize error_message",   sizeof(s.error_message));
}

void dump_section_8(void) {
	typedef struct _cffi_externpy_s platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs size_of_result", offsetof(platcheck_t, size_of_result));
	dump("fldsize size_of_result",   sizeof(s.size_of_result));
	s.size_of_result = 0; s.size_of_result = ~s.size_of_result;
	dump("fldunsigned size_of_result", s.size_of_result > 0);
	dump("fldofs reserved1", offsetof(platcheck_t, reserved1));
	dump("fldsize reserved1",   sizeof(s.reserved1));
	dump("fldofs reserved2", offsetof(platcheck_t, reserved2));
	dump("fldsize reserved2",   sizeof(s.reserved2));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	return 0;
}
