/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <stdio.h>
#include <sys/types.h>
#include <bzlib.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	if ((BUFSIZ) <= 0) {
	    long long x = (long long)(BUFSIZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BUFSIZ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_1(void) {
#ifdef BZ_CONFIG_ERROR
	dump("defined", 1);
	if ((BZ_CONFIG_ERROR) <= 0) {
	    long long x = (long long)(BZ_CONFIG_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_CONFIG_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef BZ_DATA_ERROR
	dump("defined", 1);
	if ((BZ_DATA_ERROR) <= 0) {
	    long long x = (long long)(BZ_DATA_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_DATA_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef BZ_DATA_ERROR_MAGIC
	dump("defined", 1);
	if ((BZ_DATA_ERROR_MAGIC) <= 0) {
	    long long x = (long long)(BZ_DATA_ERROR_MAGIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_DATA_ERROR_MAGIC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef BZ_FINISH
	dump("defined", 1);
	if ((BZ_FINISH) <= 0) {
	    long long x = (long long)(BZ_FINISH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_FINISH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef BZ_FINISH_OK
	dump("defined", 1);
	if ((BZ_FINISH_OK) <= 0) {
	    long long x = (long long)(BZ_FINISH_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_FINISH_OK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef BZ_FLUSH
	dump("defined", 1);
	if ((BZ_FLUSH) <= 0) {
	    long long x = (long long)(BZ_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_FLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef BZ_FLUSH_OK
	dump("defined", 1);
	if ((BZ_FLUSH_OK) <= 0) {
	    long long x = (long long)(BZ_FLUSH_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_FLUSH_OK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef BZ_IO_ERROR
	dump("defined", 1);
	if ((BZ_IO_ERROR) <= 0) {
	    long long x = (long long)(BZ_IO_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_IO_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef BZ_MEM_ERROR
	dump("defined", 1);
	if ((BZ_MEM_ERROR) <= 0) {
	    long long x = (long long)(BZ_MEM_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_MEM_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef BZ_OK
	dump("defined", 1);
	if ((BZ_OK) <= 0) {
	    long long x = (long long)(BZ_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_OK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef BZ_OUTBUFF_FULL
	dump("defined", 1);
	if ((BZ_OUTBUFF_FULL) <= 0) {
	    long long x = (long long)(BZ_OUTBUFF_FULL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_OUTBUFF_FULL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef BZ_PARAM_ERROR
	dump("defined", 1);
	if ((BZ_PARAM_ERROR) <= 0) {
	    long long x = (long long)(BZ_PARAM_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_PARAM_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef BZ_RUN
	dump("defined", 1);
	if ((BZ_RUN) <= 0) {
	    long long x = (long long)(BZ_RUN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_RUN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef BZ_RUN_OK
	dump("defined", 1);
	if ((BZ_RUN_OK) <= 0) {
	    long long x = (long long)(BZ_RUN_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_RUN_OK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef BZ_SEQUENCE_ERROR
	dump("defined", 1);
	if ((BZ_SEQUENCE_ERROR) <= 0) {
	    long long x = (long long)(BZ_SEQUENCE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_SEQUENCE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef BZ_STREAM_END
	dump("defined", 1);
	if ((BZ_STREAM_END) <= 0) {
	    long long x = (long long)(BZ_STREAM_END);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_STREAM_END);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef BZ_UNEXPECTED_EOF
	dump("defined", 1);
	if ((BZ_UNEXPECTED_EOF) <= 0) {
	    long long x = (long long)(BZ_UNEXPECTED_EOF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BZ_UNEXPECTED_EOF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
	if ((SEEK_SET) <= 0) {
	    long long x = (long long)(SEEK_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_SET);
	    printf("value: %llu\n", x);
	}
}

void dump_section_19(void) {
	typedef bz_stream platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs next_in", offsetof(platcheck_t, next_in));
	dump("fldsize next_in",   sizeof(s.next_in));
	dump("fldofs avail_in", offsetof(platcheck_t, avail_in));
	dump("fldsize avail_in",   sizeof(s.avail_in));
	s.avail_in = 0; s.avail_in = ~s.avail_in;
	dump("fldunsigned avail_in", s.avail_in > 0);
	dump("fldofs total_in_lo32", offsetof(platcheck_t, total_in_lo32));
	dump("fldsize total_in_lo32",   sizeof(s.total_in_lo32));
	s.total_in_lo32 = 0; s.total_in_lo32 = ~s.total_in_lo32;
	dump("fldunsigned total_in_lo32", s.total_in_lo32 > 0);
	dump("fldofs total_in_hi32", offsetof(platcheck_t, total_in_hi32));
	dump("fldsize total_in_hi32",   sizeof(s.total_in_hi32));
	s.total_in_hi32 = 0; s.total_in_hi32 = ~s.total_in_hi32;
	dump("fldunsigned total_in_hi32", s.total_in_hi32 > 0);
	dump("fldofs next_out", offsetof(platcheck_t, next_out));
	dump("fldsize next_out",   sizeof(s.next_out));
	dump("fldofs avail_out", offsetof(platcheck_t, avail_out));
	dump("fldsize avail_out",   sizeof(s.avail_out));
	s.avail_out = 0; s.avail_out = ~s.avail_out;
	dump("fldunsigned avail_out", s.avail_out > 0);
	dump("fldofs total_out_lo32", offsetof(platcheck_t, total_out_lo32));
	dump("fldsize total_out_lo32",   sizeof(s.total_out_lo32));
	s.total_out_lo32 = 0; s.total_out_lo32 = ~s.total_out_lo32;
	dump("fldunsigned total_out_lo32", s.total_out_lo32 > 0);
	dump("fldofs total_out_hi32", offsetof(platcheck_t, total_out_hi32));
	dump("fldsize total_out_hi32",   sizeof(s.total_out_hi32));
	s.total_out_hi32 = 0; s.total_out_hi32 = ~s.total_out_hi32;
	dump("fldunsigned total_out_hi32", s.total_out_hi32 > 0);
	dump("fldofs state", offsetof(platcheck_t, state));
	dump("fldsize state",   sizeof(s.state));
	dump("fldofs bzalloc", offsetof(platcheck_t, bzalloc));
	dump("fldsize bzalloc",   sizeof(s.bzalloc));
	dump("fldofs bzfree", offsetof(platcheck_t, bzfree));
	dump("fldsize bzfree",   sizeof(s.bzfree));
	dump("fldofs opaque", offsetof(platcheck_t, opaque));
	dump("fldsize opaque",   sizeof(s.opaque));
}

void dump_section_20(void) {
	typedef off_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_21(void) {
	typedef size_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	return 0;
}
