/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <time.h>
#include <sys/time.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	if ((CLOCKS_PER_SEC) <= 0) {
	    long long x = (long long)(CLOCKS_PER_SEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CLOCKS_PER_SEC);
	    printf("value: %llu\n", x);
	}
}

void dump_section_1(void) {
	typedef clock_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_2(void) {
	typedef struct timeval platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs tv_sec", offsetof(platcheck_t, tv_sec));
	dump("fldsize tv_sec",   sizeof(s.tv_sec));
	s.tv_sec = 0; s.tv_sec = ~s.tv_sec;
	dump("fldunsigned tv_sec", s.tv_sec > 0);
	dump("fldofs tv_usec", offsetof(platcheck_t, tv_usec));
	dump("fldsize tv_usec",   sizeof(s.tv_usec));
	s.tv_usec = 0; s.tv_usec = ~s.tv_usec;
	dump("fldunsigned tv_usec", s.tv_usec > 0);
}

void dump_section_3(void) {
	typedef struct tm platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs tm_sec", offsetof(platcheck_t, tm_sec));
	dump("fldsize tm_sec",   sizeof(s.tm_sec));
	s.tm_sec = 0; s.tm_sec = ~s.tm_sec;
	dump("fldunsigned tm_sec", s.tm_sec > 0);
	dump("fldofs tm_min", offsetof(platcheck_t, tm_min));
	dump("fldsize tm_min",   sizeof(s.tm_min));
	s.tm_min = 0; s.tm_min = ~s.tm_min;
	dump("fldunsigned tm_min", s.tm_min > 0);
	dump("fldofs tm_hour", offsetof(platcheck_t, tm_hour));
	dump("fldsize tm_hour",   sizeof(s.tm_hour));
	s.tm_hour = 0; s.tm_hour = ~s.tm_hour;
	dump("fldunsigned tm_hour", s.tm_hour > 0);
	dump("fldofs tm_mday", offsetof(platcheck_t, tm_mday));
	dump("fldsize tm_mday",   sizeof(s.tm_mday));
	s.tm_mday = 0; s.tm_mday = ~s.tm_mday;
	dump("fldunsigned tm_mday", s.tm_mday > 0);
	dump("fldofs tm_mon", offsetof(platcheck_t, tm_mon));
	dump("fldsize tm_mon",   sizeof(s.tm_mon));
	s.tm_mon = 0; s.tm_mon = ~s.tm_mon;
	dump("fldunsigned tm_mon", s.tm_mon > 0);
	dump("fldofs tm_year", offsetof(platcheck_t, tm_year));
	dump("fldsize tm_year",   sizeof(s.tm_year));
	s.tm_year = 0; s.tm_year = ~s.tm_year;
	dump("fldunsigned tm_year", s.tm_year > 0);
	dump("fldofs tm_wday", offsetof(platcheck_t, tm_wday));
	dump("fldsize tm_wday",   sizeof(s.tm_wday));
	s.tm_wday = 0; s.tm_wday = ~s.tm_wday;
	dump("fldunsigned tm_wday", s.tm_wday > 0);
	dump("fldofs tm_yday", offsetof(platcheck_t, tm_yday));
	dump("fldsize tm_yday",   sizeof(s.tm_yday));
	s.tm_yday = 0; s.tm_yday = ~s.tm_yday;
	dump("fldunsigned tm_yday", s.tm_yday > 0);
	dump("fldofs tm_isdst", offsetof(platcheck_t, tm_isdst));
	dump("fldsize tm_isdst",   sizeof(s.tm_isdst));
	s.tm_isdst = 0; s.tm_isdst = ~s.tm_isdst;
	dump("fldunsigned tm_isdst", s.tm_isdst > 0);
	dump("fldofs tm_gmtoff", offsetof(platcheck_t, tm_gmtoff));
	dump("fldsize tm_gmtoff",   sizeof(s.tm_gmtoff));
	s.tm_gmtoff = 0; s.tm_gmtoff = ~s.tm_gmtoff;
	dump("fldunsigned tm_gmtoff", s.tm_gmtoff > 0);
	dump("fldofs tm_zone", offsetof(platcheck_t, tm_zone));
	dump("fldsize tm_zone",   sizeof(s.tm_zone));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	return 0;
}
