/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <unistd.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <utime.h>
#include <sys/time.h>
#include <sys/times.h>
#include <sys/resource.h>
#include <sched.h>
#include <grp.h>
#include <dirent.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <signal.h>
#include <sys/utsname.h>
#include <pty.h>
#include <sys/sysmacros.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef clock_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_1(void) {
#ifdef F_LOCK
	dump("defined", 1);
	if ((F_LOCK) <= 0) {
	    long long x = (long long)(F_LOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_LOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef F_TEST
	dump("defined", 1);
	if ((F_TEST) <= 0) {
	    long long x = (long long)(F_TEST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_TEST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef F_TLOCK
	dump("defined", 1);
	if ((F_TLOCK) <= 0) {
	    long long x = (long long)(F_TLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_TLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef F_ULOCK
	dump("defined", 1);
	if ((F_ULOCK) <= 0) {
	    long long x = (long long)(F_ULOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_ULOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
	typedef gid_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_6(void) {
	typedef id_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_7(void) {
#ifdef NCCS
	dump("defined", 1);
	if ((NCCS) <= 0) {
	    long long x = (long long)(NCCS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NCCS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
	typedef off_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_9(void) {
	dump("size",  sizeof(off_t));
}

void dump_section_10(void) {
#ifdef O_NONBLOCK
	dump("defined", 1);
	if ((O_NONBLOCK) <= 0) {
	    long long x = (long long)(O_NONBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_NONBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef PRIO_PGRP
	dump("defined", 1);
	if ((PRIO_PGRP) <= 0) {
	    long long x = (long long)(PRIO_PGRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PRIO_PGRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef PRIO_PROCESS
	dump("defined", 1);
	if ((PRIO_PROCESS) <= 0) {
	    long long x = (long long)(PRIO_PROCESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PRIO_PROCESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef PRIO_USER
	dump("defined", 1);
	if ((PRIO_USER) <= 0) {
	    long long x = (long long)(PRIO_USER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PRIO_USER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef SCHED_BATCH
	dump("defined", 1);
	if ((SCHED_BATCH) <= 0) {
	    long long x = (long long)(SCHED_BATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SCHED_BATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef SCHED_FIFO
	dump("defined", 1);
	if ((SCHED_FIFO) <= 0) {
	    long long x = (long long)(SCHED_FIFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SCHED_FIFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef SCHED_OTHER
	dump("defined", 1);
	if ((SCHED_OTHER) <= 0) {
	    long long x = (long long)(SCHED_OTHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SCHED_OTHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef SCHED_RR
	dump("defined", 1);
	if ((SCHED_RR) <= 0) {
	    long long x = (long long)(SCHED_RR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SCHED_RR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef SEEK_CUR
	dump("defined", 1);
	if ((SEEK_CUR) <= 0) {
	    long long x = (long long)(SEEK_CUR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_CUR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef SEEK_END
	dump("defined", 1);
	if ((SEEK_END) <= 0) {
	    long long x = (long long)(SEEK_END);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_END);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef SEEK_SET
	dump("defined", 1);
	if ((SEEK_SET) <= 0) {
	    long long x = (long long)(SEEK_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef TIOCGWINSZ
	dump("defined", 1);
	if ((TIOCGWINSZ) <= 0) {
	    long long x = (long long)(TIOCGWINSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGWINSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
	typedef struct tms platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs tms_utime", offsetof(platcheck_t, tms_utime));
	dump("fldsize tms_utime",   sizeof(s.tms_utime));
	s.tms_utime = 0; s.tms_utime = ~s.tms_utime;
	dump("fldunsigned tms_utime", s.tms_utime > 0);
	dump("fldofs tms_stime", offsetof(platcheck_t, tms_stime));
	dump("fldsize tms_stime",   sizeof(s.tms_stime));
	s.tms_stime = 0; s.tms_stime = ~s.tms_stime;
	dump("fldunsigned tms_stime", s.tms_stime > 0);
	dump("fldofs tms_cutime", offsetof(platcheck_t, tms_cutime));
	dump("fldsize tms_cutime",   sizeof(s.tms_cutime));
	s.tms_cutime = 0; s.tms_cutime = ~s.tms_cutime;
	dump("fldunsigned tms_cutime", s.tms_cutime > 0);
	dump("fldofs tms_cstime", offsetof(platcheck_t, tms_cstime));
	dump("fldsize tms_cstime",   sizeof(s.tms_cstime));
	s.tms_cstime = 0; s.tms_cstime = ~s.tms_cstime;
	dump("fldunsigned tms_cstime", s.tms_cstime > 0);
}

void dump_section_23(void) {
	typedef uid_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_24(void) {
	typedef struct utimbuf platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs actime", offsetof(platcheck_t, actime));
	dump("fldsize actime",   sizeof(s.actime));
	s.actime = 0; s.actime = ~s.actime;
	dump("fldunsigned actime", s.actime > 0);
	dump("fldofs modtime", offsetof(platcheck_t, modtime));
	dump("fldsize modtime",   sizeof(s.modtime));
	s.modtime = 0; s.modtime = ~s.modtime;
	dump("fldunsigned modtime", s.modtime > 0);
}

void dump_section_25(void) {
#ifdef _HAVE_STRUCT_TERMIOS_C_ISPEED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef _HAVE_STRUCT_TERMIOS_C_OSPEED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	return 0;
}
