/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <unistd.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef _CS_ARCHITECTURE
	dump("defined", 1);
	if ((_CS_ARCHITECTURE) <= 0) {
	    long long x = (long long)(_CS_ARCHITECTURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_ARCHITECTURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef _CS_GNU_LIBC_VERSION
	dump("defined", 1);
	if ((_CS_GNU_LIBC_VERSION) <= 0) {
	    long long x = (long long)(_CS_GNU_LIBC_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_GNU_LIBC_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef _CS_GNU_LIBPTHREAD_VERSION
	dump("defined", 1);
	if ((_CS_GNU_LIBPTHREAD_VERSION) <= 0) {
	    long long x = (long long)(_CS_GNU_LIBPTHREAD_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_GNU_LIBPTHREAD_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef _CS_HOSTNAME
	dump("defined", 1);
	if ((_CS_HOSTNAME) <= 0) {
	    long long x = (long long)(_CS_HOSTNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_HOSTNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef _CS_HW_PROVIDER
	dump("defined", 1);
	if ((_CS_HW_PROVIDER) <= 0) {
	    long long x = (long long)(_CS_HW_PROVIDER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_HW_PROVIDER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef _CS_HW_SERIAL
	dump("defined", 1);
	if ((_CS_HW_SERIAL) <= 0) {
	    long long x = (long long)(_CS_HW_SERIAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_HW_SERIAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef _CS_INITTAB_NAME
	dump("defined", 1);
	if ((_CS_INITTAB_NAME) <= 0) {
	    long long x = (long long)(_CS_INITTAB_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_INITTAB_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef _CS_LFS64_CFLAGS
	dump("defined", 1);
	if ((_CS_LFS64_CFLAGS) <= 0) {
	    long long x = (long long)(_CS_LFS64_CFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS64_CFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef _CS_LFS64_LDFLAGS
	dump("defined", 1);
	if ((_CS_LFS64_LDFLAGS) <= 0) {
	    long long x = (long long)(_CS_LFS64_LDFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS64_LDFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef _CS_LFS64_LIBS
	dump("defined", 1);
	if ((_CS_LFS64_LIBS) <= 0) {
	    long long x = (long long)(_CS_LFS64_LIBS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS64_LIBS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef _CS_LFS64_LINTFLAGS
	dump("defined", 1);
	if ((_CS_LFS64_LINTFLAGS) <= 0) {
	    long long x = (long long)(_CS_LFS64_LINTFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS64_LINTFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef _CS_LFS_CFLAGS
	dump("defined", 1);
	if ((_CS_LFS_CFLAGS) <= 0) {
	    long long x = (long long)(_CS_LFS_CFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS_CFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef _CS_LFS_LDFLAGS
	dump("defined", 1);
	if ((_CS_LFS_LDFLAGS) <= 0) {
	    long long x = (long long)(_CS_LFS_LDFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS_LDFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef _CS_LFS_LIBS
	dump("defined", 1);
	if ((_CS_LFS_LIBS) <= 0) {
	    long long x = (long long)(_CS_LFS_LIBS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS_LIBS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef _CS_LFS_LINTFLAGS
	dump("defined", 1);
	if ((_CS_LFS_LINTFLAGS) <= 0) {
	    long long x = (long long)(_CS_LFS_LINTFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_LFS_LINTFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef _CS_MACHINE
	dump("defined", 1);
	if ((_CS_MACHINE) <= 0) {
	    long long x = (long long)(_CS_MACHINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_MACHINE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef _CS_PATH
	dump("defined", 1);
	if ((_CS_PATH) <= 0) {
	    long long x = (long long)(_CS_PATH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_PATH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef _CS_RELEASE
	dump("defined", 1);
	if ((_CS_RELEASE) <= 0) {
	    long long x = (long long)(_CS_RELEASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_RELEASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef _CS_SRPC_DOMAIN
	dump("defined", 1);
	if ((_CS_SRPC_DOMAIN) <= 0) {
	    long long x = (long long)(_CS_SRPC_DOMAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_SRPC_DOMAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef _CS_SYSNAME
	dump("defined", 1);
	if ((_CS_SYSNAME) <= 0) {
	    long long x = (long long)(_CS_SYSNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_SYSNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef _CS_VERSION
	dump("defined", 1);
	if ((_CS_VERSION) <= 0) {
	    long long x = (long long)(_CS_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef _CS_XBS5_ILP32_OFF32_CFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFF32_CFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFF32_CFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFF32_CFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
#ifdef _CS_XBS5_ILP32_OFF32_LDFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFF32_LDFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFF32_LDFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFF32_LDFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_23(void) {
#ifdef _CS_XBS5_ILP32_OFF32_LIBS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFF32_LIBS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFF32_LIBS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFF32_LIBS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_24(void) {
#ifdef _CS_XBS5_ILP32_OFF32_LINTFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFF32_LINTFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFF32_LINTFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFF32_LINTFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_25(void) {
#ifdef _CS_XBS5_ILP32_OFFBIG_CFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFFBIG_CFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFFBIG_CFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFFBIG_CFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef _CS_XBS5_ILP32_OFFBIG_LDFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFFBIG_LDFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFFBIG_LDFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFFBIG_LDFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_27(void) {
#ifdef _CS_XBS5_ILP32_OFFBIG_LIBS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFFBIG_LIBS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFFBIG_LIBS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFFBIG_LIBS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef _CS_XBS5_ILP32_OFFBIG_LINTFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_ILP32_OFFBIG_LINTFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_ILP32_OFFBIG_LINTFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_ILP32_OFFBIG_LINTFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef _CS_XBS5_LP64_OFF64_CFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_LP64_OFF64_CFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LP64_OFF64_CFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LP64_OFF64_CFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef _CS_XBS5_LP64_OFF64_LDFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_LP64_OFF64_LDFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LP64_OFF64_LDFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LP64_OFF64_LDFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef _CS_XBS5_LP64_OFF64_LIBS
	dump("defined", 1);
	if ((_CS_XBS5_LP64_OFF64_LIBS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LP64_OFF64_LIBS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LP64_OFF64_LIBS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
#ifdef _CS_XBS5_LP64_OFF64_LINTFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_LP64_OFF64_LINTFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LP64_OFF64_LINTFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LP64_OFF64_LINTFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_33(void) {
#ifdef _CS_XBS5_LPBIG_OFFBIG_CFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_LPBIG_OFFBIG_CFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LPBIG_OFFBIG_CFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LPBIG_OFFBIG_CFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
#ifdef _CS_XBS5_LPBIG_OFFBIG_LDFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_LPBIG_OFFBIG_LDFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LPBIG_OFFBIG_LDFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LPBIG_OFFBIG_LDFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_35(void) {
#ifdef _CS_XBS5_LPBIG_OFFBIG_LIBS
	dump("defined", 1);
	if ((_CS_XBS5_LPBIG_OFFBIG_LIBS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LPBIG_OFFBIG_LIBS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LPBIG_OFFBIG_LIBS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_36(void) {
#ifdef _CS_XBS5_LPBIG_OFFBIG_LINTFLAGS
	dump("defined", 1);
	if ((_CS_XBS5_LPBIG_OFFBIG_LINTFLAGS) <= 0) {
	    long long x = (long long)(_CS_XBS5_LPBIG_OFFBIG_LINTFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_CS_XBS5_LPBIG_OFFBIG_LINTFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_37(void) {
#ifdef _MIPS_CS_AVAIL_PROCESSORS
	dump("defined", 1);
	if ((_MIPS_CS_AVAIL_PROCESSORS) <= 0) {
	    long long x = (long long)(_MIPS_CS_AVAIL_PROCESSORS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_AVAIL_PROCESSORS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_38(void) {
#ifdef _MIPS_CS_BASE
	dump("defined", 1);
	if ((_MIPS_CS_BASE) <= 0) {
	    long long x = (long long)(_MIPS_CS_BASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_BASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_39(void) {
#ifdef _MIPS_CS_HOSTID
	dump("defined", 1);
	if ((_MIPS_CS_HOSTID) <= 0) {
	    long long x = (long long)(_MIPS_CS_HOSTID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_HOSTID);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_40(void) {
#ifdef _MIPS_CS_HW_NAME
	dump("defined", 1);
	if ((_MIPS_CS_HW_NAME) <= 0) {
	    long long x = (long long)(_MIPS_CS_HW_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_HW_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_41(void) {
#ifdef _MIPS_CS_NUM_PROCESSORS
	dump("defined", 1);
	if ((_MIPS_CS_NUM_PROCESSORS) <= 0) {
	    long long x = (long long)(_MIPS_CS_NUM_PROCESSORS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_NUM_PROCESSORS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_42(void) {
#ifdef _MIPS_CS_OSREL_MAJ
	dump("defined", 1);
	if ((_MIPS_CS_OSREL_MAJ) <= 0) {
	    long long x = (long long)(_MIPS_CS_OSREL_MAJ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_OSREL_MAJ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_43(void) {
#ifdef _MIPS_CS_OSREL_MIN
	dump("defined", 1);
	if ((_MIPS_CS_OSREL_MIN) <= 0) {
	    long long x = (long long)(_MIPS_CS_OSREL_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_OSREL_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_44(void) {
#ifdef _MIPS_CS_OSREL_PATCH
	dump("defined", 1);
	if ((_MIPS_CS_OSREL_PATCH) <= 0) {
	    long long x = (long long)(_MIPS_CS_OSREL_PATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_OSREL_PATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_45(void) {
#ifdef _MIPS_CS_OS_NAME
	dump("defined", 1);
	if ((_MIPS_CS_OS_NAME) <= 0) {
	    long long x = (long long)(_MIPS_CS_OS_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_OS_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_46(void) {
#ifdef _MIPS_CS_OS_PROVIDER
	dump("defined", 1);
	if ((_MIPS_CS_OS_PROVIDER) <= 0) {
	    long long x = (long long)(_MIPS_CS_OS_PROVIDER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_OS_PROVIDER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_47(void) {
#ifdef _MIPS_CS_PROCESSORS
	dump("defined", 1);
	if ((_MIPS_CS_PROCESSORS) <= 0) {
	    long long x = (long long)(_MIPS_CS_PROCESSORS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_PROCESSORS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_48(void) {
#ifdef _MIPS_CS_SERIAL
	dump("defined", 1);
	if ((_MIPS_CS_SERIAL) <= 0) {
	    long long x = (long long)(_MIPS_CS_SERIAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_SERIAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_49(void) {
#ifdef _MIPS_CS_VENDOR
	dump("defined", 1);
	if ((_MIPS_CS_VENDOR) <= 0) {
	    long long x = (long long)(_MIPS_CS_VENDOR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_MIPS_CS_VENDOR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_50(void) {
#ifdef _PC_ABI_AIO_XFER_MAX
	dump("defined", 1);
	if ((_PC_ABI_AIO_XFER_MAX) <= 0) {
	    long long x = (long long)(_PC_ABI_AIO_XFER_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_ABI_AIO_XFER_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
#ifdef _PC_ABI_ASYNC_IO
	dump("defined", 1);
	if ((_PC_ABI_ASYNC_IO) <= 0) {
	    long long x = (long long)(_PC_ABI_ASYNC_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_ABI_ASYNC_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_52(void) {
#ifdef _PC_ACL_ENABLED
	dump("defined", 1);
	if ((_PC_ACL_ENABLED) <= 0) {
	    long long x = (long long)(_PC_ACL_ENABLED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_ACL_ENABLED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_53(void) {
#ifdef _PC_ALLOC_SIZE_MIN
	dump("defined", 1);
	if ((_PC_ALLOC_SIZE_MIN) <= 0) {
	    long long x = (long long)(_PC_ALLOC_SIZE_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_ALLOC_SIZE_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_54(void) {
#ifdef _PC_ASYNC_IO
	dump("defined", 1);
	if ((_PC_ASYNC_IO) <= 0) {
	    long long x = (long long)(_PC_ASYNC_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_ASYNC_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_55(void) {
#ifdef _PC_CHOWN_RESTRICTED
	dump("defined", 1);
	if ((_PC_CHOWN_RESTRICTED) <= 0) {
	    long long x = (long long)(_PC_CHOWN_RESTRICTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_CHOWN_RESTRICTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_56(void) {
#ifdef _PC_FILESIZEBITS
	dump("defined", 1);
	if ((_PC_FILESIZEBITS) <= 0) {
	    long long x = (long long)(_PC_FILESIZEBITS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_FILESIZEBITS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_57(void) {
#ifdef _PC_LAST
	dump("defined", 1);
	if ((_PC_LAST) <= 0) {
	    long long x = (long long)(_PC_LAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_LAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_58(void) {
#ifdef _PC_LINK_MAX
	dump("defined", 1);
	if ((_PC_LINK_MAX) <= 0) {
	    long long x = (long long)(_PC_LINK_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_LINK_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_59(void) {
#ifdef _PC_MAX_CANON
	dump("defined", 1);
	if ((_PC_MAX_CANON) <= 0) {
	    long long x = (long long)(_PC_MAX_CANON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_MAX_CANON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_60(void) {
#ifdef _PC_MAX_INPUT
	dump("defined", 1);
	if ((_PC_MAX_INPUT) <= 0) {
	    long long x = (long long)(_PC_MAX_INPUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_MAX_INPUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_61(void) {
#ifdef _PC_MIN_HOLE_SIZE
	dump("defined", 1);
	if ((_PC_MIN_HOLE_SIZE) <= 0) {
	    long long x = (long long)(_PC_MIN_HOLE_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_MIN_HOLE_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_62(void) {
#ifdef _PC_NAME_MAX
	dump("defined", 1);
	if ((_PC_NAME_MAX) <= 0) {
	    long long x = (long long)(_PC_NAME_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_NAME_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_63(void) {
#ifdef _PC_NO_TRUNC
	dump("defined", 1);
	if ((_PC_NO_TRUNC) <= 0) {
	    long long x = (long long)(_PC_NO_TRUNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_NO_TRUNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_64(void) {
#ifdef _PC_PATH_MAX
	dump("defined", 1);
	if ((_PC_PATH_MAX) <= 0) {
	    long long x = (long long)(_PC_PATH_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_PATH_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_65(void) {
#ifdef _PC_PIPE_BUF
	dump("defined", 1);
	if ((_PC_PIPE_BUF) <= 0) {
	    long long x = (long long)(_PC_PIPE_BUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_PIPE_BUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_66(void) {
#ifdef _PC_PRIO_IO
	dump("defined", 1);
	if ((_PC_PRIO_IO) <= 0) {
	    long long x = (long long)(_PC_PRIO_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_PRIO_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_67(void) {
#ifdef _PC_REC_INCR_XFER_SIZE
	dump("defined", 1);
	if ((_PC_REC_INCR_XFER_SIZE) <= 0) {
	    long long x = (long long)(_PC_REC_INCR_XFER_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_REC_INCR_XFER_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_68(void) {
#ifdef _PC_REC_MAX_XFER_SIZE
	dump("defined", 1);
	if ((_PC_REC_MAX_XFER_SIZE) <= 0) {
	    long long x = (long long)(_PC_REC_MAX_XFER_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_REC_MAX_XFER_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_69(void) {
#ifdef _PC_REC_MIN_XFER_SIZE
	dump("defined", 1);
	if ((_PC_REC_MIN_XFER_SIZE) <= 0) {
	    long long x = (long long)(_PC_REC_MIN_XFER_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_REC_MIN_XFER_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_70(void) {
#ifdef _PC_REC_XFER_ALIGN
	dump("defined", 1);
	if ((_PC_REC_XFER_ALIGN) <= 0) {
	    long long x = (long long)(_PC_REC_XFER_ALIGN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_REC_XFER_ALIGN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_71(void) {
#ifdef _PC_SOCK_MAXBUF
	dump("defined", 1);
	if ((_PC_SOCK_MAXBUF) <= 0) {
	    long long x = (long long)(_PC_SOCK_MAXBUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_SOCK_MAXBUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_72(void) {
#ifdef _PC_SYMLINK_MAX
	dump("defined", 1);
	if ((_PC_SYMLINK_MAX) <= 0) {
	    long long x = (long long)(_PC_SYMLINK_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_SYMLINK_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_73(void) {
#ifdef _PC_SYNC_IO
	dump("defined", 1);
	if ((_PC_SYNC_IO) <= 0) {
	    long long x = (long long)(_PC_SYNC_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_SYNC_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_74(void) {
#ifdef _PC_TIMESTAMP_RESOLUTION
	dump("defined", 1);
	if ((_PC_TIMESTAMP_RESOLUTION) <= 0) {
	    long long x = (long long)(_PC_TIMESTAMP_RESOLUTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_TIMESTAMP_RESOLUTION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_75(void) {
#ifdef _PC_VDISABLE
	dump("defined", 1);
	if ((_PC_VDISABLE) <= 0) {
	    long long x = (long long)(_PC_VDISABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_VDISABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_76(void) {
#ifdef _PC_XATTR_ENABLED
	dump("defined", 1);
	if ((_PC_XATTR_ENABLED) <= 0) {
	    long long x = (long long)(_PC_XATTR_ENABLED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_XATTR_ENABLED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_77(void) {
#ifdef _PC_XATTR_EXISTS
	dump("defined", 1);
	if ((_PC_XATTR_EXISTS) <= 0) {
	    long long x = (long long)(_PC_XATTR_EXISTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_PC_XATTR_EXISTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_78(void) {
#ifdef _SC_2_CHAR_TERM
	dump("defined", 1);
	if ((_SC_2_CHAR_TERM) <= 0) {
	    long long x = (long long)(_SC_2_CHAR_TERM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_CHAR_TERM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_79(void) {
#ifdef _SC_2_C_BIND
	dump("defined", 1);
	if ((_SC_2_C_BIND) <= 0) {
	    long long x = (long long)(_SC_2_C_BIND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_C_BIND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_80(void) {
#ifdef _SC_2_C_DEV
	dump("defined", 1);
	if ((_SC_2_C_DEV) <= 0) {
	    long long x = (long long)(_SC_2_C_DEV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_C_DEV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_81(void) {
#ifdef _SC_2_C_VERSION
	dump("defined", 1);
	if ((_SC_2_C_VERSION) <= 0) {
	    long long x = (long long)(_SC_2_C_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_C_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_82(void) {
#ifdef _SC_2_FORT_DEV
	dump("defined", 1);
	if ((_SC_2_FORT_DEV) <= 0) {
	    long long x = (long long)(_SC_2_FORT_DEV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_FORT_DEV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_83(void) {
#ifdef _SC_2_FORT_RUN
	dump("defined", 1);
	if ((_SC_2_FORT_RUN) <= 0) {
	    long long x = (long long)(_SC_2_FORT_RUN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_FORT_RUN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_84(void) {
#ifdef _SC_2_LOCALEDEF
	dump("defined", 1);
	if ((_SC_2_LOCALEDEF) <= 0) {
	    long long x = (long long)(_SC_2_LOCALEDEF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_LOCALEDEF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_85(void) {
#ifdef _SC_2_SW_DEV
	dump("defined", 1);
	if ((_SC_2_SW_DEV) <= 0) {
	    long long x = (long long)(_SC_2_SW_DEV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_SW_DEV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_86(void) {
#ifdef _SC_2_UPE
	dump("defined", 1);
	if ((_SC_2_UPE) <= 0) {
	    long long x = (long long)(_SC_2_UPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_UPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_87(void) {
#ifdef _SC_2_VERSION
	dump("defined", 1);
	if ((_SC_2_VERSION) <= 0) {
	    long long x = (long long)(_SC_2_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_2_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_88(void) {
#ifdef _SC_ABI_ASYNCHRONOUS_IO
	dump("defined", 1);
	if ((_SC_ABI_ASYNCHRONOUS_IO) <= 0) {
	    long long x = (long long)(_SC_ABI_ASYNCHRONOUS_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ABI_ASYNCHRONOUS_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_89(void) {
#ifdef _SC_ACL
	dump("defined", 1);
	if ((_SC_ACL) <= 0) {
	    long long x = (long long)(_SC_ACL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ACL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_90(void) {
#ifdef _SC_AIO_LISTIO_MAX
	dump("defined", 1);
	if ((_SC_AIO_LISTIO_MAX) <= 0) {
	    long long x = (long long)(_SC_AIO_LISTIO_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_AIO_LISTIO_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_91(void) {
#ifdef _SC_AIO_MAX
	dump("defined", 1);
	if ((_SC_AIO_MAX) <= 0) {
	    long long x = (long long)(_SC_AIO_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_AIO_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_92(void) {
#ifdef _SC_AIO_PRIO_DELTA_MAX
	dump("defined", 1);
	if ((_SC_AIO_PRIO_DELTA_MAX) <= 0) {
	    long long x = (long long)(_SC_AIO_PRIO_DELTA_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_AIO_PRIO_DELTA_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_93(void) {
#ifdef _SC_ARG_MAX
	dump("defined", 1);
	if ((_SC_ARG_MAX) <= 0) {
	    long long x = (long long)(_SC_ARG_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ARG_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_94(void) {
#ifdef _SC_ASYNCHRONOUS_IO
	dump("defined", 1);
	if ((_SC_ASYNCHRONOUS_IO) <= 0) {
	    long long x = (long long)(_SC_ASYNCHRONOUS_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ASYNCHRONOUS_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_95(void) {
#ifdef _SC_ATEXIT_MAX
	dump("defined", 1);
	if ((_SC_ATEXIT_MAX) <= 0) {
	    long long x = (long long)(_SC_ATEXIT_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ATEXIT_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_96(void) {
#ifdef _SC_AUDIT
	dump("defined", 1);
	if ((_SC_AUDIT) <= 0) {
	    long long x = (long long)(_SC_AUDIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_AUDIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_97(void) {
#ifdef _SC_AVPHYS_PAGES
	dump("defined", 1);
	if ((_SC_AVPHYS_PAGES) <= 0) {
	    long long x = (long long)(_SC_AVPHYS_PAGES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_AVPHYS_PAGES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_98(void) {
#ifdef _SC_BC_BASE_MAX
	dump("defined", 1);
	if ((_SC_BC_BASE_MAX) <= 0) {
	    long long x = (long long)(_SC_BC_BASE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_BC_BASE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_99(void) {
#ifdef _SC_BC_DIM_MAX
	dump("defined", 1);
	if ((_SC_BC_DIM_MAX) <= 0) {
	    long long x = (long long)(_SC_BC_DIM_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_BC_DIM_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_100(void) {
#ifdef _SC_BC_SCALE_MAX
	dump("defined", 1);
	if ((_SC_BC_SCALE_MAX) <= 0) {
	    long long x = (long long)(_SC_BC_SCALE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_BC_SCALE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_101(void) {
#ifdef _SC_BC_STRING_MAX
	dump("defined", 1);
	if ((_SC_BC_STRING_MAX) <= 0) {
	    long long x = (long long)(_SC_BC_STRING_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_BC_STRING_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_102(void) {
#ifdef _SC_CAP
	dump("defined", 1);
	if ((_SC_CAP) <= 0) {
	    long long x = (long long)(_SC_CAP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CAP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_103(void) {
#ifdef _SC_CHARCLASS_NAME_MAX
	dump("defined", 1);
	if ((_SC_CHARCLASS_NAME_MAX) <= 0) {
	    long long x = (long long)(_SC_CHARCLASS_NAME_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CHARCLASS_NAME_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_104(void) {
#ifdef _SC_CHAR_BIT
	dump("defined", 1);
	if ((_SC_CHAR_BIT) <= 0) {
	    long long x = (long long)(_SC_CHAR_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CHAR_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_105(void) {
#ifdef _SC_CHAR_MAX
	dump("defined", 1);
	if ((_SC_CHAR_MAX) <= 0) {
	    long long x = (long long)(_SC_CHAR_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CHAR_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_106(void) {
#ifdef _SC_CHAR_MIN
	dump("defined", 1);
	if ((_SC_CHAR_MIN) <= 0) {
	    long long x = (long long)(_SC_CHAR_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CHAR_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_107(void) {
#ifdef _SC_CHILD_MAX
	dump("defined", 1);
	if ((_SC_CHILD_MAX) <= 0) {
	    long long x = (long long)(_SC_CHILD_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CHILD_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_108(void) {
#ifdef _SC_CLK_TCK
	dump("defined", 1);
	if ((_SC_CLK_TCK) <= 0) {
	    long long x = (long long)(_SC_CLK_TCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_CLK_TCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_109(void) {
#ifdef _SC_COHER_BLKSZ
	dump("defined", 1);
	if ((_SC_COHER_BLKSZ) <= 0) {
	    long long x = (long long)(_SC_COHER_BLKSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_COHER_BLKSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_110(void) {
#ifdef _SC_COLL_WEIGHTS_MAX
	dump("defined", 1);
	if ((_SC_COLL_WEIGHTS_MAX) <= 0) {
	    long long x = (long long)(_SC_COLL_WEIGHTS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_COLL_WEIGHTS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_111(void) {
#ifdef _SC_DCACHE_ASSOC
	dump("defined", 1);
	if ((_SC_DCACHE_ASSOC) <= 0) {
	    long long x = (long long)(_SC_DCACHE_ASSOC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_DCACHE_ASSOC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_112(void) {
#ifdef _SC_DCACHE_BLKSZ
	dump("defined", 1);
	if ((_SC_DCACHE_BLKSZ) <= 0) {
	    long long x = (long long)(_SC_DCACHE_BLKSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_DCACHE_BLKSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_113(void) {
#ifdef _SC_DCACHE_LINESZ
	dump("defined", 1);
	if ((_SC_DCACHE_LINESZ) <= 0) {
	    long long x = (long long)(_SC_DCACHE_LINESZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_DCACHE_LINESZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_114(void) {
#ifdef _SC_DCACHE_SZ
	dump("defined", 1);
	if ((_SC_DCACHE_SZ) <= 0) {
	    long long x = (long long)(_SC_DCACHE_SZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_DCACHE_SZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_115(void) {
#ifdef _SC_DCACHE_TBLKSZ
	dump("defined", 1);
	if ((_SC_DCACHE_TBLKSZ) <= 0) {
	    long long x = (long long)(_SC_DCACHE_TBLKSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_DCACHE_TBLKSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_116(void) {
#ifdef _SC_DELAYTIMER_MAX
	dump("defined", 1);
	if ((_SC_DELAYTIMER_MAX) <= 0) {
	    long long x = (long long)(_SC_DELAYTIMER_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_DELAYTIMER_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_117(void) {
#ifdef _SC_EQUIV_CLASS_MAX
	dump("defined", 1);
	if ((_SC_EQUIV_CLASS_MAX) <= 0) {
	    long long x = (long long)(_SC_EQUIV_CLASS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_EQUIV_CLASS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_118(void) {
#ifdef _SC_EXPR_NEST_MAX
	dump("defined", 1);
	if ((_SC_EXPR_NEST_MAX) <= 0) {
	    long long x = (long long)(_SC_EXPR_NEST_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_EXPR_NEST_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_119(void) {
#ifdef _SC_FSYNC
	dump("defined", 1);
	if ((_SC_FSYNC) <= 0) {
	    long long x = (long long)(_SC_FSYNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_FSYNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_120(void) {
#ifdef _SC_GETGR_R_SIZE_MAX
	dump("defined", 1);
	if ((_SC_GETGR_R_SIZE_MAX) <= 0) {
	    long long x = (long long)(_SC_GETGR_R_SIZE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_GETGR_R_SIZE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_121(void) {
#ifdef _SC_GETPW_R_SIZE_MAX
	dump("defined", 1);
	if ((_SC_GETPW_R_SIZE_MAX) <= 0) {
	    long long x = (long long)(_SC_GETPW_R_SIZE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_GETPW_R_SIZE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_122(void) {
#ifdef _SC_ICACHE_ASSOC
	dump("defined", 1);
	if ((_SC_ICACHE_ASSOC) <= 0) {
	    long long x = (long long)(_SC_ICACHE_ASSOC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ICACHE_ASSOC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_123(void) {
#ifdef _SC_ICACHE_BLKSZ
	dump("defined", 1);
	if ((_SC_ICACHE_BLKSZ) <= 0) {
	    long long x = (long long)(_SC_ICACHE_BLKSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ICACHE_BLKSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_124(void) {
#ifdef _SC_ICACHE_LINESZ
	dump("defined", 1);
	if ((_SC_ICACHE_LINESZ) <= 0) {
	    long long x = (long long)(_SC_ICACHE_LINESZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ICACHE_LINESZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_125(void) {
#ifdef _SC_ICACHE_SZ
	dump("defined", 1);
	if ((_SC_ICACHE_SZ) <= 0) {
	    long long x = (long long)(_SC_ICACHE_SZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ICACHE_SZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_126(void) {
#ifdef _SC_INF
	dump("defined", 1);
	if ((_SC_INF) <= 0) {
	    long long x = (long long)(_SC_INF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_INF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_127(void) {
#ifdef _SC_INT_MAX
	dump("defined", 1);
	if ((_SC_INT_MAX) <= 0) {
	    long long x = (long long)(_SC_INT_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_INT_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_128(void) {
#ifdef _SC_INT_MIN
	dump("defined", 1);
	if ((_SC_INT_MIN) <= 0) {
	    long long x = (long long)(_SC_INT_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_INT_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_129(void) {
#ifdef _SC_IOV_MAX
	dump("defined", 1);
	if ((_SC_IOV_MAX) <= 0) {
	    long long x = (long long)(_SC_IOV_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_IOV_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_130(void) {
#ifdef _SC_IP_SECOPTS
	dump("defined", 1);
	if ((_SC_IP_SECOPTS) <= 0) {
	    long long x = (long long)(_SC_IP_SECOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_IP_SECOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_131(void) {
#ifdef _SC_JOB_CONTROL
	dump("defined", 1);
	if ((_SC_JOB_CONTROL) <= 0) {
	    long long x = (long long)(_SC_JOB_CONTROL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_JOB_CONTROL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_132(void) {
#ifdef _SC_KERN_POINTERS
	dump("defined", 1);
	if ((_SC_KERN_POINTERS) <= 0) {
	    long long x = (long long)(_SC_KERN_POINTERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_KERN_POINTERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_133(void) {
#ifdef _SC_KERN_SIM
	dump("defined", 1);
	if ((_SC_KERN_SIM) <= 0) {
	    long long x = (long long)(_SC_KERN_SIM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_KERN_SIM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_134(void) {
#ifdef _SC_LINE_MAX
	dump("defined", 1);
	if ((_SC_LINE_MAX) <= 0) {
	    long long x = (long long)(_SC_LINE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_LINE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_135(void) {
#ifdef _SC_LOGIN_NAME_MAX
	dump("defined", 1);
	if ((_SC_LOGIN_NAME_MAX) <= 0) {
	    long long x = (long long)(_SC_LOGIN_NAME_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_LOGIN_NAME_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_136(void) {
#ifdef _SC_LOGNAME_MAX
	dump("defined", 1);
	if ((_SC_LOGNAME_MAX) <= 0) {
	    long long x = (long long)(_SC_LOGNAME_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_LOGNAME_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_137(void) {
#ifdef _SC_LONG_BIT
	dump("defined", 1);
	if ((_SC_LONG_BIT) <= 0) {
	    long long x = (long long)(_SC_LONG_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_LONG_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_138(void) {
#ifdef _SC_MAC
	dump("defined", 1);
	if ((_SC_MAC) <= 0) {
	    long long x = (long long)(_SC_MAC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MAC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_139(void) {
#ifdef _SC_MAPPED_FILES
	dump("defined", 1);
	if ((_SC_MAPPED_FILES) <= 0) {
	    long long x = (long long)(_SC_MAPPED_FILES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MAPPED_FILES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_140(void) {
#ifdef _SC_MAXPID
	dump("defined", 1);
	if ((_SC_MAXPID) <= 0) {
	    long long x = (long long)(_SC_MAXPID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MAXPID);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_141(void) {
#ifdef _SC_MB_LEN_MAX
	dump("defined", 1);
	if ((_SC_MB_LEN_MAX) <= 0) {
	    long long x = (long long)(_SC_MB_LEN_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MB_LEN_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_142(void) {
#ifdef _SC_MEMLOCK
	dump("defined", 1);
	if ((_SC_MEMLOCK) <= 0) {
	    long long x = (long long)(_SC_MEMLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MEMLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_143(void) {
#ifdef _SC_MEMLOCK_RANGE
	dump("defined", 1);
	if ((_SC_MEMLOCK_RANGE) <= 0) {
	    long long x = (long long)(_SC_MEMLOCK_RANGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MEMLOCK_RANGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_144(void) {
#ifdef _SC_MEMORY_PROTECTION
	dump("defined", 1);
	if ((_SC_MEMORY_PROTECTION) <= 0) {
	    long long x = (long long)(_SC_MEMORY_PROTECTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MEMORY_PROTECTION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_145(void) {
#ifdef _SC_MESSAGE_PASSING
	dump("defined", 1);
	if ((_SC_MESSAGE_PASSING) <= 0) {
	    long long x = (long long)(_SC_MESSAGE_PASSING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MESSAGE_PASSING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_146(void) {
#ifdef _SC_MMAP_FIXED_ALIGNMENT
	dump("defined", 1);
	if ((_SC_MMAP_FIXED_ALIGNMENT) <= 0) {
	    long long x = (long long)(_SC_MMAP_FIXED_ALIGNMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MMAP_FIXED_ALIGNMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_147(void) {
#ifdef _SC_MQ_OPEN_MAX
	dump("defined", 1);
	if ((_SC_MQ_OPEN_MAX) <= 0) {
	    long long x = (long long)(_SC_MQ_OPEN_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MQ_OPEN_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_148(void) {
#ifdef _SC_MQ_PRIO_MAX
	dump("defined", 1);
	if ((_SC_MQ_PRIO_MAX) <= 0) {
	    long long x = (long long)(_SC_MQ_PRIO_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_MQ_PRIO_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_149(void) {
#ifdef _SC_NACLS_MAX
	dump("defined", 1);
	if ((_SC_NACLS_MAX) <= 0) {
	    long long x = (long long)(_SC_NACLS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NACLS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_150(void) {
#ifdef _SC_NGROUPS_MAX
	dump("defined", 1);
	if ((_SC_NGROUPS_MAX) <= 0) {
	    long long x = (long long)(_SC_NGROUPS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NGROUPS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_151(void) {
#ifdef _SC_NL_ARGMAX
	dump("defined", 1);
	if ((_SC_NL_ARGMAX) <= 0) {
	    long long x = (long long)(_SC_NL_ARGMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NL_ARGMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_152(void) {
#ifdef _SC_NL_LANGMAX
	dump("defined", 1);
	if ((_SC_NL_LANGMAX) <= 0) {
	    long long x = (long long)(_SC_NL_LANGMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NL_LANGMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_153(void) {
#ifdef _SC_NL_MSGMAX
	dump("defined", 1);
	if ((_SC_NL_MSGMAX) <= 0) {
	    long long x = (long long)(_SC_NL_MSGMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NL_MSGMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_154(void) {
#ifdef _SC_NL_NMAX
	dump("defined", 1);
	if ((_SC_NL_NMAX) <= 0) {
	    long long x = (long long)(_SC_NL_NMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NL_NMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_155(void) {
#ifdef _SC_NL_SETMAX
	dump("defined", 1);
	if ((_SC_NL_SETMAX) <= 0) {
	    long long x = (long long)(_SC_NL_SETMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NL_SETMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_156(void) {
#ifdef _SC_NL_TEXTMAX
	dump("defined", 1);
	if ((_SC_NL_TEXTMAX) <= 0) {
	    long long x = (long long)(_SC_NL_TEXTMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NL_TEXTMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_157(void) {
#ifdef _SC_NPROCESSORS_CONF
	dump("defined", 1);
	if ((_SC_NPROCESSORS_CONF) <= 0) {
	    long long x = (long long)(_SC_NPROCESSORS_CONF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NPROCESSORS_CONF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_158(void) {
#ifdef _SC_NPROCESSORS_ONLN
	dump("defined", 1);
	if ((_SC_NPROCESSORS_ONLN) <= 0) {
	    long long x = (long long)(_SC_NPROCESSORS_ONLN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NPROCESSORS_ONLN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_159(void) {
#ifdef _SC_NPROC_CONF
	dump("defined", 1);
	if ((_SC_NPROC_CONF) <= 0) {
	    long long x = (long long)(_SC_NPROC_CONF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NPROC_CONF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_160(void) {
#ifdef _SC_NPROC_ONLN
	dump("defined", 1);
	if ((_SC_NPROC_ONLN) <= 0) {
	    long long x = (long long)(_SC_NPROC_ONLN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NPROC_ONLN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_161(void) {
#ifdef _SC_NZERO
	dump("defined", 1);
	if ((_SC_NZERO) <= 0) {
	    long long x = (long long)(_SC_NZERO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_NZERO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_162(void) {
#ifdef _SC_OPEN_MAX
	dump("defined", 1);
	if ((_SC_OPEN_MAX) <= 0) {
	    long long x = (long long)(_SC_OPEN_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_OPEN_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_163(void) {
#ifdef _SC_PAGESIZE
	dump("defined", 1);
	if ((_SC_PAGESIZE) <= 0) {
	    long long x = (long long)(_SC_PAGESIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PAGESIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_164(void) {
#ifdef _SC_PAGE_SIZE
	dump("defined", 1);
	if ((_SC_PAGE_SIZE) <= 0) {
	    long long x = (long long)(_SC_PAGE_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PAGE_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_165(void) {
#ifdef _SC_PASS_MAX
	dump("defined", 1);
	if ((_SC_PASS_MAX) <= 0) {
	    long long x = (long long)(_SC_PASS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PASS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_166(void) {
#ifdef _SC_PHYS_PAGES
	dump("defined", 1);
	if ((_SC_PHYS_PAGES) <= 0) {
	    long long x = (long long)(_SC_PHYS_PAGES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PHYS_PAGES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_167(void) {
#ifdef _SC_PII
	dump("defined", 1);
	if ((_SC_PII) <= 0) {
	    long long x = (long long)(_SC_PII);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_168(void) {
#ifdef _SC_PII_INTERNET
	dump("defined", 1);
	if ((_SC_PII_INTERNET) <= 0) {
	    long long x = (long long)(_SC_PII_INTERNET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_INTERNET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_169(void) {
#ifdef _SC_PII_INTERNET_DGRAM
	dump("defined", 1);
	if ((_SC_PII_INTERNET_DGRAM) <= 0) {
	    long long x = (long long)(_SC_PII_INTERNET_DGRAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_INTERNET_DGRAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_170(void) {
#ifdef _SC_PII_INTERNET_STREAM
	dump("defined", 1);
	if ((_SC_PII_INTERNET_STREAM) <= 0) {
	    long long x = (long long)(_SC_PII_INTERNET_STREAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_INTERNET_STREAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_171(void) {
#ifdef _SC_PII_OSI
	dump("defined", 1);
	if ((_SC_PII_OSI) <= 0) {
	    long long x = (long long)(_SC_PII_OSI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_OSI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_172(void) {
#ifdef _SC_PII_OSI_CLTS
	dump("defined", 1);
	if ((_SC_PII_OSI_CLTS) <= 0) {
	    long long x = (long long)(_SC_PII_OSI_CLTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_OSI_CLTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_173(void) {
#ifdef _SC_PII_OSI_COTS
	dump("defined", 1);
	if ((_SC_PII_OSI_COTS) <= 0) {
	    long long x = (long long)(_SC_PII_OSI_COTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_OSI_COTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_174(void) {
#ifdef _SC_PII_OSI_M
	dump("defined", 1);
	if ((_SC_PII_OSI_M) <= 0) {
	    long long x = (long long)(_SC_PII_OSI_M);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_OSI_M);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_175(void) {
#ifdef _SC_PII_SOCKET
	dump("defined", 1);
	if ((_SC_PII_SOCKET) <= 0) {
	    long long x = (long long)(_SC_PII_SOCKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_SOCKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_176(void) {
#ifdef _SC_PII_XTI
	dump("defined", 1);
	if ((_SC_PII_XTI) <= 0) {
	    long long x = (long long)(_SC_PII_XTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PII_XTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_177(void) {
#ifdef _SC_POLL
	dump("defined", 1);
	if ((_SC_POLL) <= 0) {
	    long long x = (long long)(_SC_POLL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_POLL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_178(void) {
#ifdef _SC_PRIORITIZED_IO
	dump("defined", 1);
	if ((_SC_PRIORITIZED_IO) <= 0) {
	    long long x = (long long)(_SC_PRIORITIZED_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PRIORITIZED_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_179(void) {
#ifdef _SC_PRIORITY_SCHEDULING
	dump("defined", 1);
	if ((_SC_PRIORITY_SCHEDULING) <= 0) {
	    long long x = (long long)(_SC_PRIORITY_SCHEDULING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_PRIORITY_SCHEDULING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_180(void) {
#ifdef _SC_REALTIME_SIGNALS
	dump("defined", 1);
	if ((_SC_REALTIME_SIGNALS) <= 0) {
	    long long x = (long long)(_SC_REALTIME_SIGNALS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_REALTIME_SIGNALS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_181(void) {
#ifdef _SC_RE_DUP_MAX
	dump("defined", 1);
	if ((_SC_RE_DUP_MAX) <= 0) {
	    long long x = (long long)(_SC_RE_DUP_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_RE_DUP_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_182(void) {
#ifdef _SC_RTSIG_MAX
	dump("defined", 1);
	if ((_SC_RTSIG_MAX) <= 0) {
	    long long x = (long long)(_SC_RTSIG_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_RTSIG_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_183(void) {
#ifdef _SC_SAVED_IDS
	dump("defined", 1);
	if ((_SC_SAVED_IDS) <= 0) {
	    long long x = (long long)(_SC_SAVED_IDS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SAVED_IDS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_184(void) {
#ifdef _SC_SCHAR_MAX
	dump("defined", 1);
	if ((_SC_SCHAR_MAX) <= 0) {
	    long long x = (long long)(_SC_SCHAR_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SCHAR_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_185(void) {
#ifdef _SC_SCHAR_MIN
	dump("defined", 1);
	if ((_SC_SCHAR_MIN) <= 0) {
	    long long x = (long long)(_SC_SCHAR_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SCHAR_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_186(void) {
#ifdef _SC_SELECT
	dump("defined", 1);
	if ((_SC_SELECT) <= 0) {
	    long long x = (long long)(_SC_SELECT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SELECT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_187(void) {
#ifdef _SC_SEMAPHORES
	dump("defined", 1);
	if ((_SC_SEMAPHORES) <= 0) {
	    long long x = (long long)(_SC_SEMAPHORES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SEMAPHORES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_188(void) {
#ifdef _SC_SEM_NSEMS_MAX
	dump("defined", 1);
	if ((_SC_SEM_NSEMS_MAX) <= 0) {
	    long long x = (long long)(_SC_SEM_NSEMS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SEM_NSEMS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_189(void) {
#ifdef _SC_SEM_VALUE_MAX
	dump("defined", 1);
	if ((_SC_SEM_VALUE_MAX) <= 0) {
	    long long x = (long long)(_SC_SEM_VALUE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SEM_VALUE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_190(void) {
#ifdef _SC_SHARED_MEMORY_OBJECTS
	dump("defined", 1);
	if ((_SC_SHARED_MEMORY_OBJECTS) <= 0) {
	    long long x = (long long)(_SC_SHARED_MEMORY_OBJECTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SHARED_MEMORY_OBJECTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_191(void) {
#ifdef _SC_SHRT_MAX
	dump("defined", 1);
	if ((_SC_SHRT_MAX) <= 0) {
	    long long x = (long long)(_SC_SHRT_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SHRT_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_192(void) {
#ifdef _SC_SHRT_MIN
	dump("defined", 1);
	if ((_SC_SHRT_MIN) <= 0) {
	    long long x = (long long)(_SC_SHRT_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SHRT_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_193(void) {
#ifdef _SC_SIGQUEUE_MAX
	dump("defined", 1);
	if ((_SC_SIGQUEUE_MAX) <= 0) {
	    long long x = (long long)(_SC_SIGQUEUE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SIGQUEUE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_194(void) {
#ifdef _SC_SIGRT_MAX
	dump("defined", 1);
	if ((_SC_SIGRT_MAX) <= 0) {
	    long long x = (long long)(_SC_SIGRT_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SIGRT_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_195(void) {
#ifdef _SC_SIGRT_MIN
	dump("defined", 1);
	if ((_SC_SIGRT_MIN) <= 0) {
	    long long x = (long long)(_SC_SIGRT_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SIGRT_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_196(void) {
#ifdef _SC_SOFTPOWER
	dump("defined", 1);
	if ((_SC_SOFTPOWER) <= 0) {
	    long long x = (long long)(_SC_SOFTPOWER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SOFTPOWER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_197(void) {
#ifdef _SC_SPLIT_CACHE
	dump("defined", 1);
	if ((_SC_SPLIT_CACHE) <= 0) {
	    long long x = (long long)(_SC_SPLIT_CACHE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SPLIT_CACHE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_198(void) {
#ifdef _SC_SSIZE_MAX
	dump("defined", 1);
	if ((_SC_SSIZE_MAX) <= 0) {
	    long long x = (long long)(_SC_SSIZE_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SSIZE_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_199(void) {
#ifdef _SC_STACK_PROT
	dump("defined", 1);
	if ((_SC_STACK_PROT) <= 0) {
	    long long x = (long long)(_SC_STACK_PROT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_STACK_PROT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_200(void) {
#ifdef _SC_STREAM_MAX
	dump("defined", 1);
	if ((_SC_STREAM_MAX) <= 0) {
	    long long x = (long long)(_SC_STREAM_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_STREAM_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_201(void) {
#ifdef _SC_SYNCHRONIZED_IO
	dump("defined", 1);
	if ((_SC_SYNCHRONIZED_IO) <= 0) {
	    long long x = (long long)(_SC_SYNCHRONIZED_IO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_SYNCHRONIZED_IO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_202(void) {
#ifdef _SC_THREADS
	dump("defined", 1);
	if ((_SC_THREADS) <= 0) {
	    long long x = (long long)(_SC_THREADS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREADS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_203(void) {
#ifdef _SC_THREAD_ATTR_STACKADDR
	dump("defined", 1);
	if ((_SC_THREAD_ATTR_STACKADDR) <= 0) {
	    long long x = (long long)(_SC_THREAD_ATTR_STACKADDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_ATTR_STACKADDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_204(void) {
#ifdef _SC_THREAD_ATTR_STACKSIZE
	dump("defined", 1);
	if ((_SC_THREAD_ATTR_STACKSIZE) <= 0) {
	    long long x = (long long)(_SC_THREAD_ATTR_STACKSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_ATTR_STACKSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_205(void) {
#ifdef _SC_THREAD_DESTRUCTOR_ITERATIONS
	dump("defined", 1);
	if ((_SC_THREAD_DESTRUCTOR_ITERATIONS) <= 0) {
	    long long x = (long long)(_SC_THREAD_DESTRUCTOR_ITERATIONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_DESTRUCTOR_ITERATIONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_206(void) {
#ifdef _SC_THREAD_KEYS_MAX
	dump("defined", 1);
	if ((_SC_THREAD_KEYS_MAX) <= 0) {
	    long long x = (long long)(_SC_THREAD_KEYS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_KEYS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_207(void) {
#ifdef _SC_THREAD_PRIORITY_SCHEDULING
	dump("defined", 1);
	if ((_SC_THREAD_PRIORITY_SCHEDULING) <= 0) {
	    long long x = (long long)(_SC_THREAD_PRIORITY_SCHEDULING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_PRIORITY_SCHEDULING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_208(void) {
#ifdef _SC_THREAD_PRIO_INHERIT
	dump("defined", 1);
	if ((_SC_THREAD_PRIO_INHERIT) <= 0) {
	    long long x = (long long)(_SC_THREAD_PRIO_INHERIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_PRIO_INHERIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_209(void) {
#ifdef _SC_THREAD_PRIO_PROTECT
	dump("defined", 1);
	if ((_SC_THREAD_PRIO_PROTECT) <= 0) {
	    long long x = (long long)(_SC_THREAD_PRIO_PROTECT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_PRIO_PROTECT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_210(void) {
#ifdef _SC_THREAD_PROCESS_SHARED
	dump("defined", 1);
	if ((_SC_THREAD_PROCESS_SHARED) <= 0) {
	    long long x = (long long)(_SC_THREAD_PROCESS_SHARED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_PROCESS_SHARED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_211(void) {
#ifdef _SC_THREAD_SAFE_FUNCTIONS
	dump("defined", 1);
	if ((_SC_THREAD_SAFE_FUNCTIONS) <= 0) {
	    long long x = (long long)(_SC_THREAD_SAFE_FUNCTIONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_SAFE_FUNCTIONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_212(void) {
#ifdef _SC_THREAD_STACK_MIN
	dump("defined", 1);
	if ((_SC_THREAD_STACK_MIN) <= 0) {
	    long long x = (long long)(_SC_THREAD_STACK_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_STACK_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_213(void) {
#ifdef _SC_THREAD_THREADS_MAX
	dump("defined", 1);
	if ((_SC_THREAD_THREADS_MAX) <= 0) {
	    long long x = (long long)(_SC_THREAD_THREADS_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_THREAD_THREADS_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_214(void) {
#ifdef _SC_TIMERS
	dump("defined", 1);
	if ((_SC_TIMERS) <= 0) {
	    long long x = (long long)(_SC_TIMERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_TIMERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_215(void) {
#ifdef _SC_TIMER_MAX
	dump("defined", 1);
	if ((_SC_TIMER_MAX) <= 0) {
	    long long x = (long long)(_SC_TIMER_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_TIMER_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_216(void) {
#ifdef _SC_TTY_NAME_MAX
	dump("defined", 1);
	if ((_SC_TTY_NAME_MAX) <= 0) {
	    long long x = (long long)(_SC_TTY_NAME_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_TTY_NAME_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_217(void) {
#ifdef _SC_TZNAME_MAX
	dump("defined", 1);
	if ((_SC_TZNAME_MAX) <= 0) {
	    long long x = (long long)(_SC_TZNAME_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_TZNAME_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_218(void) {
#ifdef _SC_T_IOV_MAX
	dump("defined", 1);
	if ((_SC_T_IOV_MAX) <= 0) {
	    long long x = (long long)(_SC_T_IOV_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_T_IOV_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_219(void) {
#ifdef _SC_UCHAR_MAX
	dump("defined", 1);
	if ((_SC_UCHAR_MAX) <= 0) {
	    long long x = (long long)(_SC_UCHAR_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_UCHAR_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_220(void) {
#ifdef _SC_UINT_MAX
	dump("defined", 1);
	if ((_SC_UINT_MAX) <= 0) {
	    long long x = (long long)(_SC_UINT_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_UINT_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_221(void) {
#ifdef _SC_UIO_MAXIOV
	dump("defined", 1);
	if ((_SC_UIO_MAXIOV) <= 0) {
	    long long x = (long long)(_SC_UIO_MAXIOV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_UIO_MAXIOV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_222(void) {
#ifdef _SC_ULONG_MAX
	dump("defined", 1);
	if ((_SC_ULONG_MAX) <= 0) {
	    long long x = (long long)(_SC_ULONG_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_ULONG_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_223(void) {
#ifdef _SC_USHRT_MAX
	dump("defined", 1);
	if ((_SC_USHRT_MAX) <= 0) {
	    long long x = (long long)(_SC_USHRT_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_USHRT_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_224(void) {
#ifdef _SC_VERSION
	dump("defined", 1);
	if ((_SC_VERSION) <= 0) {
	    long long x = (long long)(_SC_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_225(void) {
#ifdef _SC_WORD_BIT
	dump("defined", 1);
	if ((_SC_WORD_BIT) <= 0) {
	    long long x = (long long)(_SC_WORD_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_WORD_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_226(void) {
#ifdef _SC_XBS5_ILP32_OFF32
	dump("defined", 1);
	if ((_SC_XBS5_ILP32_OFF32) <= 0) {
	    long long x = (long long)(_SC_XBS5_ILP32_OFF32);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XBS5_ILP32_OFF32);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_227(void) {
#ifdef _SC_XBS5_ILP32_OFFBIG
	dump("defined", 1);
	if ((_SC_XBS5_ILP32_OFFBIG) <= 0) {
	    long long x = (long long)(_SC_XBS5_ILP32_OFFBIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XBS5_ILP32_OFFBIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_228(void) {
#ifdef _SC_XBS5_LP64_OFF64
	dump("defined", 1);
	if ((_SC_XBS5_LP64_OFF64) <= 0) {
	    long long x = (long long)(_SC_XBS5_LP64_OFF64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XBS5_LP64_OFF64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_229(void) {
#ifdef _SC_XBS5_LPBIG_OFFBIG
	dump("defined", 1);
	if ((_SC_XBS5_LPBIG_OFFBIG) <= 0) {
	    long long x = (long long)(_SC_XBS5_LPBIG_OFFBIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XBS5_LPBIG_OFFBIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_230(void) {
#ifdef _SC_XOPEN_CRYPT
	dump("defined", 1);
	if ((_SC_XOPEN_CRYPT) <= 0) {
	    long long x = (long long)(_SC_XOPEN_CRYPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_CRYPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_231(void) {
#ifdef _SC_XOPEN_ENH_I18N
	dump("defined", 1);
	if ((_SC_XOPEN_ENH_I18N) <= 0) {
	    long long x = (long long)(_SC_XOPEN_ENH_I18N);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_ENH_I18N);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_232(void) {
#ifdef _SC_XOPEN_LEGACY
	dump("defined", 1);
	if ((_SC_XOPEN_LEGACY) <= 0) {
	    long long x = (long long)(_SC_XOPEN_LEGACY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_LEGACY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_233(void) {
#ifdef _SC_XOPEN_REALTIME
	dump("defined", 1);
	if ((_SC_XOPEN_REALTIME) <= 0) {
	    long long x = (long long)(_SC_XOPEN_REALTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_REALTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_234(void) {
#ifdef _SC_XOPEN_REALTIME_THREADS
	dump("defined", 1);
	if ((_SC_XOPEN_REALTIME_THREADS) <= 0) {
	    long long x = (long long)(_SC_XOPEN_REALTIME_THREADS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_REALTIME_THREADS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_235(void) {
#ifdef _SC_XOPEN_SHM
	dump("defined", 1);
	if ((_SC_XOPEN_SHM) <= 0) {
	    long long x = (long long)(_SC_XOPEN_SHM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_SHM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_236(void) {
#ifdef _SC_XOPEN_UNIX
	dump("defined", 1);
	if ((_SC_XOPEN_UNIX) <= 0) {
	    long long x = (long long)(_SC_XOPEN_UNIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_UNIX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_237(void) {
#ifdef _SC_XOPEN_VERSION
	dump("defined", 1);
	if ((_SC_XOPEN_VERSION) <= 0) {
	    long long x = (long long)(_SC_XOPEN_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_238(void) {
#ifdef _SC_XOPEN_XCU_VERSION
	dump("defined", 1);
	if ((_SC_XOPEN_XCU_VERSION) <= 0) {
	    long long x = (long long)(_SC_XOPEN_XCU_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_XCU_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_239(void) {
#ifdef _SC_XOPEN_XPG2
	dump("defined", 1);
	if ((_SC_XOPEN_XPG2) <= 0) {
	    long long x = (long long)(_SC_XOPEN_XPG2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_XPG2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_240(void) {
#ifdef _SC_XOPEN_XPG3
	dump("defined", 1);
	if ((_SC_XOPEN_XPG3) <= 0) {
	    long long x = (long long)(_SC_XOPEN_XPG3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_XPG3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_241(void) {
#ifdef _SC_XOPEN_XPG4
	dump("defined", 1);
	if ((_SC_XOPEN_XPG4) <= 0) {
	    long long x = (long long)(_SC_XOPEN_XPG4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_SC_XOPEN_XPG4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	printf("-+- 68\n");
	dump_section_68();
	printf("---\n");
	printf("-+- 69\n");
	dump_section_69();
	printf("---\n");
	printf("-+- 70\n");
	dump_section_70();
	printf("---\n");
	printf("-+- 71\n");
	dump_section_71();
	printf("---\n");
	printf("-+- 72\n");
	dump_section_72();
	printf("---\n");
	printf("-+- 73\n");
	dump_section_73();
	printf("---\n");
	printf("-+- 74\n");
	dump_section_74();
	printf("---\n");
	printf("-+- 75\n");
	dump_section_75();
	printf("---\n");
	printf("-+- 76\n");
	dump_section_76();
	printf("---\n");
	printf("-+- 77\n");
	dump_section_77();
	printf("---\n");
	printf("-+- 78\n");
	dump_section_78();
	printf("---\n");
	printf("-+- 79\n");
	dump_section_79();
	printf("---\n");
	printf("-+- 80\n");
	dump_section_80();
	printf("---\n");
	printf("-+- 81\n");
	dump_section_81();
	printf("---\n");
	printf("-+- 82\n");
	dump_section_82();
	printf("---\n");
	printf("-+- 83\n");
	dump_section_83();
	printf("---\n");
	printf("-+- 84\n");
	dump_section_84();
	printf("---\n");
	printf("-+- 85\n");
	dump_section_85();
	printf("---\n");
	printf("-+- 86\n");
	dump_section_86();
	printf("---\n");
	printf("-+- 87\n");
	dump_section_87();
	printf("---\n");
	printf("-+- 88\n");
	dump_section_88();
	printf("---\n");
	printf("-+- 89\n");
	dump_section_89();
	printf("---\n");
	printf("-+- 90\n");
	dump_section_90();
	printf("---\n");
	printf("-+- 91\n");
	dump_section_91();
	printf("---\n");
	printf("-+- 92\n");
	dump_section_92();
	printf("---\n");
	printf("-+- 93\n");
	dump_section_93();
	printf("---\n");
	printf("-+- 94\n");
	dump_section_94();
	printf("---\n");
	printf("-+- 95\n");
	dump_section_95();
	printf("---\n");
	printf("-+- 96\n");
	dump_section_96();
	printf("---\n");
	printf("-+- 97\n");
	dump_section_97();
	printf("---\n");
	printf("-+- 98\n");
	dump_section_98();
	printf("---\n");
	printf("-+- 99\n");
	dump_section_99();
	printf("---\n");
	printf("-+- 100\n");
	dump_section_100();
	printf("---\n");
	printf("-+- 101\n");
	dump_section_101();
	printf("---\n");
	printf("-+- 102\n");
	dump_section_102();
	printf("---\n");
	printf("-+- 103\n");
	dump_section_103();
	printf("---\n");
	printf("-+- 104\n");
	dump_section_104();
	printf("---\n");
	printf("-+- 105\n");
	dump_section_105();
	printf("---\n");
	printf("-+- 106\n");
	dump_section_106();
	printf("---\n");
	printf("-+- 107\n");
	dump_section_107();
	printf("---\n");
	printf("-+- 108\n");
	dump_section_108();
	printf("---\n");
	printf("-+- 109\n");
	dump_section_109();
	printf("---\n");
	printf("-+- 110\n");
	dump_section_110();
	printf("---\n");
	printf("-+- 111\n");
	dump_section_111();
	printf("---\n");
	printf("-+- 112\n");
	dump_section_112();
	printf("---\n");
	printf("-+- 113\n");
	dump_section_113();
	printf("---\n");
	printf("-+- 114\n");
	dump_section_114();
	printf("---\n");
	printf("-+- 115\n");
	dump_section_115();
	printf("---\n");
	printf("-+- 116\n");
	dump_section_116();
	printf("---\n");
	printf("-+- 117\n");
	dump_section_117();
	printf("---\n");
	printf("-+- 118\n");
	dump_section_118();
	printf("---\n");
	printf("-+- 119\n");
	dump_section_119();
	printf("---\n");
	printf("-+- 120\n");
	dump_section_120();
	printf("---\n");
	printf("-+- 121\n");
	dump_section_121();
	printf("---\n");
	printf("-+- 122\n");
	dump_section_122();
	printf("---\n");
	printf("-+- 123\n");
	dump_section_123();
	printf("---\n");
	printf("-+- 124\n");
	dump_section_124();
	printf("---\n");
	printf("-+- 125\n");
	dump_section_125();
	printf("---\n");
	printf("-+- 126\n");
	dump_section_126();
	printf("---\n");
	printf("-+- 127\n");
	dump_section_127();
	printf("---\n");
	printf("-+- 128\n");
	dump_section_128();
	printf("---\n");
	printf("-+- 129\n");
	dump_section_129();
	printf("---\n");
	printf("-+- 130\n");
	dump_section_130();
	printf("---\n");
	printf("-+- 131\n");
	dump_section_131();
	printf("---\n");
	printf("-+- 132\n");
	dump_section_132();
	printf("---\n");
	printf("-+- 133\n");
	dump_section_133();
	printf("---\n");
	printf("-+- 134\n");
	dump_section_134();
	printf("---\n");
	printf("-+- 135\n");
	dump_section_135();
	printf("---\n");
	printf("-+- 136\n");
	dump_section_136();
	printf("---\n");
	printf("-+- 137\n");
	dump_section_137();
	printf("---\n");
	printf("-+- 138\n");
	dump_section_138();
	printf("---\n");
	printf("-+- 139\n");
	dump_section_139();
	printf("---\n");
	printf("-+- 140\n");
	dump_section_140();
	printf("---\n");
	printf("-+- 141\n");
	dump_section_141();
	printf("---\n");
	printf("-+- 142\n");
	dump_section_142();
	printf("---\n");
	printf("-+- 143\n");
	dump_section_143();
	printf("---\n");
	printf("-+- 144\n");
	dump_section_144();
	printf("---\n");
	printf("-+- 145\n");
	dump_section_145();
	printf("---\n");
	printf("-+- 146\n");
	dump_section_146();
	printf("---\n");
	printf("-+- 147\n");
	dump_section_147();
	printf("---\n");
	printf("-+- 148\n");
	dump_section_148();
	printf("---\n");
	printf("-+- 149\n");
	dump_section_149();
	printf("---\n");
	printf("-+- 150\n");
	dump_section_150();
	printf("---\n");
	printf("-+- 151\n");
	dump_section_151();
	printf("---\n");
	printf("-+- 152\n");
	dump_section_152();
	printf("---\n");
	printf("-+- 153\n");
	dump_section_153();
	printf("---\n");
	printf("-+- 154\n");
	dump_section_154();
	printf("---\n");
	printf("-+- 155\n");
	dump_section_155();
	printf("---\n");
	printf("-+- 156\n");
	dump_section_156();
	printf("---\n");
	printf("-+- 157\n");
	dump_section_157();
	printf("---\n");
	printf("-+- 158\n");
	dump_section_158();
	printf("---\n");
	printf("-+- 159\n");
	dump_section_159();
	printf("---\n");
	printf("-+- 160\n");
	dump_section_160();
	printf("---\n");
	printf("-+- 161\n");
	dump_section_161();
	printf("---\n");
	printf("-+- 162\n");
	dump_section_162();
	printf("---\n");
	printf("-+- 163\n");
	dump_section_163();
	printf("---\n");
	printf("-+- 164\n");
	dump_section_164();
	printf("---\n");
	printf("-+- 165\n");
	dump_section_165();
	printf("---\n");
	printf("-+- 166\n");
	dump_section_166();
	printf("---\n");
	printf("-+- 167\n");
	dump_section_167();
	printf("---\n");
	printf("-+- 168\n");
	dump_section_168();
	printf("---\n");
	printf("-+- 169\n");
	dump_section_169();
	printf("---\n");
	printf("-+- 170\n");
	dump_section_170();
	printf("---\n");
	printf("-+- 171\n");
	dump_section_171();
	printf("---\n");
	printf("-+- 172\n");
	dump_section_172();
	printf("---\n");
	printf("-+- 173\n");
	dump_section_173();
	printf("---\n");
	printf("-+- 174\n");
	dump_section_174();
	printf("---\n");
	printf("-+- 175\n");
	dump_section_175();
	printf("---\n");
	printf("-+- 176\n");
	dump_section_176();
	printf("---\n");
	printf("-+- 177\n");
	dump_section_177();
	printf("---\n");
	printf("-+- 178\n");
	dump_section_178();
	printf("---\n");
	printf("-+- 179\n");
	dump_section_179();
	printf("---\n");
	printf("-+- 180\n");
	dump_section_180();
	printf("---\n");
	printf("-+- 181\n");
	dump_section_181();
	printf("---\n");
	printf("-+- 182\n");
	dump_section_182();
	printf("---\n");
	printf("-+- 183\n");
	dump_section_183();
	printf("---\n");
	printf("-+- 184\n");
	dump_section_184();
	printf("---\n");
	printf("-+- 185\n");
	dump_section_185();
	printf("---\n");
	printf("-+- 186\n");
	dump_section_186();
	printf("---\n");
	printf("-+- 187\n");
	dump_section_187();
	printf("---\n");
	printf("-+- 188\n");
	dump_section_188();
	printf("---\n");
	printf("-+- 189\n");
	dump_section_189();
	printf("---\n");
	printf("-+- 190\n");
	dump_section_190();
	printf("---\n");
	printf("-+- 191\n");
	dump_section_191();
	printf("---\n");
	printf("-+- 192\n");
	dump_section_192();
	printf("---\n");
	printf("-+- 193\n");
	dump_section_193();
	printf("---\n");
	printf("-+- 194\n");
	dump_section_194();
	printf("---\n");
	printf("-+- 195\n");
	dump_section_195();
	printf("---\n");
	printf("-+- 196\n");
	dump_section_196();
	printf("---\n");
	printf("-+- 197\n");
	dump_section_197();
	printf("---\n");
	printf("-+- 198\n");
	dump_section_198();
	printf("---\n");
	printf("-+- 199\n");
	dump_section_199();
	printf("---\n");
	printf("-+- 200\n");
	dump_section_200();
	printf("---\n");
	printf("-+- 201\n");
	dump_section_201();
	printf("---\n");
	printf("-+- 202\n");
	dump_section_202();
	printf("---\n");
	printf("-+- 203\n");
	dump_section_203();
	printf("---\n");
	printf("-+- 204\n");
	dump_section_204();
	printf("---\n");
	printf("-+- 205\n");
	dump_section_205();
	printf("---\n");
	printf("-+- 206\n");
	dump_section_206();
	printf("---\n");
	printf("-+- 207\n");
	dump_section_207();
	printf("---\n");
	printf("-+- 208\n");
	dump_section_208();
	printf("---\n");
	printf("-+- 209\n");
	dump_section_209();
	printf("---\n");
	printf("-+- 210\n");
	dump_section_210();
	printf("---\n");
	printf("-+- 211\n");
	dump_section_211();
	printf("---\n");
	printf("-+- 212\n");
	dump_section_212();
	printf("---\n");
	printf("-+- 213\n");
	dump_section_213();
	printf("---\n");
	printf("-+- 214\n");
	dump_section_214();
	printf("---\n");
	printf("-+- 215\n");
	dump_section_215();
	printf("---\n");
	printf("-+- 216\n");
	dump_section_216();
	printf("---\n");
	printf("-+- 217\n");
	dump_section_217();
	printf("---\n");
	printf("-+- 218\n");
	dump_section_218();
	printf("---\n");
	printf("-+- 219\n");
	dump_section_219();
	printf("---\n");
	printf("-+- 220\n");
	dump_section_220();
	printf("---\n");
	printf("-+- 221\n");
	dump_section_221();
	printf("---\n");
	printf("-+- 222\n");
	dump_section_222();
	printf("---\n");
	printf("-+- 223\n");
	dump_section_223();
	printf("---\n");
	printf("-+- 224\n");
	dump_section_224();
	printf("---\n");
	printf("-+- 225\n");
	dump_section_225();
	printf("---\n");
	printf("-+- 226\n");
	dump_section_226();
	printf("---\n");
	printf("-+- 227\n");
	dump_section_227();
	printf("---\n");
	printf("-+- 228\n");
	dump_section_228();
	printf("---\n");
	printf("-+- 229\n");
	dump_section_229();
	printf("---\n");
	printf("-+- 230\n");
	dump_section_230();
	printf("---\n");
	printf("-+- 231\n");
	dump_section_231();
	printf("---\n");
	printf("-+- 232\n");
	dump_section_232();
	printf("---\n");
	printf("-+- 233\n");
	dump_section_233();
	printf("---\n");
	printf("-+- 234\n");
	dump_section_234();
	printf("---\n");
	printf("-+- 235\n");
	dump_section_235();
	printf("---\n");
	printf("-+- 236\n");
	dump_section_236();
	printf("---\n");
	printf("-+- 237\n");
	dump_section_237();
	printf("---\n");
	printf("-+- 238\n");
	dump_section_238();
	printf("---\n");
	printf("-+- 239\n");
	dump_section_239();
	printf("---\n");
	printf("-+- 240\n");
	dump_section_240();
	printf("---\n");
	printf("-+- 241\n");
	dump_section_241();
	printf("---\n");
	return 0;
}
