/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/mman.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef MFD_ALLOW_SEALING
	dump("defined", 1);
	if ((MFD_ALLOW_SEALING) <= 0) {
	    long long x = (long long)(MFD_ALLOW_SEALING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_ALLOW_SEALING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef MFD_CLOEXEC
	dump("defined", 1);
	if ((MFD_CLOEXEC) <= 0) {
	    long long x = (long long)(MFD_CLOEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_CLOEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef MFD_HUGETLB
	dump("defined", 1);
	if ((MFD_HUGETLB) <= 0) {
	    long long x = (long long)(MFD_HUGETLB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGETLB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef MFD_HUGE_16GB
	dump("defined", 1);
	if ((MFD_HUGE_16GB) <= 0) {
	    long long x = (long long)(MFD_HUGE_16GB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_16GB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef MFD_HUGE_16MB
	dump("defined", 1);
	if ((MFD_HUGE_16MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_16MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_16MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef MFD_HUGE_1GB
	dump("defined", 1);
	if ((MFD_HUGE_1GB) <= 0) {
	    long long x = (long long)(MFD_HUGE_1GB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_1GB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef MFD_HUGE_1MB
	dump("defined", 1);
	if ((MFD_HUGE_1MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_1MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_1MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef MFD_HUGE_256MB
	dump("defined", 1);
	if ((MFD_HUGE_256MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_256MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_256MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef MFD_HUGE_2GB
	dump("defined", 1);
	if ((MFD_HUGE_2GB) <= 0) {
	    long long x = (long long)(MFD_HUGE_2GB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_2GB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef MFD_HUGE_2MB
	dump("defined", 1);
	if ((MFD_HUGE_2MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_2MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_2MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef MFD_HUGE_32MB
	dump("defined", 1);
	if ((MFD_HUGE_32MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_32MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_32MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef MFD_HUGE_512KB
	dump("defined", 1);
	if ((MFD_HUGE_512KB) <= 0) {
	    long long x = (long long)(MFD_HUGE_512KB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_512KB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef MFD_HUGE_512MB
	dump("defined", 1);
	if ((MFD_HUGE_512MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_512MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_512MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef MFD_HUGE_64KB
	dump("defined", 1);
	if ((MFD_HUGE_64KB) <= 0) {
	    long long x = (long long)(MFD_HUGE_64KB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_64KB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef MFD_HUGE_8MB
	dump("defined", 1);
	if ((MFD_HUGE_8MB) <= 0) {
	    long long x = (long long)(MFD_HUGE_8MB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_8MB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef MFD_HUGE_MASK
	dump("defined", 1);
	if ((MFD_HUGE_MASK) <= 0) {
	    long long x = (long long)(MFD_HUGE_MASK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_MASK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef MFD_HUGE_SHIFT
	dump("defined", 1);
	if ((MFD_HUGE_SHIFT) <= 0) {
	    long long x = (long long)(MFD_HUGE_SHIFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MFD_HUGE_SHIFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	return 0;
}
