/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <locale.h>
#include <limits.h>
#include <ctype.h>
#include <wchar.h>
#include <langinfo.h>
#include <libintl.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef ABDAY_1
	dump("defined", 1);
	if ((ABDAY_1) <= 0) {
	    long long x = (long long)(ABDAY_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef ABDAY_2
	dump("defined", 1);
	if ((ABDAY_2) <= 0) {
	    long long x = (long long)(ABDAY_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef ABDAY_3
	dump("defined", 1);
	if ((ABDAY_3) <= 0) {
	    long long x = (long long)(ABDAY_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef ABDAY_4
	dump("defined", 1);
	if ((ABDAY_4) <= 0) {
	    long long x = (long long)(ABDAY_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef ABDAY_5
	dump("defined", 1);
	if ((ABDAY_5) <= 0) {
	    long long x = (long long)(ABDAY_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef ABDAY_6
	dump("defined", 1);
	if ((ABDAY_6) <= 0) {
	    long long x = (long long)(ABDAY_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef ABDAY_7
	dump("defined", 1);
	if ((ABDAY_7) <= 0) {
	    long long x = (long long)(ABDAY_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef ABMON_1
	dump("defined", 1);
	if ((ABMON_1) <= 0) {
	    long long x = (long long)(ABMON_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef ABMON_10
	dump("defined", 1);
	if ((ABMON_10) <= 0) {
	    long long x = (long long)(ABMON_10);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_10);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef ABMON_11
	dump("defined", 1);
	if ((ABMON_11) <= 0) {
	    long long x = (long long)(ABMON_11);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_11);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef ABMON_12
	dump("defined", 1);
	if ((ABMON_12) <= 0) {
	    long long x = (long long)(ABMON_12);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_12);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef ABMON_2
	dump("defined", 1);
	if ((ABMON_2) <= 0) {
	    long long x = (long long)(ABMON_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef ABMON_3
	dump("defined", 1);
	if ((ABMON_3) <= 0) {
	    long long x = (long long)(ABMON_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef ABMON_4
	dump("defined", 1);
	if ((ABMON_4) <= 0) {
	    long long x = (long long)(ABMON_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef ABMON_5
	dump("defined", 1);
	if ((ABMON_5) <= 0) {
	    long long x = (long long)(ABMON_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef ABMON_6
	dump("defined", 1);
	if ((ABMON_6) <= 0) {
	    long long x = (long long)(ABMON_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef ABMON_7
	dump("defined", 1);
	if ((ABMON_7) <= 0) {
	    long long x = (long long)(ABMON_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef ABMON_8
	dump("defined", 1);
	if ((ABMON_8) <= 0) {
	    long long x = (long long)(ABMON_8);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_8);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef ABMON_9
	dump("defined", 1);
	if ((ABMON_9) <= 0) {
	    long long x = (long long)(ABMON_9);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_9);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef ALT_DIGITS
	dump("defined", 1);
	if ((ALT_DIGITS) <= 0) {
	    long long x = (long long)(ALT_DIGITS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ALT_DIGITS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef AM_STR
	dump("defined", 1);
	if ((AM_STR) <= 0) {
	    long long x = (long long)(AM_STR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AM_STR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef CHAR_MAX
	dump("defined", 1);
	if ((CHAR_MAX) <= 0) {
	    long long x = (long long)(CHAR_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CHAR_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
#ifdef CODESET
	dump("defined", 1);
	if ((CODESET) <= 0) {
	    long long x = (long long)(CODESET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CODESET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_23(void) {
#ifdef CRNCYSTR
	dump("defined", 1);
	if ((CRNCYSTR) <= 0) {
	    long long x = (long long)(CRNCYSTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRNCYSTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_24(void) {
#ifdef DAY_1
	dump("defined", 1);
	if ((DAY_1) <= 0) {
	    long long x = (long long)(DAY_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_25(void) {
#ifdef DAY_2
	dump("defined", 1);
	if ((DAY_2) <= 0) {
	    long long x = (long long)(DAY_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef DAY_3
	dump("defined", 1);
	if ((DAY_3) <= 0) {
	    long long x = (long long)(DAY_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_27(void) {
#ifdef DAY_4
	dump("defined", 1);
	if ((DAY_4) <= 0) {
	    long long x = (long long)(DAY_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef DAY_5
	dump("defined", 1);
	if ((DAY_5) <= 0) {
	    long long x = (long long)(DAY_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef DAY_6
	dump("defined", 1);
	if ((DAY_6) <= 0) {
	    long long x = (long long)(DAY_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef DAY_7
	dump("defined", 1);
	if ((DAY_7) <= 0) {
	    long long x = (long long)(DAY_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef D_FMT
	dump("defined", 1);
	if ((D_FMT) <= 0) {
	    long long x = (long long)(D_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(D_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
#ifdef D_T_FMT
	dump("defined", 1);
	if ((D_T_FMT) <= 0) {
	    long long x = (long long)(D_T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(D_T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_33(void) {
#ifdef ERA
	dump("defined", 1);
	if ((ERA) <= 0) {
	    long long x = (long long)(ERA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
#ifdef ERA_D_FMT
	dump("defined", 1);
	if ((ERA_D_FMT) <= 0) {
	    long long x = (long long)(ERA_D_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA_D_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_35(void) {
#ifdef ERA_D_T_FMT
	dump("defined", 1);
	if ((ERA_D_T_FMT) <= 0) {
	    long long x = (long long)(ERA_D_T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA_D_T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_36(void) {
#ifdef ERA_T_FMT
	dump("defined", 1);
	if ((ERA_T_FMT) <= 0) {
	    long long x = (long long)(ERA_T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA_T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_37(void) {
#ifdef LC_ADDRESS
	dump("defined", 1);
	if ((LC_ADDRESS) <= 0) {
	    long long x = (long long)(LC_ADDRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_ADDRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_38(void) {
#ifdef LC_ALL
	dump("defined", 1);
	if ((LC_ALL) <= 0) {
	    long long x = (long long)(LC_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_ALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_39(void) {
#ifdef LC_COLLATE
	dump("defined", 1);
	if ((LC_COLLATE) <= 0) {
	    long long x = (long long)(LC_COLLATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_COLLATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_40(void) {
#ifdef LC_CTYPE
	dump("defined", 1);
	if ((LC_CTYPE) <= 0) {
	    long long x = (long long)(LC_CTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_CTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_41(void) {
#ifdef LC_IDENTIFICATION
	dump("defined", 1);
	if ((LC_IDENTIFICATION) <= 0) {
	    long long x = (long long)(LC_IDENTIFICATION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_IDENTIFICATION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_42(void) {
#ifdef LC_MAX
	dump("defined", 1);
	if ((LC_MAX) <= 0) {
	    long long x = (long long)(LC_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_43(void) {
#ifdef LC_MEASUREMENT
	dump("defined", 1);
	if ((LC_MEASUREMENT) <= 0) {
	    long long x = (long long)(LC_MEASUREMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MEASUREMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_44(void) {
#ifdef LC_MESSAGES
	dump("defined", 1);
	if ((LC_MESSAGES) <= 0) {
	    long long x = (long long)(LC_MESSAGES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MESSAGES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_45(void) {
#ifdef LC_MIN
	dump("defined", 1);
	if ((LC_MIN) <= 0) {
	    long long x = (long long)(LC_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_46(void) {
#ifdef LC_MONETARY
	dump("defined", 1);
	if ((LC_MONETARY) <= 0) {
	    long long x = (long long)(LC_MONETARY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MONETARY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_47(void) {
#ifdef LC_NAME
	dump("defined", 1);
	if ((LC_NAME) <= 0) {
	    long long x = (long long)(LC_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_48(void) {
#ifdef LC_NUMERIC
	dump("defined", 1);
	if ((LC_NUMERIC) <= 0) {
	    long long x = (long long)(LC_NUMERIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_NUMERIC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_49(void) {
#ifdef LC_PAPER
	dump("defined", 1);
	if ((LC_PAPER) <= 0) {
	    long long x = (long long)(LC_PAPER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_PAPER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_50(void) {
#ifdef LC_TELEPHONE
	dump("defined", 1);
	if ((LC_TELEPHONE) <= 0) {
	    long long x = (long long)(LC_TELEPHONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_TELEPHONE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
#ifdef LC_TIME
	dump("defined", 1);
	if ((LC_TIME) <= 0) {
	    long long x = (long long)(LC_TIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_TIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_52(void) {
#ifdef MON_1
	dump("defined", 1);
	if ((MON_1) <= 0) {
	    long long x = (long long)(MON_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_53(void) {
#ifdef MON_10
	dump("defined", 1);
	if ((MON_10) <= 0) {
	    long long x = (long long)(MON_10);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_10);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_54(void) {
#ifdef MON_11
	dump("defined", 1);
	if ((MON_11) <= 0) {
	    long long x = (long long)(MON_11);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_11);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_55(void) {
#ifdef MON_12
	dump("defined", 1);
	if ((MON_12) <= 0) {
	    long long x = (long long)(MON_12);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_12);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_56(void) {
#ifdef MON_2
	dump("defined", 1);
	if ((MON_2) <= 0) {
	    long long x = (long long)(MON_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_57(void) {
#ifdef MON_3
	dump("defined", 1);
	if ((MON_3) <= 0) {
	    long long x = (long long)(MON_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_58(void) {
#ifdef MON_4
	dump("defined", 1);
	if ((MON_4) <= 0) {
	    long long x = (long long)(MON_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_59(void) {
#ifdef MON_5
	dump("defined", 1);
	if ((MON_5) <= 0) {
	    long long x = (long long)(MON_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_60(void) {
#ifdef MON_6
	dump("defined", 1);
	if ((MON_6) <= 0) {
	    long long x = (long long)(MON_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_61(void) {
#ifdef MON_7
	dump("defined", 1);
	if ((MON_7) <= 0) {
	    long long x = (long long)(MON_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_62(void) {
#ifdef MON_8
	dump("defined", 1);
	if ((MON_8) <= 0) {
	    long long x = (long long)(MON_8);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_8);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_63(void) {
#ifdef MON_9
	dump("defined", 1);
	if ((MON_9) <= 0) {
	    long long x = (long long)(MON_9);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_9);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_64(void) {
#ifdef NOEXPR
	dump("defined", 1);
	if ((NOEXPR) <= 0) {
	    long long x = (long long)(NOEXPR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NOEXPR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_65(void) {
#ifdef PM_STR
	dump("defined", 1);
	if ((PM_STR) <= 0) {
	    long long x = (long long)(PM_STR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PM_STR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_66(void) {
#ifdef RADIXCHAR
	dump("defined", 1);
	if ((RADIXCHAR) <= 0) {
	    long long x = (long long)(RADIXCHAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RADIXCHAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_67(void) {
#ifdef THOUSEP
	dump("defined", 1);
	if ((THOUSEP) <= 0) {
	    long long x = (long long)(THOUSEP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(THOUSEP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_68(void) {
#ifdef T_FMT
	dump("defined", 1);
	if ((T_FMT) <= 0) {
	    long long x = (long long)(T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_69(void) {
#ifdef T_FMT_AMPM
	dump("defined", 1);
	if ((T_FMT_AMPM) <= 0) {
	    long long x = (long long)(T_FMT_AMPM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(T_FMT_AMPM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_70(void) {
#ifdef YESEXPR
	dump("defined", 1);
	if ((YESEXPR) <= 0) {
	    long long x = (long long)(YESEXPR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(YESEXPR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_71(void) {
#ifdef _DATE_FMT
	dump("defined", 1);
	if ((_DATE_FMT) <= 0) {
	    long long x = (long long)(_DATE_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_DATE_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_72(void) {
	typedef struct lconv platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs decimal_point", offsetof(platcheck_t, decimal_point));
	dump("fldsize decimal_point",   sizeof(s.decimal_point));
	dump("fldofs thousands_sep", offsetof(platcheck_t, thousands_sep));
	dump("fldsize thousands_sep",   sizeof(s.thousands_sep));
	dump("fldofs grouping", offsetof(platcheck_t, grouping));
	dump("fldsize grouping",   sizeof(s.grouping));
	dump("fldofs int_curr_symbol", offsetof(platcheck_t, int_curr_symbol));
	dump("fldsize int_curr_symbol",   sizeof(s.int_curr_symbol));
	dump("fldofs currency_symbol", offsetof(platcheck_t, currency_symbol));
	dump("fldsize currency_symbol",   sizeof(s.currency_symbol));
	dump("fldofs mon_decimal_point", offsetof(platcheck_t, mon_decimal_point));
	dump("fldsize mon_decimal_point",   sizeof(s.mon_decimal_point));
	dump("fldofs mon_thousands_sep", offsetof(platcheck_t, mon_thousands_sep));
	dump("fldsize mon_thousands_sep",   sizeof(s.mon_thousands_sep));
	dump("fldofs mon_grouping", offsetof(platcheck_t, mon_grouping));
	dump("fldsize mon_grouping",   sizeof(s.mon_grouping));
	dump("fldofs positive_sign", offsetof(platcheck_t, positive_sign));
	dump("fldsize positive_sign",   sizeof(s.positive_sign));
	dump("fldofs negative_sign", offsetof(platcheck_t, negative_sign));
	dump("fldsize negative_sign",   sizeof(s.negative_sign));
	dump("fldofs int_frac_digits", offsetof(platcheck_t, int_frac_digits));
	dump("fldsize int_frac_digits",   sizeof(s.int_frac_digits));
	s.int_frac_digits = 0; s.int_frac_digits = ~s.int_frac_digits;
	dump("fldunsigned int_frac_digits", s.int_frac_digits > 0);
	dump("fldofs frac_digits", offsetof(platcheck_t, frac_digits));
	dump("fldsize frac_digits",   sizeof(s.frac_digits));
	s.frac_digits = 0; s.frac_digits = ~s.frac_digits;
	dump("fldunsigned frac_digits", s.frac_digits > 0);
	dump("fldofs p_cs_precedes", offsetof(platcheck_t, p_cs_precedes));
	dump("fldsize p_cs_precedes",   sizeof(s.p_cs_precedes));
	s.p_cs_precedes = 0; s.p_cs_precedes = ~s.p_cs_precedes;
	dump("fldunsigned p_cs_precedes", s.p_cs_precedes > 0);
	dump("fldofs p_sep_by_space", offsetof(platcheck_t, p_sep_by_space));
	dump("fldsize p_sep_by_space",   sizeof(s.p_sep_by_space));
	s.p_sep_by_space = 0; s.p_sep_by_space = ~s.p_sep_by_space;
	dump("fldunsigned p_sep_by_space", s.p_sep_by_space > 0);
	dump("fldofs n_cs_precedes", offsetof(platcheck_t, n_cs_precedes));
	dump("fldsize n_cs_precedes",   sizeof(s.n_cs_precedes));
	s.n_cs_precedes = 0; s.n_cs_precedes = ~s.n_cs_precedes;
	dump("fldunsigned n_cs_precedes", s.n_cs_precedes > 0);
	dump("fldofs n_sep_by_space", offsetof(platcheck_t, n_sep_by_space));
	dump("fldsize n_sep_by_space",   sizeof(s.n_sep_by_space));
	s.n_sep_by_space = 0; s.n_sep_by_space = ~s.n_sep_by_space;
	dump("fldunsigned n_sep_by_space", s.n_sep_by_space > 0);
	dump("fldofs p_sign_posn", offsetof(platcheck_t, p_sign_posn));
	dump("fldsize p_sign_posn",   sizeof(s.p_sign_posn));
	s.p_sign_posn = 0; s.p_sign_posn = ~s.p_sign_posn;
	dump("fldunsigned p_sign_posn", s.p_sign_posn > 0);
	dump("fldofs n_sign_posn", offsetof(platcheck_t, n_sign_posn));
	dump("fldsize n_sign_posn",   sizeof(s.n_sign_posn));
	s.n_sign_posn = 0; s.n_sign_posn = ~s.n_sign_posn;
	dump("fldunsigned n_sign_posn", s.n_sign_posn > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	printf("-+- 68\n");
	dump_section_68();
	printf("---\n");
	printf("-+- 69\n");
	dump_section_69();
	printf("---\n");
	printf("-+- 70\n");
	dump_section_70();
	printf("---\n");
	printf("-+- 71\n");
	dump_section_71();
	printf("---\n");
	printf("-+- 72\n");
	dump_section_72();
	printf("---\n");
	return 0;
}
