/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/statvfs.h>
#include <unistd.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef struct statvfs platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs f_bsize", offsetof(platcheck_t, f_bsize));
	dump("fldsize f_bsize",   sizeof(s.f_bsize));
	s.f_bsize = 0; s.f_bsize = ~s.f_bsize;
	dump("fldunsigned f_bsize", s.f_bsize > 0);
	dump("fldofs f_frsize", offsetof(platcheck_t, f_frsize));
	dump("fldsize f_frsize",   sizeof(s.f_frsize));
	s.f_frsize = 0; s.f_frsize = ~s.f_frsize;
	dump("fldunsigned f_frsize", s.f_frsize > 0);
	dump("fldofs f_blocks", offsetof(platcheck_t, f_blocks));
	dump("fldsize f_blocks",   sizeof(s.f_blocks));
	s.f_blocks = 0; s.f_blocks = ~s.f_blocks;
	dump("fldunsigned f_blocks", s.f_blocks > 0);
	dump("fldofs f_bfree", offsetof(platcheck_t, f_bfree));
	dump("fldsize f_bfree",   sizeof(s.f_bfree));
	s.f_bfree = 0; s.f_bfree = ~s.f_bfree;
	dump("fldunsigned f_bfree", s.f_bfree > 0);
	dump("fldofs f_bavail", offsetof(platcheck_t, f_bavail));
	dump("fldsize f_bavail",   sizeof(s.f_bavail));
	s.f_bavail = 0; s.f_bavail = ~s.f_bavail;
	dump("fldunsigned f_bavail", s.f_bavail > 0);
	dump("fldofs f_files", offsetof(platcheck_t, f_files));
	dump("fldsize f_files",   sizeof(s.f_files));
	s.f_files = 0; s.f_files = ~s.f_files;
	dump("fldunsigned f_files", s.f_files > 0);
	dump("fldofs f_ffree", offsetof(platcheck_t, f_ffree));
	dump("fldsize f_ffree",   sizeof(s.f_ffree));
	s.f_ffree = 0; s.f_ffree = ~s.f_ffree;
	dump("fldunsigned f_ffree", s.f_ffree > 0);
	dump("fldofs f_favail", offsetof(platcheck_t, f_favail));
	dump("fldsize f_favail",   sizeof(s.f_favail));
	s.f_favail = 0; s.f_favail = ~s.f_favail;
	dump("fldunsigned f_favail", s.f_favail > 0);
	dump("fldofs f_flag", offsetof(platcheck_t, f_flag));
	dump("fldsize f_flag",   sizeof(s.f_flag));
	s.f_flag = 0; s.f_flag = ~s.f_flag;
	dump("fldunsigned f_flag", s.f_flag > 0);
	dump("fldofs f_namemax", offsetof(platcheck_t, f_namemax));
	dump("fldsize f_namemax",   sizeof(s.f_namemax));
	s.f_namemax = 0; s.f_namemax = ~s.f_namemax;
	dump("fldunsigned f_namemax", s.f_namemax > 0);
	dump("fldofs f_fsid", offsetof(platcheck_t, f_fsid));
	dump("fldsize f_fsid",   sizeof(s.f_fsid));
	s.f_fsid = 0; s.f_fsid = ~s.f_fsid;
	dump("fldunsigned f_fsid", s.f_fsid > 0);
}

void dump_section_1(void) {
	typedef struct stat platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs st_mode", offsetof(platcheck_t, st_mode));
	dump("fldsize st_mode",   sizeof(s.st_mode));
	s.st_mode = 0; s.st_mode = ~s.st_mode;
	dump("fldunsigned st_mode", s.st_mode > 0);
	dump("fldofs st_ino", offsetof(platcheck_t, st_ino));
	dump("fldsize st_ino",   sizeof(s.st_ino));
	s.st_ino = 0; s.st_ino = ~s.st_ino;
	dump("fldunsigned st_ino", s.st_ino > 0);
	dump("fldofs st_dev", offsetof(platcheck_t, st_dev));
	dump("fldsize st_dev",   sizeof(s.st_dev));
	s.st_dev = 0; s.st_dev = ~s.st_dev;
	dump("fldunsigned st_dev", s.st_dev > 0);
	dump("fldofs st_nlink", offsetof(platcheck_t, st_nlink));
	dump("fldsize st_nlink",   sizeof(s.st_nlink));
	s.st_nlink = 0; s.st_nlink = ~s.st_nlink;
	dump("fldunsigned st_nlink", s.st_nlink > 0);
	dump("fldofs st_uid", offsetof(platcheck_t, st_uid));
	dump("fldsize st_uid",   sizeof(s.st_uid));
	s.st_uid = 0; s.st_uid = ~s.st_uid;
	dump("fldunsigned st_uid", s.st_uid > 0);
	dump("fldofs st_gid", offsetof(platcheck_t, st_gid));
	dump("fldsize st_gid",   sizeof(s.st_gid));
	s.st_gid = 0; s.st_gid = ~s.st_gid;
	dump("fldunsigned st_gid", s.st_gid > 0);
	dump("fldofs st_size", offsetof(platcheck_t, st_size));
	dump("fldsize st_size",   sizeof(s.st_size));
	s.st_size = 0; s.st_size = ~s.st_size;
	dump("fldunsigned st_size", s.st_size > 0);
	dump("fldofs st_atim", offsetof(platcheck_t, st_atim));
	dump("fldsize st_atim",   sizeof(s.st_atim));
	dump("fldofs st_mtim", offsetof(platcheck_t, st_mtim));
	dump("fldsize st_mtim",   sizeof(s.st_mtim));
	dump("fldofs st_ctim", offsetof(platcheck_t, st_ctim));
	dump("fldsize st_ctim",   sizeof(s.st_ctim));
	dump("fldofs st_blksize", offsetof(platcheck_t, st_blksize));
	dump("fldsize st_blksize",   sizeof(s.st_blksize));
	s.st_blksize = 0; s.st_blksize = ~s.st_blksize;
	dump("fldunsigned st_blksize", s.st_blksize > 0);
	dump("fldofs st_blocks", offsetof(platcheck_t, st_blocks));
	dump("fldsize st_blocks",   sizeof(s.st_blocks));
	s.st_blocks = 0; s.st_blocks = ~s.st_blocks;
	dump("fldunsigned st_blocks", s.st_blocks > 0);
	dump("fldofs st_rdev", offsetof(platcheck_t, st_rdev));
	dump("fldsize st_rdev",   sizeof(s.st_rdev));
	s.st_rdev = 0; s.st_rdev = ~s.st_rdev;
	dump("fldunsigned st_rdev", s.st_rdev > 0);
	dump("fldofs st_flags", offsetof(platcheck_t, st_flags));
	dump("fldsize st_flags",   sizeof(s.st_flags));
	s.st_flags = 0; s.st_flags = ~s.st_flags;
	dump("fldunsigned st_flags", s.st_flags > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	return 0;
}
