/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <poll.h>
#include <sys/select.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <errno.h>
#include <limits.h>
#include <net/if.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <poll.h>
#include <sys/select.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <errno.h>
#include <limits.h>
#include <net/if.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>

#ifdef AF_NETLINK
#include <linux/netlink.h>
#endif


#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef AD_DECnet
	dump("defined", 1);
	if ((AD_DECnet) <= 0) {
	    long long x = (long long)(AD_DECnet);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AD_DECnet);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef AF_AAL5
	dump("defined", 1);
	if ((AF_AAL5) <= 0) {
	    long long x = (long long)(AF_AAL5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_AAL5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef AF_APPLETALK
	dump("defined", 1);
	if ((AF_APPLETALK) <= 0) {
	    long long x = (long long)(AF_APPLETALK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_APPLETALK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef AF_ASH
	dump("defined", 1);
	if ((AF_ASH) <= 0) {
	    long long x = (long long)(AF_ASH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ASH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef AF_ATMPVC
	dump("defined", 1);
	if ((AF_ATMPVC) <= 0) {
	    long long x = (long long)(AF_ATMPVC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ATMPVC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef AF_ATMSVC
	dump("defined", 1);
	if ((AF_ATMSVC) <= 0) {
	    long long x = (long long)(AF_ATMSVC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ATMSVC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef AF_AX25
	dump("defined", 1);
	if ((AF_AX25) <= 0) {
	    long long x = (long long)(AF_AX25);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_AX25);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef AF_BLUETOOTH
	dump("defined", 1);
	if ((AF_BLUETOOTH) <= 0) {
	    long long x = (long long)(AF_BLUETOOTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_BLUETOOTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef AF_BRIDGE
	dump("defined", 1);
	if ((AF_BRIDGE) <= 0) {
	    long long x = (long long)(AF_BRIDGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_BRIDGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef AF_ECONET
	dump("defined", 1);
	if ((AF_ECONET) <= 0) {
	    long long x = (long long)(AF_ECONET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ECONET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef AF_INET
	dump("defined", 1);
	if ((AF_INET) <= 0) {
	    long long x = (long long)(AF_INET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_INET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef AF_INET6
	dump("defined", 1);
	if ((AF_INET6) <= 0) {
	    long long x = (long long)(AF_INET6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_INET6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef AF_IPX
	dump("defined", 1);
	if ((AF_IPX) <= 0) {
	    long long x = (long long)(AF_IPX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_IPX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef AF_IRDA
	dump("defined", 1);
	if ((AF_IRDA) <= 0) {
	    long long x = (long long)(AF_IRDA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_IRDA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef AF_KEY
	dump("defined", 1);
	if ((AF_KEY) <= 0) {
	    long long x = (long long)(AF_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef AF_LLC
	dump("defined", 1);
	if ((AF_LLC) <= 0) {
	    long long x = (long long)(AF_LLC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_LLC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef AF_NETBEUI
	dump("defined", 1);
	if ((AF_NETBEUI) <= 0) {
	    long long x = (long long)(AF_NETBEUI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_NETBEUI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef AF_NETLINK
	dump("defined", 1);
	if ((AF_NETLINK) <= 0) {
	    long long x = (long long)(AF_NETLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_NETLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef AF_NETROM
	dump("defined", 1);
	if ((AF_NETROM) <= 0) {
	    long long x = (long long)(AF_NETROM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_NETROM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef AF_PACKET
	dump("defined", 1);
	if ((AF_PACKET) <= 0) {
	    long long x = (long long)(AF_PACKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_PACKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef AF_PPPOX
	dump("defined", 1);
	if ((AF_PPPOX) <= 0) {
	    long long x = (long long)(AF_PPPOX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_PPPOX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef AF_ROSE
	dump("defined", 1);
	if ((AF_ROSE) <= 0) {
	    long long x = (long long)(AF_ROSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ROSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
#ifdef AF_ROUTE
	dump("defined", 1);
	if ((AF_ROUTE) <= 0) {
	    long long x = (long long)(AF_ROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_23(void) {
#ifdef AF_SECURITY
	dump("defined", 1);
	if ((AF_SECURITY) <= 0) {
	    long long x = (long long)(AF_SECURITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_SECURITY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_24(void) {
#ifdef AF_SNA
	dump("defined", 1);
	if ((AF_SNA) <= 0) {
	    long long x = (long long)(AF_SNA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_SNA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_25(void) {
#ifdef AF_UNIX
	dump("defined", 1);
	if ((AF_UNIX) <= 0) {
	    long long x = (long long)(AF_UNIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_UNIX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef AF_UNSPEC
	dump("defined", 1);
	if ((AF_UNSPEC) <= 0) {
	    long long x = (long long)(AF_UNSPEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_UNSPEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_27(void) {
#ifdef AF_WANPIPE
	dump("defined", 1);
	if ((AF_WANPIPE) <= 0) {
	    long long x = (long long)(AF_WANPIPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_WANPIPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef AF_X25
	dump("defined", 1);
	if ((AF_X25) <= 0) {
	    long long x = (long long)(AF_X25);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_X25);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef AI_ADDRCONFIG
	dump("defined", 1);
	if ((AI_ADDRCONFIG) <= 0) {
	    long long x = (long long)(AI_ADDRCONFIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_ADDRCONFIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef AI_ALL
	dump("defined", 1);
	if ((AI_ALL) <= 0) {
	    long long x = (long long)(AI_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_ALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef AI_CANONNAME
	dump("defined", 1);
	if ((AI_CANONNAME) <= 0) {
	    long long x = (long long)(AI_CANONNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_CANONNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
#ifdef AI_DEFAULT
	dump("defined", 1);
	if ((AI_DEFAULT) <= 0) {
	    long long x = (long long)(AI_DEFAULT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_DEFAULT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_33(void) {
#ifdef AI_MASK
	dump("defined", 1);
	if ((AI_MASK) <= 0) {
	    long long x = (long long)(AI_MASK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_MASK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
#ifdef AI_NUMERICHOST
	dump("defined", 1);
	if ((AI_NUMERICHOST) <= 0) {
	    long long x = (long long)(AI_NUMERICHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_NUMERICHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_35(void) {
#ifdef AI_NUMERICSERV
	dump("defined", 1);
	if ((AI_NUMERICSERV) <= 0) {
	    long long x = (long long)(AI_NUMERICSERV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_NUMERICSERV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_36(void) {
#ifdef AI_PASSIVE
	dump("defined", 1);
	if ((AI_PASSIVE) <= 0) {
	    long long x = (long long)(AI_PASSIVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_PASSIVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_37(void) {
#ifdef AI_V4MAPPED
	dump("defined", 1);
	if ((AI_V4MAPPED) <= 0) {
	    long long x = (long long)(AI_V4MAPPED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_V4MAPPED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_38(void) {
#ifdef AI_V4MAPPED_CFG
	dump("defined", 1);
	if ((AI_V4MAPPED_CFG) <= 0) {
	    long long x = (long long)(AI_V4MAPPED_CFG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_V4MAPPED_CFG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_39(void) {
#ifdef BTPROTO_L2CAP
	dump("defined", 1);
	if ((BTPROTO_L2CAP) <= 0) {
	    long long x = (long long)(BTPROTO_L2CAP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BTPROTO_L2CAP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_40(void) {
#ifdef BTPROTO_RFCOMM
	dump("defined", 1);
	if ((BTPROTO_RFCOMM) <= 0) {
	    long long x = (long long)(BTPROTO_RFCOMM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BTPROTO_RFCOMM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_41(void) {
#ifdef BTPROTO_SCO
	dump("defined", 1);
	if ((BTPROTO_SCO) <= 0) {
	    long long x = (long long)(BTPROTO_SCO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BTPROTO_SCO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_42(void) {
#ifdef EAFNOSUPPORT
	dump("defined", 1);
	if ((EAFNOSUPPORT) <= 0) {
	    long long x = (long long)(EAFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_43(void) {
#ifdef EAI_ADDRFAMILY
	dump("defined", 1);
	if ((EAI_ADDRFAMILY) <= 0) {
	    long long x = (long long)(EAI_ADDRFAMILY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_ADDRFAMILY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_44(void) {
#ifdef EAI_AGAIN
	dump("defined", 1);
	if ((EAI_AGAIN) <= 0) {
	    long long x = (long long)(EAI_AGAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_AGAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_45(void) {
#ifdef EAI_BADFLAGS
	dump("defined", 1);
	if ((EAI_BADFLAGS) <= 0) {
	    long long x = (long long)(EAI_BADFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_BADFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_46(void) {
#ifdef EAI_BADHINTS
	dump("defined", 1);
	if ((EAI_BADHINTS) <= 0) {
	    long long x = (long long)(EAI_BADHINTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_BADHINTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_47(void) {
#ifdef EAI_FAIL
	dump("defined", 1);
	if ((EAI_FAIL) <= 0) {
	    long long x = (long long)(EAI_FAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_FAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_48(void) {
#ifdef EAI_FAMILY
	dump("defined", 1);
	if ((EAI_FAMILY) <= 0) {
	    long long x = (long long)(EAI_FAMILY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_FAMILY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_49(void) {
#ifdef EAI_MAX
	dump("defined", 1);
	if ((EAI_MAX) <= 0) {
	    long long x = (long long)(EAI_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_50(void) {
#ifdef EAI_MEMORY
	dump("defined", 1);
	if ((EAI_MEMORY) <= 0) {
	    long long x = (long long)(EAI_MEMORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_MEMORY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
#ifdef EAI_NODATA
	dump("defined", 1);
	if ((EAI_NODATA) <= 0) {
	    long long x = (long long)(EAI_NODATA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_NODATA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_52(void) {
#ifdef EAI_NONAME
	dump("defined", 1);
	if ((EAI_NONAME) <= 0) {
	    long long x = (long long)(EAI_NONAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_NONAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_53(void) {
#ifdef EAI_OVERFLOW
	dump("defined", 1);
	if ((EAI_OVERFLOW) <= 0) {
	    long long x = (long long)(EAI_OVERFLOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_OVERFLOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_54(void) {
#ifdef EAI_PROTOCOL
	dump("defined", 1);
	if ((EAI_PROTOCOL) <= 0) {
	    long long x = (long long)(EAI_PROTOCOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_PROTOCOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_55(void) {
#ifdef EAI_SERVICE
	dump("defined", 1);
	if ((EAI_SERVICE) <= 0) {
	    long long x = (long long)(EAI_SERVICE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_SERVICE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_56(void) {
#ifdef EAI_SOCKTYPE
	dump("defined", 1);
	if ((EAI_SOCKTYPE) <= 0) {
	    long long x = (long long)(EAI_SOCKTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_SOCKTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_57(void) {
#ifdef EAI_SYSTEM
	dump("defined", 1);
	if ((EAI_SYSTEM) <= 0) {
	    long long x = (long long)(EAI_SYSTEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_SYSTEM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_58(void) {
#ifdef EINPROGRESS
	dump("defined", 1);
	if ((EINPROGRESS) <= 0) {
	    long long x = (long long)(EINPROGRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINPROGRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_59(void) {
#ifdef EINTR
	dump("defined", 1);
	if ((EINTR) <= 0) {
	    long long x = (long long)(EINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_60(void) {
#ifdef EISCONN
	dump("defined", 1);
	if ((EISCONN) <= 0) {
	    long long x = (long long)(EISCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EISCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_61(void) {
#ifdef EWOULDBLOCK
	dump("defined", 1);
	if ((EWOULDBLOCK) <= 0) {
	    long long x = (long long)(EWOULDBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EWOULDBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_62(void) {
#ifdef FD_ACCEPT
	dump("defined", 1);
	if ((FD_ACCEPT) <= 0) {
	    long long x = (long long)(FD_ACCEPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_ACCEPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_63(void) {
#ifdef FD_CLOSE
	dump("defined", 1);
	if ((FD_CLOSE) <= 0) {
	    long long x = (long long)(FD_CLOSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CLOSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_64(void) {
#ifdef FD_CLOSE_BIT
	dump("defined", 1);
	if ((FD_CLOSE_BIT) <= 0) {
	    long long x = (long long)(FD_CLOSE_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CLOSE_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_65(void) {
#ifdef FD_CONNECT
	dump("defined", 1);
	if ((FD_CONNECT) <= 0) {
	    long long x = (long long)(FD_CONNECT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CONNECT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_66(void) {
#ifdef FD_CONNECT_BIT
	dump("defined", 1);
	if ((FD_CONNECT_BIT) <= 0) {
	    long long x = (long long)(FD_CONNECT_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CONNECT_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_67(void) {
#ifdef FD_READ
	dump("defined", 1);
	if ((FD_READ) <= 0) {
	    long long x = (long long)(FD_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_READ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_68(void) {
#ifdef FD_SETSIZE
	dump("defined", 1);
	if ((FD_SETSIZE) <= 0) {
	    long long x = (long long)(FD_SETSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_SETSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_69(void) {
#ifdef FD_WRITE
	dump("defined", 1);
	if ((FD_WRITE) <= 0) {
	    long long x = (long long)(FD_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_WRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_70(void) {
#ifdef FIONBIO
	dump("defined", 1);
	if ((FIONBIO) <= 0) {
	    long long x = (long long)(FIONBIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONBIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_71(void) {
#ifdef F_GETFL
	dump("defined", 1);
	if ((F_GETFL) <= 0) {
	    long long x = (long long)(F_GETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_72(void) {
#ifdef F_SETFL
	dump("defined", 1);
	if ((F_SETFL) <= 0) {
	    long long x = (long long)(F_SETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_73(void) {
#ifdef INADDR_ALLHOSTS_GROUP
	dump("defined", 1);
	if ((INADDR_ALLHOSTS_GROUP) <= 0) {
	    long long x = (long long)(INADDR_ALLHOSTS_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_ALLHOSTS_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_74(void) {
#ifdef INADDR_ANY
	dump("defined", 1);
	if ((INADDR_ANY) <= 0) {
	    long long x = (long long)(INADDR_ANY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_ANY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_75(void) {
#ifdef INADDR_BROADCAST
	dump("defined", 1);
	if ((INADDR_BROADCAST) <= 0) {
	    long long x = (long long)(INADDR_BROADCAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_BROADCAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_76(void) {
#ifdef INADDR_LOOPBACK
	dump("defined", 1);
	if ((INADDR_LOOPBACK) <= 0) {
	    long long x = (long long)(INADDR_LOOPBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_LOOPBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_77(void) {
#ifdef INADDR_MAX_LOCAL_GROUP
	dump("defined", 1);
	if ((INADDR_MAX_LOCAL_GROUP) <= 0) {
	    long long x = (long long)(INADDR_MAX_LOCAL_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_MAX_LOCAL_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_78(void) {
#ifdef INADDR_NONE
	dump("defined", 1);
	if ((INADDR_NONE) <= 0) {
	    long long x = (long long)(INADDR_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_NONE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_79(void) {
#ifdef INADDR_UNSPEC_GROUP
	dump("defined", 1);
	if ((INADDR_UNSPEC_GROUP) <= 0) {
	    long long x = (long long)(INADDR_UNSPEC_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_UNSPEC_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_80(void) {
#ifdef INET6_ADDRSTRLEN
	dump("defined", 1);
	if ((INET6_ADDRSTRLEN) <= 0) {
	    long long x = (long long)(INET6_ADDRSTRLEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INET6_ADDRSTRLEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_81(void) {
#ifdef INET_ADDRSTRLEN
	dump("defined", 1);
	if ((INET_ADDRSTRLEN) <= 0) {
	    long long x = (long long)(INET_ADDRSTRLEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INET_ADDRSTRLEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_82(void) {
#ifdef INFINITE
	dump("defined", 1);
	if ((INFINITE) <= 0) {
	    long long x = (long long)(INFINITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INFINITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_83(void) {
#ifdef INVALID_SOCKET
	dump("defined", 1);
	if ((INVALID_SOCKET) <= 0) {
	    long long x = (long long)(INVALID_SOCKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INVALID_SOCKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_84(void) {
#ifdef IPPORT_RESERVED
	dump("defined", 1);
	if ((IPPORT_RESERVED) <= 0) {
	    long long x = (long long)(IPPORT_RESERVED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPORT_RESERVED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_85(void) {
#ifdef IPPORT_USERRESERVED
	dump("defined", 1);
	if ((IPPORT_USERRESERVED) <= 0) {
	    long long x = (long long)(IPPORT_USERRESERVED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPORT_USERRESERVED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_86(void) {
#ifdef IPPROTO_AH
	dump("defined", 1);
	if ((IPPROTO_AH) <= 0) {
	    long long x = (long long)(IPPROTO_AH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_AH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_87(void) {
#ifdef IPPROTO_BIP
	dump("defined", 1);
	if ((IPPROTO_BIP) <= 0) {
	    long long x = (long long)(IPPROTO_BIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_BIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_88(void) {
#ifdef IPPROTO_DSTOPTS
	dump("defined", 1);
	if ((IPPROTO_DSTOPTS) <= 0) {
	    long long x = (long long)(IPPROTO_DSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_DSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_89(void) {
#ifdef IPPROTO_EGP
	dump("defined", 1);
	if ((IPPROTO_EGP) <= 0) {
	    long long x = (long long)(IPPROTO_EGP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_EGP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_90(void) {
#ifdef IPPROTO_EON
	dump("defined", 1);
	if ((IPPROTO_EON) <= 0) {
	    long long x = (long long)(IPPROTO_EON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_EON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_91(void) {
#ifdef IPPROTO_ESP
	dump("defined", 1);
	if ((IPPROTO_ESP) <= 0) {
	    long long x = (long long)(IPPROTO_ESP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ESP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_92(void) {
#ifdef IPPROTO_FRAGMENT
	dump("defined", 1);
	if ((IPPROTO_FRAGMENT) <= 0) {
	    long long x = (long long)(IPPROTO_FRAGMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_FRAGMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_93(void) {
#ifdef IPPROTO_GGP
	dump("defined", 1);
	if ((IPPROTO_GGP) <= 0) {
	    long long x = (long long)(IPPROTO_GGP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_GGP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_94(void) {
#ifdef IPPROTO_GRE
	dump("defined", 1);
	if ((IPPROTO_GRE) <= 0) {
	    long long x = (long long)(IPPROTO_GRE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_GRE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_95(void) {
#ifdef IPPROTO_HELLO
	dump("defined", 1);
	if ((IPPROTO_HELLO) <= 0) {
	    long long x = (long long)(IPPROTO_HELLO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_HELLO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_96(void) {
#ifdef IPPROTO_HOPOPTS
	dump("defined", 1);
	if ((IPPROTO_HOPOPTS) <= 0) {
	    long long x = (long long)(IPPROTO_HOPOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_HOPOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_97(void) {
#ifdef IPPROTO_ICMP
	dump("defined", 1);
	if ((IPPROTO_ICMP) <= 0) {
	    long long x = (long long)(IPPROTO_ICMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ICMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_98(void) {
#ifdef IPPROTO_ICMPV6
	dump("defined", 1);
	if ((IPPROTO_ICMPV6) <= 0) {
	    long long x = (long long)(IPPROTO_ICMPV6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ICMPV6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_99(void) {
#ifdef IPPROTO_IDP
	dump("defined", 1);
	if ((IPPROTO_IDP) <= 0) {
	    long long x = (long long)(IPPROTO_IDP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IDP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_100(void) {
#ifdef IPPROTO_IGMP
	dump("defined", 1);
	if ((IPPROTO_IGMP) <= 0) {
	    long long x = (long long)(IPPROTO_IGMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IGMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_101(void) {
#ifdef IPPROTO_IP
	dump("defined", 1);
	if ((IPPROTO_IP) <= 0) {
	    long long x = (long long)(IPPROTO_IP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_102(void) {
#ifdef IPPROTO_IPCOMP
	dump("defined", 1);
	if ((IPPROTO_IPCOMP) <= 0) {
	    long long x = (long long)(IPPROTO_IPCOMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPCOMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_103(void) {
#ifdef IPPROTO_IPIP
	dump("defined", 1);
	if ((IPPROTO_IPIP) <= 0) {
	    long long x = (long long)(IPPROTO_IPIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_104(void) {
#ifdef IPPROTO_IPV4
	dump("defined", 1);
	if ((IPPROTO_IPV4) <= 0) {
	    long long x = (long long)(IPPROTO_IPV4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPV4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_105(void) {
#ifdef IPPROTO_IPV6
	dump("defined", 1);
	if ((IPPROTO_IPV6) <= 0) {
	    long long x = (long long)(IPPROTO_IPV6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPV6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_106(void) {
#ifdef IPPROTO_MAX
	dump("defined", 1);
	if ((IPPROTO_MAX) <= 0) {
	    long long x = (long long)(IPPROTO_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_107(void) {
#ifdef IPPROTO_MOBILE
	dump("defined", 1);
	if ((IPPROTO_MOBILE) <= 0) {
	    long long x = (long long)(IPPROTO_MOBILE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_MOBILE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_108(void) {
#ifdef IPPROTO_ND
	dump("defined", 1);
	if ((IPPROTO_ND) <= 0) {
	    long long x = (long long)(IPPROTO_ND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_109(void) {
#ifdef IPPROTO_NONE
	dump("defined", 1);
	if ((IPPROTO_NONE) <= 0) {
	    long long x = (long long)(IPPROTO_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_NONE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_110(void) {
#ifdef IPPROTO_PIM
	dump("defined", 1);
	if ((IPPROTO_PIM) <= 0) {
	    long long x = (long long)(IPPROTO_PIM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_PIM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_111(void) {
#ifdef IPPROTO_PUP
	dump("defined", 1);
	if ((IPPROTO_PUP) <= 0) {
	    long long x = (long long)(IPPROTO_PUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_PUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_112(void) {
#ifdef IPPROTO_RAW
	dump("defined", 1);
	if ((IPPROTO_RAW) <= 0) {
	    long long x = (long long)(IPPROTO_RAW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_RAW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_113(void) {
#ifdef IPPROTO_ROUTING
	dump("defined", 1);
	if ((IPPROTO_ROUTING) <= 0) {
	    long long x = (long long)(IPPROTO_ROUTING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ROUTING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_114(void) {
#ifdef IPPROTO_RSVP
	dump("defined", 1);
	if ((IPPROTO_RSVP) <= 0) {
	    long long x = (long long)(IPPROTO_RSVP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_RSVP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_115(void) {
#ifdef IPPROTO_SCTP
	dump("defined", 1);
	if ((IPPROTO_SCTP) <= 0) {
	    long long x = (long long)(IPPROTO_SCTP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_SCTP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_116(void) {
#ifdef IPPROTO_TCP
	dump("defined", 1);
	if ((IPPROTO_TCP) <= 0) {
	    long long x = (long long)(IPPROTO_TCP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_TCP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_117(void) {
#ifdef IPPROTO_TP
	dump("defined", 1);
	if ((IPPROTO_TP) <= 0) {
	    long long x = (long long)(IPPROTO_TP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_TP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_118(void) {
#ifdef IPPROTO_UDP
	dump("defined", 1);
	if ((IPPROTO_UDP) <= 0) {
	    long long x = (long long)(IPPROTO_UDP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_UDP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_119(void) {
#ifdef IPPROTO_VRRP
	dump("defined", 1);
	if ((IPPROTO_VRRP) <= 0) {
	    long long x = (long long)(IPPROTO_VRRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_VRRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_120(void) {
#ifdef IPPROTO_XTP
	dump("defined", 1);
	if ((IPPROTO_XTP) <= 0) {
	    long long x = (long long)(IPPROTO_XTP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_XTP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_121(void) {
#ifdef IPV6_CHECKSUM
	dump("defined", 1);
	if ((IPV6_CHECKSUM) <= 0) {
	    long long x = (long long)(IPV6_CHECKSUM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_CHECKSUM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_122(void) {
#ifdef IPV6_DONTFRAG
	dump("defined", 1);
	if ((IPV6_DONTFRAG) <= 0) {
	    long long x = (long long)(IPV6_DONTFRAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_DONTFRAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_123(void) {
#ifdef IPV6_DSTOPTS
	dump("defined", 1);
	if ((IPV6_DSTOPTS) <= 0) {
	    long long x = (long long)(IPV6_DSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_DSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_124(void) {
#ifdef IPV6_HOPLIMIT
	dump("defined", 1);
	if ((IPV6_HOPLIMIT) <= 0) {
	    long long x = (long long)(IPV6_HOPLIMIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_HOPLIMIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_125(void) {
#ifdef IPV6_HOPOPTS
	dump("defined", 1);
	if ((IPV6_HOPOPTS) <= 0) {
	    long long x = (long long)(IPV6_HOPOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_HOPOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_126(void) {
#ifdef IPV6_JOIN_GROUP
	dump("defined", 1);
	if ((IPV6_JOIN_GROUP) <= 0) {
	    long long x = (long long)(IPV6_JOIN_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_JOIN_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_127(void) {
#ifdef IPV6_LEAVE_GROUP
	dump("defined", 1);
	if ((IPV6_LEAVE_GROUP) <= 0) {
	    long long x = (long long)(IPV6_LEAVE_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_LEAVE_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_128(void) {
#ifdef IPV6_MULTICAST_HOPS
	dump("defined", 1);
	if ((IPV6_MULTICAST_HOPS) <= 0) {
	    long long x = (long long)(IPV6_MULTICAST_HOPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_MULTICAST_HOPS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_129(void) {
#ifdef IPV6_MULTICAST_IF
	dump("defined", 1);
	if ((IPV6_MULTICAST_IF) <= 0) {
	    long long x = (long long)(IPV6_MULTICAST_IF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_MULTICAST_IF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_130(void) {
#ifdef IPV6_MULTICAST_LOOP
	dump("defined", 1);
	if ((IPV6_MULTICAST_LOOP) <= 0) {
	    long long x = (long long)(IPV6_MULTICAST_LOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_MULTICAST_LOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_131(void) {
#ifdef IPV6_NEXTHOP
	dump("defined", 1);
	if ((IPV6_NEXTHOP) <= 0) {
	    long long x = (long long)(IPV6_NEXTHOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_NEXTHOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_132(void) {
#ifdef IPV6_PATHMTU
	dump("defined", 1);
	if ((IPV6_PATHMTU) <= 0) {
	    long long x = (long long)(IPV6_PATHMTU);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_PATHMTU);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_133(void) {
#ifdef IPV6_PKTINFO
	dump("defined", 1);
	if ((IPV6_PKTINFO) <= 0) {
	    long long x = (long long)(IPV6_PKTINFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_PKTINFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_134(void) {
#ifdef IPV6_RECVDSTOPTS
	dump("defined", 1);
	if ((IPV6_RECVDSTOPTS) <= 0) {
	    long long x = (long long)(IPV6_RECVDSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVDSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_135(void) {
#ifdef IPV6_RECVHOPLIMIT
	dump("defined", 1);
	if ((IPV6_RECVHOPLIMIT) <= 0) {
	    long long x = (long long)(IPV6_RECVHOPLIMIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVHOPLIMIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_136(void) {
#ifdef IPV6_RECVHOPOPTS
	dump("defined", 1);
	if ((IPV6_RECVHOPOPTS) <= 0) {
	    long long x = (long long)(IPV6_RECVHOPOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVHOPOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_137(void) {
#ifdef IPV6_RECVPATHMTU
	dump("defined", 1);
	if ((IPV6_RECVPATHMTU) <= 0) {
	    long long x = (long long)(IPV6_RECVPATHMTU);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVPATHMTU);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_138(void) {
#ifdef IPV6_RECVPKTINFO
	dump("defined", 1);
	if ((IPV6_RECVPKTINFO) <= 0) {
	    long long x = (long long)(IPV6_RECVPKTINFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVPKTINFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_139(void) {
#ifdef IPV6_RECVRTHDR
	dump("defined", 1);
	if ((IPV6_RECVRTHDR) <= 0) {
	    long long x = (long long)(IPV6_RECVRTHDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVRTHDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_140(void) {
#ifdef IPV6_RECVTCLASS
	dump("defined", 1);
	if ((IPV6_RECVTCLASS) <= 0) {
	    long long x = (long long)(IPV6_RECVTCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVTCLASS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_141(void) {
#ifdef IPV6_RTHDR
	dump("defined", 1);
	if ((IPV6_RTHDR) <= 0) {
	    long long x = (long long)(IPV6_RTHDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RTHDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_142(void) {
#ifdef IPV6_RTHDRDSTOPTS
	dump("defined", 1);
	if ((IPV6_RTHDRDSTOPTS) <= 0) {
	    long long x = (long long)(IPV6_RTHDRDSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RTHDRDSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_143(void) {
#ifdef IPV6_RTHDR_TYPE_0
	dump("defined", 1);
	if ((IPV6_RTHDR_TYPE_0) <= 0) {
	    long long x = (long long)(IPV6_RTHDR_TYPE_0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RTHDR_TYPE_0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_144(void) {
#ifdef IPV6_TCLASS
	dump("defined", 1);
	if ((IPV6_TCLASS) <= 0) {
	    long long x = (long long)(IPV6_TCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_TCLASS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_145(void) {
#ifdef IPV6_UNICAST_HOPS
	dump("defined", 1);
	if ((IPV6_UNICAST_HOPS) <= 0) {
	    long long x = (long long)(IPV6_UNICAST_HOPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_UNICAST_HOPS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_146(void) {
#ifdef IPV6_USE_MIN_MTU
	dump("defined", 1);
	if ((IPV6_USE_MIN_MTU) <= 0) {
	    long long x = (long long)(IPV6_USE_MIN_MTU);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_USE_MIN_MTU);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_147(void) {
#ifdef IPV6_V6ONLY
	dump("defined", 1);
	if ((IPV6_V6ONLY) <= 0) {
	    long long x = (long long)(IPV6_V6ONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_V6ONLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_148(void) {
#ifdef IPX_TYPE
	dump("defined", 1);
	if ((IPX_TYPE) <= 0) {
	    long long x = (long long)(IPX_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPX_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_149(void) {
#ifdef IP_ADD_MEMBERSHIP
	dump("defined", 1);
	if ((IP_ADD_MEMBERSHIP) <= 0) {
	    long long x = (long long)(IP_ADD_MEMBERSHIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_ADD_MEMBERSHIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_150(void) {
#ifdef IP_DEFAULT_MULTICAST_LOOP
	dump("defined", 1);
	if ((IP_DEFAULT_MULTICAST_LOOP) <= 0) {
	    long long x = (long long)(IP_DEFAULT_MULTICAST_LOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_DEFAULT_MULTICAST_LOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_151(void) {
#ifdef IP_DEFAULT_MULTICAST_TTL
	dump("defined", 1);
	if ((IP_DEFAULT_MULTICAST_TTL) <= 0) {
	    long long x = (long long)(IP_DEFAULT_MULTICAST_TTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_DEFAULT_MULTICAST_TTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_152(void) {
#ifdef IP_DROP_MEMBERSHIP
	dump("defined", 1);
	if ((IP_DROP_MEMBERSHIP) <= 0) {
	    long long x = (long long)(IP_DROP_MEMBERSHIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_DROP_MEMBERSHIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_153(void) {
#ifdef IP_HDRINCL
	dump("defined", 1);
	if ((IP_HDRINCL) <= 0) {
	    long long x = (long long)(IP_HDRINCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_HDRINCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_154(void) {
#ifdef IP_MAX_MEMBERSHIPS
	dump("defined", 1);
	if ((IP_MAX_MEMBERSHIPS) <= 0) {
	    long long x = (long long)(IP_MAX_MEMBERSHIPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MAX_MEMBERSHIPS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_155(void) {
#ifdef IP_MULTICAST_IF
	dump("defined", 1);
	if ((IP_MULTICAST_IF) <= 0) {
	    long long x = (long long)(IP_MULTICAST_IF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MULTICAST_IF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_156(void) {
#ifdef IP_MULTICAST_LOOP
	dump("defined", 1);
	if ((IP_MULTICAST_LOOP) <= 0) {
	    long long x = (long long)(IP_MULTICAST_LOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MULTICAST_LOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_157(void) {
#ifdef IP_MULTICAST_TTL
	dump("defined", 1);
	if ((IP_MULTICAST_TTL) <= 0) {
	    long long x = (long long)(IP_MULTICAST_TTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MULTICAST_TTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_158(void) {
#ifdef IP_OPTIONS
	dump("defined", 1);
	if ((IP_OPTIONS) <= 0) {
	    long long x = (long long)(IP_OPTIONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_OPTIONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_159(void) {
#ifdef IP_RECVDSTADDR
	dump("defined", 1);
	if ((IP_RECVDSTADDR) <= 0) {
	    long long x = (long long)(IP_RECVDSTADDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RECVDSTADDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_160(void) {
#ifdef IP_RECVOPTS
	dump("defined", 1);
	if ((IP_RECVOPTS) <= 0) {
	    long long x = (long long)(IP_RECVOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RECVOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_161(void) {
#ifdef IP_RECVRETOPTS
	dump("defined", 1);
	if ((IP_RECVRETOPTS) <= 0) {
	    long long x = (long long)(IP_RECVRETOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RECVRETOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_162(void) {
#ifdef IP_RETOPTS
	dump("defined", 1);
	if ((IP_RETOPTS) <= 0) {
	    long long x = (long long)(IP_RETOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RETOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_163(void) {
#ifdef IP_TOS
	dump("defined", 1);
	if ((IP_TOS) <= 0) {
	    long long x = (long long)(IP_TOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_TOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_164(void) {
#ifdef IP_TTL
	dump("defined", 1);
	if ((IP_TTL) <= 0) {
	    long long x = (long long)(IP_TTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_TTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_165(void) {
#ifdef MSG_BTAG
	dump("defined", 1);
	if ((MSG_BTAG) <= 0) {
	    long long x = (long long)(MSG_BTAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_BTAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_166(void) {
#ifdef MSG_CTRUNC
	dump("defined", 1);
	if ((MSG_CTRUNC) <= 0) {
	    long long x = (long long)(MSG_CTRUNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_CTRUNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_167(void) {
#ifdef MSG_DONTROUTE
	dump("defined", 1);
	if ((MSG_DONTROUTE) <= 0) {
	    long long x = (long long)(MSG_DONTROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_DONTROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_168(void) {
#ifdef MSG_DONTWAIT
	dump("defined", 1);
	if ((MSG_DONTWAIT) <= 0) {
	    long long x = (long long)(MSG_DONTWAIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_DONTWAIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_169(void) {
#ifdef MSG_EOR
	dump("defined", 1);
	if ((MSG_EOR) <= 0) {
	    long long x = (long long)(MSG_EOR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_EOR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_170(void) {
#ifdef MSG_ERRQUEUE
	dump("defined", 1);
	if ((MSG_ERRQUEUE) <= 0) {
	    long long x = (long long)(MSG_ERRQUEUE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_ERRQUEUE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_171(void) {
#ifdef MSG_ETAG
	dump("defined", 1);
	if ((MSG_ETAG) <= 0) {
	    long long x = (long long)(MSG_ETAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_ETAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_172(void) {
#ifdef MSG_OOB
	dump("defined", 1);
	if ((MSG_OOB) <= 0) {
	    long long x = (long long)(MSG_OOB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_OOB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_173(void) {
#ifdef MSG_PEEK
	dump("defined", 1);
	if ((MSG_PEEK) <= 0) {
	    long long x = (long long)(MSG_PEEK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_PEEK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_174(void) {
#ifdef MSG_TRUNC
	dump("defined", 1);
	if ((MSG_TRUNC) <= 0) {
	    long long x = (long long)(MSG_TRUNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_TRUNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_175(void) {
#ifdef MSG_WAITALL
	dump("defined", 1);
	if ((MSG_WAITALL) <= 0) {
	    long long x = (long long)(MSG_WAITALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_WAITALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_176(void) {
#ifdef NETLINK_ARPD
	dump("defined", 1);
	if ((NETLINK_ARPD) <= 0) {
	    long long x = (long long)(NETLINK_ARPD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_ARPD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_177(void) {
#ifdef NETLINK_DNRTMSG
	dump("defined", 1);
	if ((NETLINK_DNRTMSG) <= 0) {
	    long long x = (long long)(NETLINK_DNRTMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_DNRTMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_178(void) {
#ifdef NETLINK_FIREWALL
	dump("defined", 1);
	if ((NETLINK_FIREWALL) <= 0) {
	    long long x = (long long)(NETLINK_FIREWALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_FIREWALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_179(void) {
#ifdef NETLINK_IP6_FW
	dump("defined", 1);
	if ((NETLINK_IP6_FW) <= 0) {
	    long long x = (long long)(NETLINK_IP6_FW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_IP6_FW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_180(void) {
#ifdef NETLINK_NFLOG
	dump("defined", 1);
	if ((NETLINK_NFLOG) <= 0) {
	    long long x = (long long)(NETLINK_NFLOG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_NFLOG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_181(void) {
#ifdef NETLINK_ROUTE
	dump("defined", 1);
	if ((NETLINK_ROUTE) <= 0) {
	    long long x = (long long)(NETLINK_ROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_ROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_182(void) {
#ifdef NETLINK_ROUTE6
	dump("defined", 1);
	if ((NETLINK_ROUTE6) <= 0) {
	    long long x = (long long)(NETLINK_ROUTE6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_ROUTE6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_183(void) {
#ifdef NETLINK_SKIP
	dump("defined", 1);
	if ((NETLINK_SKIP) <= 0) {
	    long long x = (long long)(NETLINK_SKIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_SKIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_184(void) {
#ifdef NETLINK_TAPBASE
	dump("defined", 1);
	if ((NETLINK_TAPBASE) <= 0) {
	    long long x = (long long)(NETLINK_TAPBASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_TAPBASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_185(void) {
#ifdef NETLINK_TCPDIAG
	dump("defined", 1);
	if ((NETLINK_TCPDIAG) <= 0) {
	    long long x = (long long)(NETLINK_TCPDIAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_TCPDIAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_186(void) {
#ifdef NETLINK_USERSOCK
	dump("defined", 1);
	if ((NETLINK_USERSOCK) <= 0) {
	    long long x = (long long)(NETLINK_USERSOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_USERSOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_187(void) {
#ifdef NETLINK_W1
	dump("defined", 1);
	if ((NETLINK_W1) <= 0) {
	    long long x = (long long)(NETLINK_W1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_W1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_188(void) {
#ifdef NETLINK_XFRM
	dump("defined", 1);
	if ((NETLINK_XFRM) <= 0) {
	    long long x = (long long)(NETLINK_XFRM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_XFRM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_189(void) {
#ifdef NI_DGRAM
	dump("defined", 1);
	if ((NI_DGRAM) <= 0) {
	    long long x = (long long)(NI_DGRAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_DGRAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_190(void) {
#ifdef NI_MAXHOST
	dump("defined", 1);
	if ((NI_MAXHOST) <= 0) {
	    long long x = (long long)(NI_MAXHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_MAXHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_191(void) {
#ifdef NI_MAXSERV
	dump("defined", 1);
	if ((NI_MAXSERV) <= 0) {
	    long long x = (long long)(NI_MAXSERV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_MAXSERV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_192(void) {
#ifdef NI_NAMEREQD
	dump("defined", 1);
	if ((NI_NAMEREQD) <= 0) {
	    long long x = (long long)(NI_NAMEREQD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NAMEREQD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_193(void) {
#ifdef NI_NOFQDN
	dump("defined", 1);
	if ((NI_NOFQDN) <= 0) {
	    long long x = (long long)(NI_NOFQDN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NOFQDN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_194(void) {
#ifdef NI_NUMERICHOST
	dump("defined", 1);
	if ((NI_NUMERICHOST) <= 0) {
	    long long x = (long long)(NI_NUMERICHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NUMERICHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_195(void) {
#ifdef NI_NUMERICSERV
	dump("defined", 1);
	if ((NI_NUMERICSERV) <= 0) {
	    long long x = (long long)(NI_NUMERICSERV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NUMERICSERV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_196(void) {
#ifdef O_NONBLOCK
	dump("defined", 1);
	if ((O_NONBLOCK) <= 0) {
	    long long x = (long long)(O_NONBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_NONBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_197(void) {
#ifdef O_RDONLY
	dump("defined", 1);
	if ((O_RDONLY) <= 0) {
	    long long x = (long long)(O_RDONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_RDONLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_198(void) {
#ifdef O_RDWR
	dump("defined", 1);
	if ((O_RDWR) <= 0) {
	    long long x = (long long)(O_RDWR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_RDWR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_199(void) {
#ifdef O_WRONLY
	dump("defined", 1);
	if ((O_WRONLY) <= 0) {
	    long long x = (long long)(O_WRONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_WRONLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_200(void) {
#ifdef PACKET_BROADCAST
	dump("defined", 1);
	if ((PACKET_BROADCAST) <= 0) {
	    long long x = (long long)(PACKET_BROADCAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_BROADCAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_201(void) {
#ifdef PACKET_FASTROUTE
	dump("defined", 1);
	if ((PACKET_FASTROUTE) <= 0) {
	    long long x = (long long)(PACKET_FASTROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_FASTROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_202(void) {
#ifdef PACKET_HOST
	dump("defined", 1);
	if ((PACKET_HOST) <= 0) {
	    long long x = (long long)(PACKET_HOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_HOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_203(void) {
#ifdef PACKET_LOOPBACK
	dump("defined", 1);
	if ((PACKET_LOOPBACK) <= 0) {
	    long long x = (long long)(PACKET_LOOPBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_LOOPBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_204(void) {
#ifdef PACKET_MULTICAST
	dump("defined", 1);
	if ((PACKET_MULTICAST) <= 0) {
	    long long x = (long long)(PACKET_MULTICAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_MULTICAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_205(void) {
#ifdef PACKET_OTHERHOST
	dump("defined", 1);
	if ((PACKET_OTHERHOST) <= 0) {
	    long long x = (long long)(PACKET_OTHERHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_OTHERHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_206(void) {
#ifdef PACKET_OUTGOING
	dump("defined", 1);
	if ((PACKET_OUTGOING) <= 0) {
	    long long x = (long long)(PACKET_OUTGOING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_OUTGOING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_207(void) {
#ifdef PIPE_BUF
	dump("defined", 1);
	if ((PIPE_BUF) <= 0) {
	    long long x = (long long)(PIPE_BUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PIPE_BUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_208(void) {
#ifdef POLLERR
	dump("defined", 1);
	if ((POLLERR) <= 0) {
	    long long x = (long long)(POLLERR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLERR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_209(void) {
#ifdef POLLHUP
	dump("defined", 1);
	if ((POLLHUP) <= 0) {
	    long long x = (long long)(POLLHUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLHUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_210(void) {
#ifdef POLLIN
	dump("defined", 1);
	if ((POLLIN) <= 0) {
	    long long x = (long long)(POLLIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_211(void) {
#ifdef POLLMSG
	dump("defined", 1);
	if ((POLLMSG) <= 0) {
	    long long x = (long long)(POLLMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_212(void) {
#ifdef POLLNVAL
	dump("defined", 1);
	if ((POLLNVAL) <= 0) {
	    long long x = (long long)(POLLNVAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLNVAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_213(void) {
#ifdef POLLOUT
	dump("defined", 1);
	if ((POLLOUT) <= 0) {
	    long long x = (long long)(POLLOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_214(void) {
#ifdef POLLPRI
	dump("defined", 1);
	if ((POLLPRI) <= 0) {
	    long long x = (long long)(POLLPRI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLPRI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_215(void) {
#ifdef POLLRDBAND
	dump("defined", 1);
	if ((POLLRDBAND) <= 0) {
	    long long x = (long long)(POLLRDBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLRDBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_216(void) {
#ifdef POLLRDNORM
	dump("defined", 1);
	if ((POLLRDNORM) <= 0) {
	    long long x = (long long)(POLLRDNORM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLRDNORM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_217(void) {
#ifdef POLLWEBAND
	dump("defined", 1);
	if ((POLLWEBAND) <= 0) {
	    long long x = (long long)(POLLWEBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLWEBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_218(void) {
#ifdef POLLWRNORM
	dump("defined", 1);
	if ((POLLWRNORM) <= 0) {
	    long long x = (long long)(POLLWRNORM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLWRNORM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_219(void) {
#ifdef SCM_RIGHTS
	dump("defined", 1);
	if ((SCM_RIGHTS) <= 0) {
	    long long x = (long long)(SCM_RIGHTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SCM_RIGHTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_220(void) {
#ifdef SHUT_RD
	dump("defined", 1);
	if ((SHUT_RD) <= 0) {
	    long long x = (long long)(SHUT_RD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SHUT_RD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_221(void) {
#ifdef SHUT_RDWR
	dump("defined", 1);
	if ((SHUT_RDWR) <= 0) {
	    long long x = (long long)(SHUT_RDWR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SHUT_RDWR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_222(void) {
#ifdef SHUT_WR
	dump("defined", 1);
	if ((SHUT_WR) <= 0) {
	    long long x = (long long)(SHUT_WR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SHUT_WR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_223(void) {
#ifdef SIOCGIFINDEX
	dump("defined", 1);
	if ((SIOCGIFINDEX) <= 0) {
	    long long x = (long long)(SIOCGIFINDEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIOCGIFINDEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_224(void) {
#ifdef SIOCGIFNAME
	dump("defined", 1);
	if ((SIOCGIFNAME) <= 0) {
	    long long x = (long long)(SIOCGIFNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIOCGIFNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_225(void) {
#ifdef SIO_KEEPALIVE_VALS
	dump("defined", 1);
	if ((SIO_KEEPALIVE_VALS) <= 0) {
	    long long x = (long long)(SIO_KEEPALIVE_VALS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIO_KEEPALIVE_VALS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_226(void) {
#ifdef SIO_RCVALL
	dump("defined", 1);
	if ((SIO_RCVALL) <= 0) {
	    long long x = (long long)(SIO_RCVALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIO_RCVALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_227(void) {
#ifdef SOCK_CLOEXEC
	dump("defined", 1);
	if ((SOCK_CLOEXEC) <= 0) {
	    long long x = (long long)(SOCK_CLOEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_CLOEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_228(void) {
#ifdef SOCK_DGRAM
	dump("defined", 1);
	if ((SOCK_DGRAM) <= 0) {
	    long long x = (long long)(SOCK_DGRAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_DGRAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_229(void) {
#ifdef SOCK_NONBLOCK
	dump("defined", 1);
	if ((SOCK_NONBLOCK) <= 0) {
	    long long x = (long long)(SOCK_NONBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_NONBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_230(void) {
#ifdef SOCK_RAW
	dump("defined", 1);
	if ((SOCK_RAW) <= 0) {
	    long long x = (long long)(SOCK_RAW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_RAW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_231(void) {
#ifdef SOCK_RDM
	dump("defined", 1);
	if ((SOCK_RDM) <= 0) {
	    long long x = (long long)(SOCK_RDM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_RDM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_232(void) {
#ifdef SOCK_SEQPACKET
	dump("defined", 1);
	if ((SOCK_SEQPACKET) <= 0) {
	    long long x = (long long)(SOCK_SEQPACKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_SEQPACKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_233(void) {
#ifdef SOCK_STREAM
	dump("defined", 1);
	if ((SOCK_STREAM) <= 0) {
	    long long x = (long long)(SOCK_STREAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_STREAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_234(void) {
#ifdef SOL_ATALK
	dump("defined", 1);
	if ((SOL_ATALK) <= 0) {
	    long long x = (long long)(SOL_ATALK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_ATALK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_235(void) {
#ifdef SOL_AX25
	dump("defined", 1);
	if ((SOL_AX25) <= 0) {
	    long long x = (long long)(SOL_AX25);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_AX25);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_236(void) {
#ifdef SOL_IP
	dump("defined", 1);
	if ((SOL_IP) <= 0) {
	    long long x = (long long)(SOL_IP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_IP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_237(void) {
#ifdef SOL_IPX
	dump("defined", 1);
	if ((SOL_IPX) <= 0) {
	    long long x = (long long)(SOL_IPX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_IPX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_238(void) {
#ifdef SOL_NETROM
	dump("defined", 1);
	if ((SOL_NETROM) <= 0) {
	    long long x = (long long)(SOL_NETROM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_NETROM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_239(void) {
#ifdef SOL_ROSE
	dump("defined", 1);
	if ((SOL_ROSE) <= 0) {
	    long long x = (long long)(SOL_ROSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_ROSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_240(void) {
#ifdef SOL_SOCKET
	dump("defined", 1);
	if ((SOL_SOCKET) <= 0) {
	    long long x = (long long)(SOL_SOCKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_SOCKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_241(void) {
#ifdef SOL_TCP
	dump("defined", 1);
	if ((SOL_TCP) <= 0) {
	    long long x = (long long)(SOL_TCP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_TCP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_242(void) {
#ifdef SOL_UDP
	dump("defined", 1);
	if ((SOL_UDP) <= 0) {
	    long long x = (long long)(SOL_UDP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_UDP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_243(void) {
#ifdef SOMAXCONN
	dump("defined", 1);
	if ((SOMAXCONN) <= 0) {
	    long long x = (long long)(SOMAXCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOMAXCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_244(void) {
#ifdef SO_ACCEPTCONN
	dump("defined", 1);
	if ((SO_ACCEPTCONN) <= 0) {
	    long long x = (long long)(SO_ACCEPTCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_ACCEPTCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_245(void) {
#ifdef SO_BROADCAST
	dump("defined", 1);
	if ((SO_BROADCAST) <= 0) {
	    long long x = (long long)(SO_BROADCAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_BROADCAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_246(void) {
#ifdef SO_DEBUG
	dump("defined", 1);
	if ((SO_DEBUG) <= 0) {
	    long long x = (long long)(SO_DEBUG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_DEBUG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_247(void) {
#ifdef SO_DOMAIN
	dump("defined", 1);
	if ((SO_DOMAIN) <= 0) {
	    long long x = (long long)(SO_DOMAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_DOMAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_248(void) {
#ifdef SO_DONTROUTE
	dump("defined", 1);
	if ((SO_DONTROUTE) <= 0) {
	    long long x = (long long)(SO_DONTROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_DONTROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_249(void) {
#ifdef SO_ERROR
	dump("defined", 1);
	if ((SO_ERROR) <= 0) {
	    long long x = (long long)(SO_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_250(void) {
#ifdef SO_EXCLUSIVEADDRUSE
	dump("defined", 1);
	if ((SO_EXCLUSIVEADDRUSE) <= 0) {
	    long long x = (long long)(SO_EXCLUSIVEADDRUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_EXCLUSIVEADDRUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_251(void) {
#ifdef SO_KEEPALIVE
	dump("defined", 1);
	if ((SO_KEEPALIVE) <= 0) {
	    long long x = (long long)(SO_KEEPALIVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_KEEPALIVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_252(void) {
#ifdef SO_LINGER
	dump("defined", 1);
	if ((SO_LINGER) <= 0) {
	    long long x = (long long)(SO_LINGER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_LINGER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_253(void) {
#ifdef SO_OOBINLINE
	dump("defined", 1);
	if ((SO_OOBINLINE) <= 0) {
	    long long x = (long long)(SO_OOBINLINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_OOBINLINE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_254(void) {
#ifdef SO_PASSSEC
	dump("defined", 1);
	if ((SO_PASSSEC) <= 0) {
	    long long x = (long long)(SO_PASSSEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_PASSSEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_255(void) {
#ifdef SO_PEERSEC
	dump("defined", 1);
	if ((SO_PEERSEC) <= 0) {
	    long long x = (long long)(SO_PEERSEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_PEERSEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_256(void) {
#ifdef SO_PROTOCOL
	dump("defined", 1);
	if ((SO_PROTOCOL) <= 0) {
	    long long x = (long long)(SO_PROTOCOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_PROTOCOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_257(void) {
#ifdef SO_RCVBUF
	dump("defined", 1);
	if ((SO_RCVBUF) <= 0) {
	    long long x = (long long)(SO_RCVBUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_RCVBUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_258(void) {
#ifdef SO_RCVLOWAT
	dump("defined", 1);
	if ((SO_RCVLOWAT) <= 0) {
	    long long x = (long long)(SO_RCVLOWAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_RCVLOWAT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_259(void) {
#ifdef SO_RCVTIMEO
	dump("defined", 1);
	if ((SO_RCVTIMEO) <= 0) {
	    long long x = (long long)(SO_RCVTIMEO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_RCVTIMEO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_260(void) {
#ifdef SO_REUSEADDR
	dump("defined", 1);
	if ((SO_REUSEADDR) <= 0) {
	    long long x = (long long)(SO_REUSEADDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_REUSEADDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_261(void) {
#ifdef SO_REUSEPORT
	dump("defined", 1);
	if ((SO_REUSEPORT) <= 0) {
	    long long x = (long long)(SO_REUSEPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_REUSEPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_262(void) {
#ifdef SO_SNDBUF
	dump("defined", 1);
	if ((SO_SNDBUF) <= 0) {
	    long long x = (long long)(SO_SNDBUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_SNDBUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_263(void) {
#ifdef SO_SNDLOWAT
	dump("defined", 1);
	if ((SO_SNDLOWAT) <= 0) {
	    long long x = (long long)(SO_SNDLOWAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_SNDLOWAT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_264(void) {
#ifdef SO_SNDTIMEO
	dump("defined", 1);
	if ((SO_SNDTIMEO) <= 0) {
	    long long x = (long long)(SO_SNDTIMEO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_SNDTIMEO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_265(void) {
#ifdef SO_TYPE
	dump("defined", 1);
	if ((SO_TYPE) <= 0) {
	    long long x = (long long)(SO_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_266(void) {
#ifdef SO_USELOOPBACK
	dump("defined", 1);
	if ((SO_USELOOPBACK) <= 0) {
	    long long x = (long long)(SO_USELOOPBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_USELOOPBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_267(void) {
#ifdef TCP_CONGESTION
	dump("defined", 1);
	if ((TCP_CONGESTION) <= 0) {
	    long long x = (long long)(TCP_CONGESTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_CONGESTION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_268(void) {
#ifdef TCP_CORK
	dump("defined", 1);
	if ((TCP_CORK) <= 0) {
	    long long x = (long long)(TCP_CORK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_CORK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_269(void) {
#ifdef TCP_DEFER_ACCEPT
	dump("defined", 1);
	if ((TCP_DEFER_ACCEPT) <= 0) {
	    long long x = (long long)(TCP_DEFER_ACCEPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_DEFER_ACCEPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_270(void) {
#ifdef TCP_INFO
	dump("defined", 1);
	if ((TCP_INFO) <= 0) {
	    long long x = (long long)(TCP_INFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_INFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_271(void) {
#ifdef TCP_KEEPCNT
	dump("defined", 1);
	if ((TCP_KEEPCNT) <= 0) {
	    long long x = (long long)(TCP_KEEPCNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_KEEPCNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_272(void) {
#ifdef TCP_KEEPIDLE
	dump("defined", 1);
	if ((TCP_KEEPIDLE) <= 0) {
	    long long x = (long long)(TCP_KEEPIDLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_KEEPIDLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_273(void) {
#ifdef TCP_KEEPINTVL
	dump("defined", 1);
	if ((TCP_KEEPINTVL) <= 0) {
	    long long x = (long long)(TCP_KEEPINTVL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_KEEPINTVL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_274(void) {
#ifdef TCP_LINGER2
	dump("defined", 1);
	if ((TCP_LINGER2) <= 0) {
	    long long x = (long long)(TCP_LINGER2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_LINGER2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_275(void) {
#ifdef TCP_MAXSEG
	dump("defined", 1);
	if ((TCP_MAXSEG) <= 0) {
	    long long x = (long long)(TCP_MAXSEG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_MAXSEG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_276(void) {
#ifdef TCP_NODELAY
	dump("defined", 1);
	if ((TCP_NODELAY) <= 0) {
	    long long x = (long long)(TCP_NODELAY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_NODELAY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_277(void) {
#ifdef TCP_NOTSENT_LOWAT
	dump("defined", 1);
	if ((TCP_NOTSENT_LOWAT) <= 0) {
	    long long x = (long long)(TCP_NOTSENT_LOWAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_NOTSENT_LOWAT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_278(void) {
#ifdef TCP_QUICKACK
	dump("defined", 1);
	if ((TCP_QUICKACK) <= 0) {
	    long long x = (long long)(TCP_QUICKACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_QUICKACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_279(void) {
#ifdef TCP_SYNCNT
	dump("defined", 1);
	if ((TCP_SYNCNT) <= 0) {
	    long long x = (long long)(TCP_SYNCNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_SYNCNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_280(void) {
#ifdef TCP_USER_TIMEOUT
	dump("defined", 1);
	if ((TCP_USER_TIMEOUT) <= 0) {
	    long long x = (long long)(TCP_USER_TIMEOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_USER_TIMEOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_281(void) {
#ifdef TCP_WINDOW_CLAMP
	dump("defined", 1);
	if ((TCP_WINDOW_CLAMP) <= 0) {
	    long long x = (long long)(TCP_WINDOW_CLAMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_WINDOW_CLAMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_282(void) {
#ifdef _WIN32
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_283(void) {
#ifdef WSAEAFNOSUPPORT
	dump("defined", 1);
	if ((WSAEAFNOSUPPORT) <= 0) {
	    long long x = (long long)(WSAEAFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEAFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_284(void) {
#ifdef WSAEINPROGRESS
	dump("defined", 1);
	if ((WSAEINPROGRESS) <= 0) {
	    long long x = (long long)(WSAEINPROGRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINPROGRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_285(void) {
#ifdef WSAEINTR
	dump("defined", 1);
	if ((WSAEINTR) <= 0) {
	    long long x = (long long)(WSAEINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_286(void) {
#ifdef WSAEISCONN
	dump("defined", 1);
	if ((WSAEISCONN) <= 0) {
	    long long x = (long long)(WSAEISCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEISCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_287(void) {
#ifdef WSAEWOULDBLOCK
	dump("defined", 1);
	if ((WSAEWOULDBLOCK) <= 0) {
	    long long x = (long long)(WSAEWOULDBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEWOULDBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_288(void) {
#ifdef WSA_FLAG_OVERLAPPED
	dump("defined", 1);
	if ((WSA_FLAG_OVERLAPPED) <= 0) {
	    long long x = (long long)(WSA_FLAG_OVERLAPPED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_FLAG_OVERLAPPED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_289(void) {
#ifdef WSA_INVALID_HANDLE
	dump("defined", 1);
	if ((WSA_INVALID_HANDLE) <= 0) {
	    long long x = (long long)(WSA_INVALID_HANDLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_INVALID_HANDLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_290(void) {
#ifdef WSA_INVALID_PARAMETER
	dump("defined", 1);
	if ((WSA_INVALID_PARAMETER) <= 0) {
	    long long x = (long long)(WSA_INVALID_PARAMETER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_INVALID_PARAMETER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_291(void) {
#ifdef WSA_IO_INCOMPLETE
	dump("defined", 1);
	if ((WSA_IO_INCOMPLETE) <= 0) {
	    long long x = (long long)(WSA_IO_INCOMPLETE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_IO_INCOMPLETE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_292(void) {
#ifdef WSA_IO_PENDING
	dump("defined", 1);
	if ((WSA_IO_PENDING) <= 0) {
	    long long x = (long long)(WSA_IO_PENDING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_IO_PENDING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_293(void) {
#ifdef WSA_NOT_ENOUGH_MEMORY
	dump("defined", 1);
	if ((WSA_NOT_ENOUGH_MEMORY) <= 0) {
	    long long x = (long long)(WSA_NOT_ENOUGH_MEMORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_NOT_ENOUGH_MEMORY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_294(void) {
#ifdef WSA_OPERATION_ABORTED
	dump("defined", 1);
	if ((WSA_OPERATION_ABORTED) <= 0) {
	    long long x = (long long)(WSA_OPERATION_ABORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_OPERATION_ABORTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_295(void) {
#ifdef WSA_WAIT_FAILED
	dump("defined", 1);
	if ((WSA_WAIT_FAILED) <= 0) {
	    long long x = (long long)(WSA_WAIT_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_WAIT_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_296(void) {
#ifdef WSA_WAIT_TIMEOUT
	dump("defined", 1);
	if ((WSA_WAIT_TIMEOUT) <= 0) {
	    long long x = (long long)(WSA_WAIT_TIMEOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_WAIT_TIMEOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_297(void) {
	typedef struct addrinfo platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ai_flags", offsetof(platcheck_t, ai_flags));
	dump("fldsize ai_flags",   sizeof(s.ai_flags));
	s.ai_flags = 0; s.ai_flags = ~s.ai_flags;
	dump("fldunsigned ai_flags", s.ai_flags > 0);
	dump("fldofs ai_family", offsetof(platcheck_t, ai_family));
	dump("fldsize ai_family",   sizeof(s.ai_family));
	s.ai_family = 0; s.ai_family = ~s.ai_family;
	dump("fldunsigned ai_family", s.ai_family > 0);
	dump("fldofs ai_socktype", offsetof(platcheck_t, ai_socktype));
	dump("fldsize ai_socktype",   sizeof(s.ai_socktype));
	s.ai_socktype = 0; s.ai_socktype = ~s.ai_socktype;
	dump("fldunsigned ai_socktype", s.ai_socktype > 0);
	dump("fldofs ai_protocol", offsetof(platcheck_t, ai_protocol));
	dump("fldsize ai_protocol",   sizeof(s.ai_protocol));
	s.ai_protocol = 0; s.ai_protocol = ~s.ai_protocol;
	dump("fldunsigned ai_protocol", s.ai_protocol > 0);
	dump("fldofs ai_addrlen", offsetof(platcheck_t, ai_addrlen));
	dump("fldsize ai_addrlen",   sizeof(s.ai_addrlen));
	s.ai_addrlen = 0; s.ai_addrlen = ~s.ai_addrlen;
	dump("fldunsigned ai_addrlen", s.ai_addrlen > 0);
	dump("fldofs ai_addr", offsetof(platcheck_t, ai_addr));
	dump("fldsize ai_addr",   sizeof(s.ai_addr));
	dump("fldofs ai_canonname", offsetof(platcheck_t, ai_canonname));
	dump("fldsize ai_canonname",   sizeof(s.ai_canonname));
	dump("fldofs ai_next", offsetof(platcheck_t, ai_next));
	dump("fldsize ai_next",   sizeof(s.ai_next));
}

void dump_section_298(void) {
	typedef struct hostent platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs h_name", offsetof(platcheck_t, h_name));
	dump("fldsize h_name",   sizeof(s.h_name));
	dump("fldofs h_aliases", offsetof(platcheck_t, h_aliases));
	dump("fldsize h_aliases",   sizeof(s.h_aliases));
	dump("fldofs h_addrtype", offsetof(platcheck_t, h_addrtype));
	dump("fldsize h_addrtype",   sizeof(s.h_addrtype));
	s.h_addrtype = 0; s.h_addrtype = ~s.h_addrtype;
	dump("fldunsigned h_addrtype", s.h_addrtype > 0);
	dump("fldofs h_length", offsetof(platcheck_t, h_length));
	dump("fldsize h_length",   sizeof(s.h_length));
	s.h_length = 0; s.h_length = ~s.h_length;
	dump("fldunsigned h_length", s.h_length > 0);
	dump("fldofs h_addr_list", offsetof(platcheck_t, h_addr_list));
	dump("fldsize h_addr_list",   sizeof(s.h_addr_list));
}

void dump_section_299(void) {
	typedef struct if_nameindex platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs if_index", offsetof(platcheck_t, if_index));
	dump("fldsize if_index",   sizeof(s.if_index));
	s.if_index = 0; s.if_index = ~s.if_index;
	dump("fldunsigned if_index", s.if_index > 0);
	dump("fldofs if_name", offsetof(platcheck_t, if_name));
	dump("fldsize if_name",   sizeof(s.if_name));
}

void dump_section_300(void) {
	typedef struct ifreq platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ifr_ifindex", offsetof(platcheck_t, ifr_ifindex));
	dump("fldsize ifr_ifindex",   sizeof(s.ifr_ifindex));
	s.ifr_ifindex = 0; s.ifr_ifindex = ~s.ifr_ifindex;
	dump("fldunsigned ifr_ifindex", s.ifr_ifindex > 0);
	dump("fldofs ifr_name", offsetof(platcheck_t, ifr_name));
	dump("fldsize ifr_name",   sizeof(s.ifr_name));
}

void dump_section_301(void) {
	typedef struct in6_addr platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs s6_addr", offsetof(platcheck_t, s6_addr));
	dump("fldsize s6_addr",   sizeof(s.s6_addr));
}

void dump_section_302(void) {
	typedef struct in_addr platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs s_addr", offsetof(platcheck_t, s_addr));
	dump("fldsize s_addr",   sizeof(s.s_addr));
	s.s_addr = 0; s.s_addr = ~s.s_addr;
	dump("fldunsigned s_addr", s.s_addr > 0);
}

void dump_section_303(void) {
#ifdef linux
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_304(void) {
	typedef nfds_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_305(void) {
	typedef struct pollfd platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs fd", offsetof(platcheck_t, fd));
	dump("fldsize fd",   sizeof(s.fd));
	s.fd = 0; s.fd = ~s.fd;
	dump("fldunsigned fd", s.fd > 0);
	dump("fldofs events", offsetof(platcheck_t, events));
	dump("fldsize events",   sizeof(s.events));
	s.events = 0; s.events = ~s.events;
	dump("fldunsigned events", s.events > 0);
	dump("fldofs revents", offsetof(platcheck_t, revents));
	dump("fldsize revents",   sizeof(s.revents));
	s.revents = 0; s.revents = ~s.revents;
	dump("fldunsigned revents", s.revents > 0);
}

void dump_section_306(void) {
	typedef struct protoent platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs p_proto", offsetof(platcheck_t, p_proto));
	dump("fldsize p_proto",   sizeof(s.p_proto));
	s.p_proto = 0; s.p_proto = ~s.p_proto;
	dump("fldunsigned p_proto", s.p_proto > 0);
}

void dump_section_307(void) {
	typedef struct servent platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs s_name", offsetof(platcheck_t, s_name));
	dump("fldsize s_name",   sizeof(s.s_name));
	dump("fldofs s_port", offsetof(platcheck_t, s_port));
	dump("fldsize s_port",   sizeof(s.s_port));
	s.s_port = 0; s.s_port = ~s.s_port;
	dump("fldunsigned s_port", s.s_port > 0);
	dump("fldofs s_proto", offsetof(platcheck_t, s_proto));
	dump("fldsize s_proto",   sizeof(s.s_proto));
}

void dump_section_308(void) {
	typedef size_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_309(void) {
	typedef struct sockaddr platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sa_family", offsetof(platcheck_t, sa_family));
	dump("fldsize sa_family",   sizeof(s.sa_family));
	s.sa_family = 0; s.sa_family = ~s.sa_family;
	dump("fldunsigned sa_family", s.sa_family > 0);
	dump("fldofs sa_data", offsetof(platcheck_t, sa_data));
	dump("fldsize sa_data",   sizeof(s.sa_data));
}

void dump_section_310(void) {
	typedef struct sockaddr_in platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sin_family", offsetof(platcheck_t, sin_family));
	dump("fldsize sin_family",   sizeof(s.sin_family));
	s.sin_family = 0; s.sin_family = ~s.sin_family;
	dump("fldunsigned sin_family", s.sin_family > 0);
	dump("fldofs sin_port", offsetof(platcheck_t, sin_port));
	dump("fldsize sin_port",   sizeof(s.sin_port));
	s.sin_port = 0; s.sin_port = ~s.sin_port;
	dump("fldunsigned sin_port", s.sin_port > 0);
	dump("fldofs sin_addr", offsetof(platcheck_t, sin_addr));
	dump("fldsize sin_addr",   sizeof(s.sin_addr));
}

void dump_section_311(void) {
	typedef struct sockaddr_in6 platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sin6_family", offsetof(platcheck_t, sin6_family));
	dump("fldsize sin6_family",   sizeof(s.sin6_family));
	s.sin6_family = 0; s.sin6_family = ~s.sin6_family;
	dump("fldunsigned sin6_family", s.sin6_family > 0);
	dump("fldofs sin6_port", offsetof(platcheck_t, sin6_port));
	dump("fldsize sin6_port",   sizeof(s.sin6_port));
	s.sin6_port = 0; s.sin6_port = ~s.sin6_port;
	dump("fldunsigned sin6_port", s.sin6_port > 0);
	dump("fldofs sin6_flowinfo", offsetof(platcheck_t, sin6_flowinfo));
	dump("fldsize sin6_flowinfo",   sizeof(s.sin6_flowinfo));
	s.sin6_flowinfo = 0; s.sin6_flowinfo = ~s.sin6_flowinfo;
	dump("fldunsigned sin6_flowinfo", s.sin6_flowinfo > 0);
	dump("fldofs sin6_addr", offsetof(platcheck_t, sin6_addr));
	dump("fldsize sin6_addr",   sizeof(s.sin6_addr));
	dump("fldofs sin6_scope_id", offsetof(platcheck_t, sin6_scope_id));
	dump("fldsize sin6_scope_id",   sizeof(s.sin6_scope_id));
	s.sin6_scope_id = 0; s.sin6_scope_id = ~s.sin6_scope_id;
	dump("fldunsigned sin6_scope_id", s.sin6_scope_id > 0);
}

void dump_section_312(void) {
	typedef struct sockaddr_ll platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sll_family", offsetof(platcheck_t, sll_family));
	dump("fldsize sll_family",   sizeof(s.sll_family));
	s.sll_family = 0; s.sll_family = ~s.sll_family;
	dump("fldunsigned sll_family", s.sll_family > 0);
	dump("fldofs sll_ifindex", offsetof(platcheck_t, sll_ifindex));
	dump("fldsize sll_ifindex",   sizeof(s.sll_ifindex));
	s.sll_ifindex = 0; s.sll_ifindex = ~s.sll_ifindex;
	dump("fldunsigned sll_ifindex", s.sll_ifindex > 0);
	dump("fldofs sll_protocol", offsetof(platcheck_t, sll_protocol));
	dump("fldsize sll_protocol",   sizeof(s.sll_protocol));
	s.sll_protocol = 0; s.sll_protocol = ~s.sll_protocol;
	dump("fldunsigned sll_protocol", s.sll_protocol > 0);
	dump("fldofs sll_pkttype", offsetof(platcheck_t, sll_pkttype));
	dump("fldsize sll_pkttype",   sizeof(s.sll_pkttype));
	s.sll_pkttype = 0; s.sll_pkttype = ~s.sll_pkttype;
	dump("fldunsigned sll_pkttype", s.sll_pkttype > 0);
	dump("fldofs sll_hatype", offsetof(platcheck_t, sll_hatype));
	dump("fldsize sll_hatype",   sizeof(s.sll_hatype));
	s.sll_hatype = 0; s.sll_hatype = ~s.sll_hatype;
	dump("fldunsigned sll_hatype", s.sll_hatype > 0);
	dump("fldofs sll_addr", offsetof(platcheck_t, sll_addr));
	dump("fldsize sll_addr",   sizeof(s.sll_addr));
	dump("fldofs sll_halen", offsetof(platcheck_t, sll_halen));
	dump("fldsize sll_halen",   sizeof(s.sll_halen));
	s.sll_halen = 0; s.sll_halen = ~s.sll_halen;
	dump("fldunsigned sll_halen", s.sll_halen > 0);
}

void dump_section_313(void) {
#ifdef AF_NETLINK
	typedef struct sockaddr_nl platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("defined", 1);
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs nl_family", offsetof(platcheck_t, nl_family));
	dump("fldsize nl_family",   sizeof(s.nl_family));
	s.nl_family = 0; s.nl_family = ~s.nl_family;
	dump("fldunsigned nl_family", s.nl_family > 0);
	dump("fldofs nl_pid", offsetof(platcheck_t, nl_pid));
	dump("fldsize nl_pid",   sizeof(s.nl_pid));
	s.nl_pid = 0; s.nl_pid = ~s.nl_pid;
	dump("fldunsigned nl_pid", s.nl_pid > 0);
	dump("fldofs nl_groups", offsetof(platcheck_t, nl_groups));
	dump("fldsize nl_groups",   sizeof(s.nl_groups));
	s.nl_groups = 0; s.nl_groups = ~s.nl_groups;
	dump("fldunsigned nl_groups", s.nl_groups > 0);
#else
	dump("defined", 0);
#endif
}

void dump_section_314(void) {
#ifdef AF_UNIX
	typedef struct sockaddr_un platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("defined", 1);
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sun_family", offsetof(platcheck_t, sun_family));
	dump("fldsize sun_family",   sizeof(s.sun_family));
	s.sun_family = 0; s.sun_family = ~s.sun_family;
	dump("fldunsigned sun_family", s.sun_family > 0);
	dump("fldofs sun_path", offsetof(platcheck_t, sun_path));
	dump("fldsize sun_path",   sizeof(s.sun_path));
#else
	dump("defined", 0);
#endif
}

void dump_section_315(void) {
	typedef socklen_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_316(void) {
	typedef ssize_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_317(void) {
	typedef struct timeval platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs tv_sec", offsetof(platcheck_t, tv_sec));
	dump("fldsize tv_sec",   sizeof(s.tv_sec));
	s.tv_sec = 0; s.tv_sec = ~s.tv_sec;
	dump("fldunsigned tv_sec", s.tv_sec > 0);
	dump("fldofs tv_usec", offsetof(platcheck_t, tv_usec));
	dump("fldsize tv_usec",   sizeof(s.tv_usec));
	s.tv_usec = 0; s.tv_usec = ~s.tv_usec;
	dump("fldunsigned tv_usec", s.tv_usec > 0);
}

void dump_section_318(void) {
	typedef uint16_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_319(void) {
	typedef uint32_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	printf("-+- 68\n");
	dump_section_68();
	printf("---\n");
	printf("-+- 69\n");
	dump_section_69();
	printf("---\n");
	printf("-+- 70\n");
	dump_section_70();
	printf("---\n");
	printf("-+- 71\n");
	dump_section_71();
	printf("---\n");
	printf("-+- 72\n");
	dump_section_72();
	printf("---\n");
	printf("-+- 73\n");
	dump_section_73();
	printf("---\n");
	printf("-+- 74\n");
	dump_section_74();
	printf("---\n");
	printf("-+- 75\n");
	dump_section_75();
	printf("---\n");
	printf("-+- 76\n");
	dump_section_76();
	printf("---\n");
	printf("-+- 77\n");
	dump_section_77();
	printf("---\n");
	printf("-+- 78\n");
	dump_section_78();
	printf("---\n");
	printf("-+- 79\n");
	dump_section_79();
	printf("---\n");
	printf("-+- 80\n");
	dump_section_80();
	printf("---\n");
	printf("-+- 81\n");
	dump_section_81();
	printf("---\n");
	printf("-+- 82\n");
	dump_section_82();
	printf("---\n");
	printf("-+- 83\n");
	dump_section_83();
	printf("---\n");
	printf("-+- 84\n");
	dump_section_84();
	printf("---\n");
	printf("-+- 85\n");
	dump_section_85();
	printf("---\n");
	printf("-+- 86\n");
	dump_section_86();
	printf("---\n");
	printf("-+- 87\n");
	dump_section_87();
	printf("---\n");
	printf("-+- 88\n");
	dump_section_88();
	printf("---\n");
	printf("-+- 89\n");
	dump_section_89();
	printf("---\n");
	printf("-+- 90\n");
	dump_section_90();
	printf("---\n");
	printf("-+- 91\n");
	dump_section_91();
	printf("---\n");
	printf("-+- 92\n");
	dump_section_92();
	printf("---\n");
	printf("-+- 93\n");
	dump_section_93();
	printf("---\n");
	printf("-+- 94\n");
	dump_section_94();
	printf("---\n");
	printf("-+- 95\n");
	dump_section_95();
	printf("---\n");
	printf("-+- 96\n");
	dump_section_96();
	printf("---\n");
	printf("-+- 97\n");
	dump_section_97();
	printf("---\n");
	printf("-+- 98\n");
	dump_section_98();
	printf("---\n");
	printf("-+- 99\n");
	dump_section_99();
	printf("---\n");
	printf("-+- 100\n");
	dump_section_100();
	printf("---\n");
	printf("-+- 101\n");
	dump_section_101();
	printf("---\n");
	printf("-+- 102\n");
	dump_section_102();
	printf("---\n");
	printf("-+- 103\n");
	dump_section_103();
	printf("---\n");
	printf("-+- 104\n");
	dump_section_104();
	printf("---\n");
	printf("-+- 105\n");
	dump_section_105();
	printf("---\n");
	printf("-+- 106\n");
	dump_section_106();
	printf("---\n");
	printf("-+- 107\n");
	dump_section_107();
	printf("---\n");
	printf("-+- 108\n");
	dump_section_108();
	printf("---\n");
	printf("-+- 109\n");
	dump_section_109();
	printf("---\n");
	printf("-+- 110\n");
	dump_section_110();
	printf("---\n");
	printf("-+- 111\n");
	dump_section_111();
	printf("---\n");
	printf("-+- 112\n");
	dump_section_112();
	printf("---\n");
	printf("-+- 113\n");
	dump_section_113();
	printf("---\n");
	printf("-+- 114\n");
	dump_section_114();
	printf("---\n");
	printf("-+- 115\n");
	dump_section_115();
	printf("---\n");
	printf("-+- 116\n");
	dump_section_116();
	printf("---\n");
	printf("-+- 117\n");
	dump_section_117();
	printf("---\n");
	printf("-+- 118\n");
	dump_section_118();
	printf("---\n");
	printf("-+- 119\n");
	dump_section_119();
	printf("---\n");
	printf("-+- 120\n");
	dump_section_120();
	printf("---\n");
	printf("-+- 121\n");
	dump_section_121();
	printf("---\n");
	printf("-+- 122\n");
	dump_section_122();
	printf("---\n");
	printf("-+- 123\n");
	dump_section_123();
	printf("---\n");
	printf("-+- 124\n");
	dump_section_124();
	printf("---\n");
	printf("-+- 125\n");
	dump_section_125();
	printf("---\n");
	printf("-+- 126\n");
	dump_section_126();
	printf("---\n");
	printf("-+- 127\n");
	dump_section_127();
	printf("---\n");
	printf("-+- 128\n");
	dump_section_128();
	printf("---\n");
	printf("-+- 129\n");
	dump_section_129();
	printf("---\n");
	printf("-+- 130\n");
	dump_section_130();
	printf("---\n");
	printf("-+- 131\n");
	dump_section_131();
	printf("---\n");
	printf("-+- 132\n");
	dump_section_132();
	printf("---\n");
	printf("-+- 133\n");
	dump_section_133();
	printf("---\n");
	printf("-+- 134\n");
	dump_section_134();
	printf("---\n");
	printf("-+- 135\n");
	dump_section_135();
	printf("---\n");
	printf("-+- 136\n");
	dump_section_136();
	printf("---\n");
	printf("-+- 137\n");
	dump_section_137();
	printf("---\n");
	printf("-+- 138\n");
	dump_section_138();
	printf("---\n");
	printf("-+- 139\n");
	dump_section_139();
	printf("---\n");
	printf("-+- 140\n");
	dump_section_140();
	printf("---\n");
	printf("-+- 141\n");
	dump_section_141();
	printf("---\n");
	printf("-+- 142\n");
	dump_section_142();
	printf("---\n");
	printf("-+- 143\n");
	dump_section_143();
	printf("---\n");
	printf("-+- 144\n");
	dump_section_144();
	printf("---\n");
	printf("-+- 145\n");
	dump_section_145();
	printf("---\n");
	printf("-+- 146\n");
	dump_section_146();
	printf("---\n");
	printf("-+- 147\n");
	dump_section_147();
	printf("---\n");
	printf("-+- 148\n");
	dump_section_148();
	printf("---\n");
	printf("-+- 149\n");
	dump_section_149();
	printf("---\n");
	printf("-+- 150\n");
	dump_section_150();
	printf("---\n");
	printf("-+- 151\n");
	dump_section_151();
	printf("---\n");
	printf("-+- 152\n");
	dump_section_152();
	printf("---\n");
	printf("-+- 153\n");
	dump_section_153();
	printf("---\n");
	printf("-+- 154\n");
	dump_section_154();
	printf("---\n");
	printf("-+- 155\n");
	dump_section_155();
	printf("---\n");
	printf("-+- 156\n");
	dump_section_156();
	printf("---\n");
	printf("-+- 157\n");
	dump_section_157();
	printf("---\n");
	printf("-+- 158\n");
	dump_section_158();
	printf("---\n");
	printf("-+- 159\n");
	dump_section_159();
	printf("---\n");
	printf("-+- 160\n");
	dump_section_160();
	printf("---\n");
	printf("-+- 161\n");
	dump_section_161();
	printf("---\n");
	printf("-+- 162\n");
	dump_section_162();
	printf("---\n");
	printf("-+- 163\n");
	dump_section_163();
	printf("---\n");
	printf("-+- 164\n");
	dump_section_164();
	printf("---\n");
	printf("-+- 165\n");
	dump_section_165();
	printf("---\n");
	printf("-+- 166\n");
	dump_section_166();
	printf("---\n");
	printf("-+- 167\n");
	dump_section_167();
	printf("---\n");
	printf("-+- 168\n");
	dump_section_168();
	printf("---\n");
	printf("-+- 169\n");
	dump_section_169();
	printf("---\n");
	printf("-+- 170\n");
	dump_section_170();
	printf("---\n");
	printf("-+- 171\n");
	dump_section_171();
	printf("---\n");
	printf("-+- 172\n");
	dump_section_172();
	printf("---\n");
	printf("-+- 173\n");
	dump_section_173();
	printf("---\n");
	printf("-+- 174\n");
	dump_section_174();
	printf("---\n");
	printf("-+- 175\n");
	dump_section_175();
	printf("---\n");
	printf("-+- 176\n");
	dump_section_176();
	printf("---\n");
	printf("-+- 177\n");
	dump_section_177();
	printf("---\n");
	printf("-+- 178\n");
	dump_section_178();
	printf("---\n");
	printf("-+- 179\n");
	dump_section_179();
	printf("---\n");
	printf("-+- 180\n");
	dump_section_180();
	printf("---\n");
	printf("-+- 181\n");
	dump_section_181();
	printf("---\n");
	printf("-+- 182\n");
	dump_section_182();
	printf("---\n");
	printf("-+- 183\n");
	dump_section_183();
	printf("---\n");
	printf("-+- 184\n");
	dump_section_184();
	printf("---\n");
	printf("-+- 185\n");
	dump_section_185();
	printf("---\n");
	printf("-+- 186\n");
	dump_section_186();
	printf("---\n");
	printf("-+- 187\n");
	dump_section_187();
	printf("---\n");
	printf("-+- 188\n");
	dump_section_188();
	printf("---\n");
	printf("-+- 189\n");
	dump_section_189();
	printf("---\n");
	printf("-+- 190\n");
	dump_section_190();
	printf("---\n");
	printf("-+- 191\n");
	dump_section_191();
	printf("---\n");
	printf("-+- 192\n");
	dump_section_192();
	printf("---\n");
	printf("-+- 193\n");
	dump_section_193();
	printf("---\n");
	printf("-+- 194\n");
	dump_section_194();
	printf("---\n");
	printf("-+- 195\n");
	dump_section_195();
	printf("---\n");
	printf("-+- 196\n");
	dump_section_196();
	printf("---\n");
	printf("-+- 197\n");
	dump_section_197();
	printf("---\n");
	printf("-+- 198\n");
	dump_section_198();
	printf("---\n");
	printf("-+- 199\n");
	dump_section_199();
	printf("---\n");
	printf("-+- 200\n");
	dump_section_200();
	printf("---\n");
	printf("-+- 201\n");
	dump_section_201();
	printf("---\n");
	printf("-+- 202\n");
	dump_section_202();
	printf("---\n");
	printf("-+- 203\n");
	dump_section_203();
	printf("---\n");
	printf("-+- 204\n");
	dump_section_204();
	printf("---\n");
	printf("-+- 205\n");
	dump_section_205();
	printf("---\n");
	printf("-+- 206\n");
	dump_section_206();
	printf("---\n");
	printf("-+- 207\n");
	dump_section_207();
	printf("---\n");
	printf("-+- 208\n");
	dump_section_208();
	printf("---\n");
	printf("-+- 209\n");
	dump_section_209();
	printf("---\n");
	printf("-+- 210\n");
	dump_section_210();
	printf("---\n");
	printf("-+- 211\n");
	dump_section_211();
	printf("---\n");
	printf("-+- 212\n");
	dump_section_212();
	printf("---\n");
	printf("-+- 213\n");
	dump_section_213();
	printf("---\n");
	printf("-+- 214\n");
	dump_section_214();
	printf("---\n");
	printf("-+- 215\n");
	dump_section_215();
	printf("---\n");
	printf("-+- 216\n");
	dump_section_216();
	printf("---\n");
	printf("-+- 217\n");
	dump_section_217();
	printf("---\n");
	printf("-+- 218\n");
	dump_section_218();
	printf("---\n");
	printf("-+- 219\n");
	dump_section_219();
	printf("---\n");
	printf("-+- 220\n");
	dump_section_220();
	printf("---\n");
	printf("-+- 221\n");
	dump_section_221();
	printf("---\n");
	printf("-+- 222\n");
	dump_section_222();
	printf("---\n");
	printf("-+- 223\n");
	dump_section_223();
	printf("---\n");
	printf("-+- 224\n");
	dump_section_224();
	printf("---\n");
	printf("-+- 225\n");
	dump_section_225();
	printf("---\n");
	printf("-+- 226\n");
	dump_section_226();
	printf("---\n");
	printf("-+- 227\n");
	dump_section_227();
	printf("---\n");
	printf("-+- 228\n");
	dump_section_228();
	printf("---\n");
	printf("-+- 229\n");
	dump_section_229();
	printf("---\n");
	printf("-+- 230\n");
	dump_section_230();
	printf("---\n");
	printf("-+- 231\n");
	dump_section_231();
	printf("---\n");
	printf("-+- 232\n");
	dump_section_232();
	printf("---\n");
	printf("-+- 233\n");
	dump_section_233();
	printf("---\n");
	printf("-+- 234\n");
	dump_section_234();
	printf("---\n");
	printf("-+- 235\n");
	dump_section_235();
	printf("---\n");
	printf("-+- 236\n");
	dump_section_236();
	printf("---\n");
	printf("-+- 237\n");
	dump_section_237();
	printf("---\n");
	printf("-+- 238\n");
	dump_section_238();
	printf("---\n");
	printf("-+- 239\n");
	dump_section_239();
	printf("---\n");
	printf("-+- 240\n");
	dump_section_240();
	printf("---\n");
	printf("-+- 241\n");
	dump_section_241();
	printf("---\n");
	printf("-+- 242\n");
	dump_section_242();
	printf("---\n");
	printf("-+- 243\n");
	dump_section_243();
	printf("---\n");
	printf("-+- 244\n");
	dump_section_244();
	printf("---\n");
	printf("-+- 245\n");
	dump_section_245();
	printf("---\n");
	printf("-+- 246\n");
	dump_section_246();
	printf("---\n");
	printf("-+- 247\n");
	dump_section_247();
	printf("---\n");
	printf("-+- 248\n");
	dump_section_248();
	printf("---\n");
	printf("-+- 249\n");
	dump_section_249();
	printf("---\n");
	printf("-+- 250\n");
	dump_section_250();
	printf("---\n");
	printf("-+- 251\n");
	dump_section_251();
	printf("---\n");
	printf("-+- 252\n");
	dump_section_252();
	printf("---\n");
	printf("-+- 253\n");
	dump_section_253();
	printf("---\n");
	printf("-+- 254\n");
	dump_section_254();
	printf("---\n");
	printf("-+- 255\n");
	dump_section_255();
	printf("---\n");
	printf("-+- 256\n");
	dump_section_256();
	printf("---\n");
	printf("-+- 257\n");
	dump_section_257();
	printf("---\n");
	printf("-+- 258\n");
	dump_section_258();
	printf("---\n");
	printf("-+- 259\n");
	dump_section_259();
	printf("---\n");
	printf("-+- 260\n");
	dump_section_260();
	printf("---\n");
	printf("-+- 261\n");
	dump_section_261();
	printf("---\n");
	printf("-+- 262\n");
	dump_section_262();
	printf("---\n");
	printf("-+- 263\n");
	dump_section_263();
	printf("---\n");
	printf("-+- 264\n");
	dump_section_264();
	printf("---\n");
	printf("-+- 265\n");
	dump_section_265();
	printf("---\n");
	printf("-+- 266\n");
	dump_section_266();
	printf("---\n");
	printf("-+- 267\n");
	dump_section_267();
	printf("---\n");
	printf("-+- 268\n");
	dump_section_268();
	printf("---\n");
	printf("-+- 269\n");
	dump_section_269();
	printf("---\n");
	printf("-+- 270\n");
	dump_section_270();
	printf("---\n");
	printf("-+- 271\n");
	dump_section_271();
	printf("---\n");
	printf("-+- 272\n");
	dump_section_272();
	printf("---\n");
	printf("-+- 273\n");
	dump_section_273();
	printf("---\n");
	printf("-+- 274\n");
	dump_section_274();
	printf("---\n");
	printf("-+- 275\n");
	dump_section_275();
	printf("---\n");
	printf("-+- 276\n");
	dump_section_276();
	printf("---\n");
	printf("-+- 277\n");
	dump_section_277();
	printf("---\n");
	printf("-+- 278\n");
	dump_section_278();
	printf("---\n");
	printf("-+- 279\n");
	dump_section_279();
	printf("---\n");
	printf("-+- 280\n");
	dump_section_280();
	printf("---\n");
	printf("-+- 281\n");
	dump_section_281();
	printf("---\n");
	printf("-+- 282\n");
	dump_section_282();
	printf("---\n");
	printf("-+- 283\n");
	dump_section_283();
	printf("---\n");
	printf("-+- 284\n");
	dump_section_284();
	printf("---\n");
	printf("-+- 285\n");
	dump_section_285();
	printf("---\n");
	printf("-+- 286\n");
	dump_section_286();
	printf("---\n");
	printf("-+- 287\n");
	dump_section_287();
	printf("---\n");
	printf("-+- 288\n");
	dump_section_288();
	printf("---\n");
	printf("-+- 289\n");
	dump_section_289();
	printf("---\n");
	printf("-+- 290\n");
	dump_section_290();
	printf("---\n");
	printf("-+- 291\n");
	dump_section_291();
	printf("---\n");
	printf("-+- 292\n");
	dump_section_292();
	printf("---\n");
	printf("-+- 293\n");
	dump_section_293();
	printf("---\n");
	printf("-+- 294\n");
	dump_section_294();
	printf("---\n");
	printf("-+- 295\n");
	dump_section_295();
	printf("---\n");
	printf("-+- 296\n");
	dump_section_296();
	printf("---\n");
	printf("-+- 297\n");
	dump_section_297();
	printf("---\n");
	printf("-+- 298\n");
	dump_section_298();
	printf("---\n");
	printf("-+- 299\n");
	dump_section_299();
	printf("---\n");
	printf("-+- 300\n");
	dump_section_300();
	printf("---\n");
	printf("-+- 301\n");
	dump_section_301();
	printf("---\n");
	printf("-+- 302\n");
	dump_section_302();
	printf("---\n");
	printf("-+- 303\n");
	dump_section_303();
	printf("---\n");
	printf("-+- 304\n");
	dump_section_304();
	printf("---\n");
	printf("-+- 305\n");
	dump_section_305();
	printf("---\n");
	printf("-+- 306\n");
	dump_section_306();
	printf("---\n");
	printf("-+- 307\n");
	dump_section_307();
	printf("---\n");
	printf("-+- 308\n");
	dump_section_308();
	printf("---\n");
	printf("-+- 309\n");
	dump_section_309();
	printf("---\n");
	printf("-+- 310\n");
	dump_section_310();
	printf("---\n");
	printf("-+- 311\n");
	dump_section_311();
	printf("---\n");
	printf("-+- 312\n");
	dump_section_312();
	printf("---\n");
	printf("-+- 313\n");
	dump_section_313();
	printf("---\n");
	printf("-+- 314\n");
	dump_section_314();
	printf("---\n");
	printf("-+- 315\n");
	dump_section_315();
	printf("---\n");
	printf("-+- 316\n");
	dump_section_316();
	printf("---\n");
	printf("-+- 317\n");
	dump_section_317();
	printf("---\n");
	printf("-+- 318\n");
	dump_section_318();
	printf("---\n");
	printf("-+- 319\n");
	dump_section_319();
	printf("---\n");
	return 0;
}
