/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <expat.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	if ((XML_CQUANT_NONE) <= 0) {
	    long long x = (long long)(XML_CQUANT_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_NONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_1(void) {
	if ((XML_CQUANT_OPT) <= 0) {
	    long long x = (long long)(XML_CQUANT_OPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_OPT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_2(void) {
	if ((XML_CQUANT_PLUS) <= 0) {
	    long long x = (long long)(XML_CQUANT_PLUS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_PLUS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_3(void) {
	if ((XML_CQUANT_REP) <= 0) {
	    long long x = (long long)(XML_CQUANT_REP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_REP);
	    printf("value: %llu\n", x);
	}
}

void dump_section_4(void) {
	if ((XML_CTYPE_ANY) <= 0) {
	    long long x = (long long)(XML_CTYPE_ANY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_ANY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_5(void) {
	if ((XML_CTYPE_CHOICE) <= 0) {
	    long long x = (long long)(XML_CTYPE_CHOICE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_CHOICE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_6(void) {
	if ((XML_CTYPE_EMPTY) <= 0) {
	    long long x = (long long)(XML_CTYPE_EMPTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_EMPTY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_7(void) {
	if ((XML_CTYPE_MIXED) <= 0) {
	    long long x = (long long)(XML_CTYPE_MIXED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_MIXED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_8(void) {
	if ((XML_CTYPE_NAME) <= 0) {
	    long long x = (long long)(XML_CTYPE_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_NAME);
	    printf("value: %llu\n", x);
	}
}

void dump_section_9(void) {
	if ((XML_CTYPE_SEQ) <= 0) {
	    long long x = (long long)(XML_CTYPE_SEQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_SEQ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_10(void) {
	typedef XML_Content platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs numchildren", offsetof(platcheck_t, numchildren));
	dump("fldsize numchildren",   sizeof(s.numchildren));
	s.numchildren = 0; s.numchildren = ~s.numchildren;
	dump("fldunsigned numchildren", s.numchildren > 0);
	dump("fldofs children", offsetof(platcheck_t, children));
	dump("fldsize children",   sizeof(s.children));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	s.type = 0; s.type = ~s.type;
	dump("fldunsigned type", s.type > 0);
	dump("fldofs quant", offsetof(platcheck_t, quant));
	dump("fldsize quant",   sizeof(s.quant));
	s.quant = 0; s.quant = ~s.quant;
	dump("fldunsigned quant", s.quant > 0);
}

void dump_section_11(void) {
	if ((XML_ERROR_ABORTED) <= 0) {
	    long long x = (long long)(XML_ERROR_ABORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ABORTED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_12(void) {
	if ((XML_ERROR_ASYNC_ENTITY) <= 0) {
	    long long x = (long long)(XML_ERROR_ASYNC_ENTITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ASYNC_ENTITY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_13(void) {
	if ((XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_14(void) {
	if ((XML_ERROR_BAD_CHAR_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_BAD_CHAR_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_BAD_CHAR_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_15(void) {
	if ((XML_ERROR_BINARY_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_BINARY_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_BINARY_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_16(void) {
	if ((XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING) <= 0) {
	    long long x = (long long)(XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_17(void) {
	if ((XML_ERROR_DUPLICATE_ATTRIBUTE) <= 0) {
	    long long x = (long long)(XML_ERROR_DUPLICATE_ATTRIBUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_DUPLICATE_ATTRIBUTE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_18(void) {
	if ((XML_ERROR_ENTITY_DECLARED_IN_PE) <= 0) {
	    long long x = (long long)(XML_ERROR_ENTITY_DECLARED_IN_PE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ENTITY_DECLARED_IN_PE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_19(void) {
	if ((XML_ERROR_EXTERNAL_ENTITY_HANDLING) <= 0) {
	    long long x = (long long)(XML_ERROR_EXTERNAL_ENTITY_HANDLING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_EXTERNAL_ENTITY_HANDLING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_20(void) {
	if ((XML_ERROR_FEATURE_REQUIRES_XML_DTD) <= 0) {
	    long long x = (long long)(XML_ERROR_FEATURE_REQUIRES_XML_DTD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_FEATURE_REQUIRES_XML_DTD);
	    printf("value: %llu\n", x);
	}
}

void dump_section_21(void) {
	if ((XML_ERROR_FINISHED) <= 0) {
	    long long x = (long long)(XML_ERROR_FINISHED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_FINISHED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_22(void) {
	if ((XML_ERROR_INCOMPLETE_PE) <= 0) {
	    long long x = (long long)(XML_ERROR_INCOMPLETE_PE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_INCOMPLETE_PE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_23(void) {
	if ((XML_ERROR_INCORRECT_ENCODING) <= 0) {
	    long long x = (long long)(XML_ERROR_INCORRECT_ENCODING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_INCORRECT_ENCODING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_24(void) {
	if ((XML_ERROR_INVALID_TOKEN) <= 0) {
	    long long x = (long long)(XML_ERROR_INVALID_TOKEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_INVALID_TOKEN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_25(void) {
	if ((XML_ERROR_JUNK_AFTER_DOC_ELEMENT) <= 0) {
	    long long x = (long long)(XML_ERROR_JUNK_AFTER_DOC_ELEMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_JUNK_AFTER_DOC_ELEMENT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_26(void) {
	if ((XML_ERROR_MISPLACED_XML_PI) <= 0) {
	    long long x = (long long)(XML_ERROR_MISPLACED_XML_PI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_MISPLACED_XML_PI);
	    printf("value: %llu\n", x);
	}
}

void dump_section_27(void) {
	if ((XML_ERROR_NOT_STANDALONE) <= 0) {
	    long long x = (long long)(XML_ERROR_NOT_STANDALONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NOT_STANDALONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_28(void) {
	if ((XML_ERROR_NOT_SUSPENDED) <= 0) {
	    long long x = (long long)(XML_ERROR_NOT_SUSPENDED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NOT_SUSPENDED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_29(void) {
	if ((XML_ERROR_NO_ELEMENTS) <= 0) {
	    long long x = (long long)(XML_ERROR_NO_ELEMENTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NO_ELEMENTS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_30(void) {
	if ((XML_ERROR_NO_MEMORY) <= 0) {
	    long long x = (long long)(XML_ERROR_NO_MEMORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NO_MEMORY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_31(void) {
	if ((XML_ERROR_PARAM_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_PARAM_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_PARAM_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_32(void) {
	if ((XML_ERROR_PARTIAL_CHAR) <= 0) {
	    long long x = (long long)(XML_ERROR_PARTIAL_CHAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_PARTIAL_CHAR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_33(void) {
	if ((XML_ERROR_PUBLICID) <= 0) {
	    long long x = (long long)(XML_ERROR_PUBLICID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_PUBLICID);
	    printf("value: %llu\n", x);
	}
}

void dump_section_34(void) {
	if ((XML_ERROR_RECURSIVE_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_RECURSIVE_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_RECURSIVE_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_35(void) {
	if ((XML_ERROR_SUSPENDED) <= 0) {
	    long long x = (long long)(XML_ERROR_SUSPENDED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_SUSPENDED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_36(void) {
	if ((XML_ERROR_SUSPEND_PE) <= 0) {
	    long long x = (long long)(XML_ERROR_SUSPEND_PE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_SUSPEND_PE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_37(void) {
	if ((XML_ERROR_SYNTAX) <= 0) {
	    long long x = (long long)(XML_ERROR_SYNTAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_SYNTAX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_38(void) {
	if ((XML_ERROR_TAG_MISMATCH) <= 0) {
	    long long x = (long long)(XML_ERROR_TAG_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_TAG_MISMATCH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_39(void) {
	if ((XML_ERROR_TEXT_DECL) <= 0) {
	    long long x = (long long)(XML_ERROR_TEXT_DECL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_TEXT_DECL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_40(void) {
	if ((XML_ERROR_UNBOUND_PREFIX) <= 0) {
	    long long x = (long long)(XML_ERROR_UNBOUND_PREFIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNBOUND_PREFIX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_41(void) {
	if ((XML_ERROR_UNCLOSED_CDATA_SECTION) <= 0) {
	    long long x = (long long)(XML_ERROR_UNCLOSED_CDATA_SECTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNCLOSED_CDATA_SECTION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_42(void) {
	if ((XML_ERROR_UNCLOSED_TOKEN) <= 0) {
	    long long x = (long long)(XML_ERROR_UNCLOSED_TOKEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNCLOSED_TOKEN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_43(void) {
	if ((XML_ERROR_UNDECLARING_PREFIX) <= 0) {
	    long long x = (long long)(XML_ERROR_UNDECLARING_PREFIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNDECLARING_PREFIX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_44(void) {
	if ((XML_ERROR_UNDEFINED_ENTITY) <= 0) {
	    long long x = (long long)(XML_ERROR_UNDEFINED_ENTITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNDEFINED_ENTITY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_45(void) {
	if ((XML_ERROR_UNEXPECTED_STATE) <= 0) {
	    long long x = (long long)(XML_ERROR_UNEXPECTED_STATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNEXPECTED_STATE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_46(void) {
	if ((XML_ERROR_UNKNOWN_ENCODING) <= 0) {
	    long long x = (long long)(XML_ERROR_UNKNOWN_ENCODING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNKNOWN_ENCODING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_47(void) {
	if ((XML_ERROR_XML_DECL) <= 0) {
	    long long x = (long long)(XML_ERROR_XML_DECL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_XML_DECL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_48(void) {
	typedef XML_Encoding platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs map", offsetof(platcheck_t, map));
	dump("fldsize map",   sizeof(s.map));
	dump("fldofs data", offsetof(platcheck_t, data));
	dump("fldsize data",   sizeof(s.data));
	dump("fldofs convert", offsetof(platcheck_t, convert));
	dump("fldsize convert",   sizeof(s.convert));
	dump("fldofs release", offsetof(platcheck_t, release));
	dump("fldsize release",   sizeof(s.release));
}

void dump_section_49(void) {
	if ((XML_FALSE) <= 0) {
	    long long x = (long long)(XML_FALSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_FALSE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_50(void) {
	if ((XML_MAJOR_VERSION) <= 0) {
	    long long x = (long long)(XML_MAJOR_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_MAJOR_VERSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_51(void) {
	if ((XML_MICRO_VERSION) <= 0) {
	    long long x = (long long)(XML_MICRO_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_MICRO_VERSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_52(void) {
	if ((XML_MINOR_VERSION) <= 0) {
	    long long x = (long long)(XML_MINOR_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_MINOR_VERSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_53(void) {
	if ((XML_PARAM_ENTITY_PARSING_ALWAYS) <= 0) {
	    long long x = (long long)(XML_PARAM_ENTITY_PARSING_ALWAYS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_PARAM_ENTITY_PARSING_ALWAYS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_54(void) {
	if ((XML_PARAM_ENTITY_PARSING_NEVER) <= 0) {
	    long long x = (long long)(XML_PARAM_ENTITY_PARSING_NEVER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_PARAM_ENTITY_PARSING_NEVER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_55(void) {
	if ((XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE) <= 0) {
	    long long x = (long long)(XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_56(void) {
	dump("size",  sizeof(XML_Parser));
}

void dump_section_57(void) {
	if ((XML_TRUE) <= 0) {
	    long long x = (long long)(XML_TRUE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_TRUE);
	    printf("value: %llu\n", x);
	}
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	return 0;
}
