/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <termios.h>
#include <unistd.h>
#include <sys/ioctl.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef B0
	dump("defined", 1);
	if ((B0) <= 0) {
	    long long x = (long long)(B0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef B110
	dump("defined", 1);
	if ((B110) <= 0) {
	    long long x = (long long)(B110);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B110);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef B115200
	dump("defined", 1);
	if ((B115200) <= 0) {
	    long long x = (long long)(B115200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B115200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef B1200
	dump("defined", 1);
	if ((B1200) <= 0) {
	    long long x = (long long)(B1200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B1200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef B134
	dump("defined", 1);
	if ((B134) <= 0) {
	    long long x = (long long)(B134);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B134);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef B150
	dump("defined", 1);
	if ((B150) <= 0) {
	    long long x = (long long)(B150);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B150);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef B1800
	dump("defined", 1);
	if ((B1800) <= 0) {
	    long long x = (long long)(B1800);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B1800);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef B19200
	dump("defined", 1);
	if ((B19200) <= 0) {
	    long long x = (long long)(B19200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B19200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef B200
	dump("defined", 1);
	if ((B200) <= 0) {
	    long long x = (long long)(B200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef B230400
	dump("defined", 1);
	if ((B230400) <= 0) {
	    long long x = (long long)(B230400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B230400);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef B2400
	dump("defined", 1);
	if ((B2400) <= 0) {
	    long long x = (long long)(B2400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B2400);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef B300
	dump("defined", 1);
	if ((B300) <= 0) {
	    long long x = (long long)(B300);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B300);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef B38400
	dump("defined", 1);
	if ((B38400) <= 0) {
	    long long x = (long long)(B38400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B38400);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef B460800
	dump("defined", 1);
	if ((B460800) <= 0) {
	    long long x = (long long)(B460800);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B460800);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef B4800
	dump("defined", 1);
	if ((B4800) <= 0) {
	    long long x = (long long)(B4800);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B4800);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef B50
	dump("defined", 1);
	if ((B50) <= 0) {
	    long long x = (long long)(B50);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B50);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef B57600
	dump("defined", 1);
	if ((B57600) <= 0) {
	    long long x = (long long)(B57600);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B57600);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef B600
	dump("defined", 1);
	if ((B600) <= 0) {
	    long long x = (long long)(B600);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B600);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef B75
	dump("defined", 1);
	if ((B75) <= 0) {
	    long long x = (long long)(B75);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B75);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef B9600
	dump("defined", 1);
	if ((B9600) <= 0) {
	    long long x = (long long)(B9600);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B9600);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef BRKINT
	dump("defined", 1);
	if ((BRKINT) <= 0) {
	    long long x = (long long)(BRKINT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BRKINT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef BS0
	dump("defined", 1);
	if ((BS0) <= 0) {
	    long long x = (long long)(BS0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BS0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
#ifdef BS1
	dump("defined", 1);
	if ((BS1) <= 0) {
	    long long x = (long long)(BS1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BS1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_23(void) {
#ifdef BSDLY
	dump("defined", 1);
	if ((BSDLY) <= 0) {
	    long long x = (long long)(BSDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BSDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_24(void) {
#ifdef CBAUD
	dump("defined", 1);
	if ((CBAUD) <= 0) {
	    long long x = (long long)(CBAUD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CBAUD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_25(void) {
#ifdef CBAUDEX
	dump("defined", 1);
	if ((CBAUDEX) <= 0) {
	    long long x = (long long)(CBAUDEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CBAUDEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef CDEL
	dump("defined", 1);
	if ((CDEL) <= 0) {
	    long long x = (long long)(CDEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CDEL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_27(void) {
#ifdef CDSUSP
	dump("defined", 1);
	if ((CDSUSP) <= 0) {
	    long long x = (long long)(CDSUSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CDSUSP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef CEOF
	dump("defined", 1);
	if ((CEOF) <= 0) {
	    long long x = (long long)(CEOF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef CEOL
	dump("defined", 1);
	if ((CEOL) <= 0) {
	    long long x = (long long)(CEOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef CEOL2
	dump("defined", 1);
	if ((CEOL2) <= 0) {
	    long long x = (long long)(CEOL2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOL2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef CEOT
	dump("defined", 1);
	if ((CEOT) <= 0) {
	    long long x = (long long)(CEOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
#ifdef CERASE
	dump("defined", 1);
	if ((CERASE) <= 0) {
	    long long x = (long long)(CERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_33(void) {
#ifdef CESC
	dump("defined", 1);
	if ((CESC) <= 0) {
	    long long x = (long long)(CESC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CESC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
#ifdef CFLUSH
	dump("defined", 1);
	if ((CFLUSH) <= 0) {
	    long long x = (long long)(CFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_35(void) {
#ifdef CIBAUD
	dump("defined", 1);
	if ((CIBAUD) <= 0) {
	    long long x = (long long)(CIBAUD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CIBAUD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_36(void) {
#ifdef CINTR
	dump("defined", 1);
	if ((CINTR) <= 0) {
	    long long x = (long long)(CINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_37(void) {
#ifdef CKILL
	dump("defined", 1);
	if ((CKILL) <= 0) {
	    long long x = (long long)(CKILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CKILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_38(void) {
#ifdef CLNEXT
	dump("defined", 1);
	if ((CLNEXT) <= 0) {
	    long long x = (long long)(CLNEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CLNEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_39(void) {
#ifdef CLOCAL
	dump("defined", 1);
	if ((CLOCAL) <= 0) {
	    long long x = (long long)(CLOCAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CLOCAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_40(void) {
#ifdef CNUL
	dump("defined", 1);
	if ((CNUL) <= 0) {
	    long long x = (long long)(CNUL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CNUL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_41(void) {
#ifdef COMMON
	dump("defined", 1);
	if ((COMMON) <= 0) {
	    long long x = (long long)(COMMON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(COMMON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_42(void) {
#ifdef CQUIT
	dump("defined", 1);
	if ((CQUIT) <= 0) {
	    long long x = (long long)(CQUIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CQUIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_43(void) {
#ifdef CR0
	dump("defined", 1);
	if ((CR0) <= 0) {
	    long long x = (long long)(CR0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_44(void) {
#ifdef CR1
	dump("defined", 1);
	if ((CR1) <= 0) {
	    long long x = (long long)(CR1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_45(void) {
#ifdef CR2
	dump("defined", 1);
	if ((CR2) <= 0) {
	    long long x = (long long)(CR2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_46(void) {
#ifdef CR3
	dump("defined", 1);
	if ((CR3) <= 0) {
	    long long x = (long long)(CR3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_47(void) {
#ifdef CRDLY
	dump("defined", 1);
	if ((CRDLY) <= 0) {
	    long long x = (long long)(CRDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_48(void) {
#ifdef CREAD
	dump("defined", 1);
	if ((CREAD) <= 0) {
	    long long x = (long long)(CREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_49(void) {
#ifdef CRPRNT
	dump("defined", 1);
	if ((CRPRNT) <= 0) {
	    long long x = (long long)(CRPRNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRPRNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_50(void) {
#ifdef CRTSCTS
	dump("defined", 1);
	if ((CRTSCTS) <= 0) {
	    long long x = (long long)(CRTSCTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRTSCTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
#ifdef CS5
	dump("defined", 1);
	if ((CS5) <= 0) {
	    long long x = (long long)(CS5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_52(void) {
#ifdef CS6
	dump("defined", 1);
	if ((CS6) <= 0) {
	    long long x = (long long)(CS6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_53(void) {
#ifdef CS7
	dump("defined", 1);
	if ((CS7) <= 0) {
	    long long x = (long long)(CS7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_54(void) {
#ifdef CS8
	dump("defined", 1);
	if ((CS8) <= 0) {
	    long long x = (long long)(CS8);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS8);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_55(void) {
#ifdef CSIZE
	dump("defined", 1);
	if ((CSIZE) <= 0) {
	    long long x = (long long)(CSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_56(void) {
#ifdef CSTART
	dump("defined", 1);
	if ((CSTART) <= 0) {
	    long long x = (long long)(CSTART);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSTART);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_57(void) {
#ifdef CSTOP
	dump("defined", 1);
	if ((CSTOP) <= 0) {
	    long long x = (long long)(CSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_58(void) {
#ifdef CSTOPB
	dump("defined", 1);
	if ((CSTOPB) <= 0) {
	    long long x = (long long)(CSTOPB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSTOPB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_59(void) {
#ifdef CSUSP
	dump("defined", 1);
	if ((CSUSP) <= 0) {
	    long long x = (long long)(CSUSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSUSP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_60(void) {
#ifdef CSWTCH
	dump("defined", 1);
	if ((CSWTCH) <= 0) {
	    long long x = (long long)(CSWTCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSWTCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_61(void) {
#ifdef CWERASE
	dump("defined", 1);
	if ((CWERASE) <= 0) {
	    long long x = (long long)(CWERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CWERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_62(void) {
#ifdef ECHO
	dump("defined", 1);
	if ((ECHO) <= 0) {
	    long long x = (long long)(ECHO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_63(void) {
#ifdef ECHOCTL
	dump("defined", 1);
	if ((ECHOCTL) <= 0) {
	    long long x = (long long)(ECHOCTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOCTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_64(void) {
#ifdef ECHOE
	dump("defined", 1);
	if ((ECHOE) <= 0) {
	    long long x = (long long)(ECHOE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_65(void) {
#ifdef ECHOK
	dump("defined", 1);
	if ((ECHOK) <= 0) {
	    long long x = (long long)(ECHOK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_66(void) {
#ifdef ECHOKE
	dump("defined", 1);
	if ((ECHOKE) <= 0) {
	    long long x = (long long)(ECHOKE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOKE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_67(void) {
#ifdef ECHONL
	dump("defined", 1);
	if ((ECHONL) <= 0) {
	    long long x = (long long)(ECHONL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHONL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_68(void) {
#ifdef ECHOPRT
	dump("defined", 1);
	if ((ECHOPRT) <= 0) {
	    long long x = (long long)(ECHOPRT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOPRT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_69(void) {
#ifdef EXTA
	dump("defined", 1);
	if ((EXTA) <= 0) {
	    long long x = (long long)(EXTA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EXTA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_70(void) {
#ifdef EXTB
	dump("defined", 1);
	if ((EXTB) <= 0) {
	    long long x = (long long)(EXTB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EXTB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_71(void) {
#ifdef FF0
	dump("defined", 1);
	if ((FF0) <= 0) {
	    long long x = (long long)(FF0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FF0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_72(void) {
#ifdef FF1
	dump("defined", 1);
	if ((FF1) <= 0) {
	    long long x = (long long)(FF1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FF1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_73(void) {
#ifdef FFDLY
	dump("defined", 1);
	if ((FFDLY) <= 0) {
	    long long x = (long long)(FFDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FFDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_74(void) {
#ifdef FIOASYNC
	dump("defined", 1);
	if ((FIOASYNC) <= 0) {
	    long long x = (long long)(FIOASYNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIOASYNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_75(void) {
#ifdef FIOCLEX
	dump("defined", 1);
	if ((FIOCLEX) <= 0) {
	    long long x = (long long)(FIOCLEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIOCLEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_76(void) {
#ifdef FIONBIO
	dump("defined", 1);
	if ((FIONBIO) <= 0) {
	    long long x = (long long)(FIONBIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONBIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_77(void) {
#ifdef FIONCLEX
	dump("defined", 1);
	if ((FIONCLEX) <= 0) {
	    long long x = (long long)(FIONCLEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONCLEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_78(void) {
#ifdef FIONREAD
	dump("defined", 1);
	if ((FIONREAD) <= 0) {
	    long long x = (long long)(FIONREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_79(void) {
#ifdef FLUSHO
	dump("defined", 1);
	if ((FLUSHO) <= 0) {
	    long long x = (long long)(FLUSHO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FLUSHO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_80(void) {
#ifdef HUPCL
	dump("defined", 1);
	if ((HUPCL) <= 0) {
	    long long x = (long long)(HUPCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(HUPCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_81(void) {
#ifdef IBSHIFT
	dump("defined", 1);
	if ((IBSHIFT) <= 0) {
	    long long x = (long long)(IBSHIFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IBSHIFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_82(void) {
#ifdef ICANON
	dump("defined", 1);
	if ((ICANON) <= 0) {
	    long long x = (long long)(ICANON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ICANON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_83(void) {
#ifdef ICRNL
	dump("defined", 1);
	if ((ICRNL) <= 0) {
	    long long x = (long long)(ICRNL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ICRNL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_84(void) {
#ifdef IEXTEN
	dump("defined", 1);
	if ((IEXTEN) <= 0) {
	    long long x = (long long)(IEXTEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IEXTEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_85(void) {
#ifdef IGNBRK
	dump("defined", 1);
	if ((IGNBRK) <= 0) {
	    long long x = (long long)(IGNBRK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IGNBRK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_86(void) {
#ifdef IGNCR
	dump("defined", 1);
	if ((IGNCR) <= 0) {
	    long long x = (long long)(IGNCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IGNCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_87(void) {
#ifdef IGNPAR
	dump("defined", 1);
	if ((IGNPAR) <= 0) {
	    long long x = (long long)(IGNPAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IGNPAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_88(void) {
#ifdef IMAXBEL
	dump("defined", 1);
	if ((IMAXBEL) <= 0) {
	    long long x = (long long)(IMAXBEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IMAXBEL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_89(void) {
#ifdef INIT_C_CC
	dump("defined", 1);
	if ((INIT_C_CC) <= 0) {
	    long long x = (long long)(INIT_C_CC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INIT_C_CC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_90(void) {
#ifdef INLCR
	dump("defined", 1);
	if ((INLCR) <= 0) {
	    long long x = (long long)(INLCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INLCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_91(void) {
#ifdef INPCK
	dump("defined", 1);
	if ((INPCK) <= 0) {
	    long long x = (long long)(INPCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INPCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_92(void) {
#ifdef IOCSIZE_MASK
	dump("defined", 1);
	if ((IOCSIZE_MASK) <= 0) {
	    long long x = (long long)(IOCSIZE_MASK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IOCSIZE_MASK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_93(void) {
#ifdef IOCSIZE_SHIFT
	dump("defined", 1);
	if ((IOCSIZE_SHIFT) <= 0) {
	    long long x = (long long)(IOCSIZE_SHIFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IOCSIZE_SHIFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_94(void) {
#ifdef ISIG
	dump("defined", 1);
	if ((ISIG) <= 0) {
	    long long x = (long long)(ISIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ISIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_95(void) {
#ifdef ISTRIP
	dump("defined", 1);
	if ((ISTRIP) <= 0) {
	    long long x = (long long)(ISTRIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ISTRIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_96(void) {
#ifdef IUCLC
	dump("defined", 1);
	if ((IUCLC) <= 0) {
	    long long x = (long long)(IUCLC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IUCLC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_97(void) {
#ifdef IXANY
	dump("defined", 1);
	if ((IXANY) <= 0) {
	    long long x = (long long)(IXANY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IXANY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_98(void) {
#ifdef IXOFF
	dump("defined", 1);
	if ((IXOFF) <= 0) {
	    long long x = (long long)(IXOFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IXOFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_99(void) {
#ifdef IXON
	dump("defined", 1);
	if ((IXON) <= 0) {
	    long long x = (long long)(IXON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IXON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_100(void) {
#ifdef NCC
	dump("defined", 1);
	if ((NCC) <= 0) {
	    long long x = (long long)(NCC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NCC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_101(void) {
#ifdef NCCS
	dump("defined", 1);
	if ((NCCS) <= 0) {
	    long long x = (long long)(NCCS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NCCS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_102(void) {
#ifdef NL0
	dump("defined", 1);
	if ((NL0) <= 0) {
	    long long x = (long long)(NL0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NL0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_103(void) {
#ifdef NL1
	dump("defined", 1);
	if ((NL1) <= 0) {
	    long long x = (long long)(NL1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NL1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_104(void) {
#ifdef NLDLY
	dump("defined", 1);
	if ((NLDLY) <= 0) {
	    long long x = (long long)(NLDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NLDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_105(void) {
#ifdef NOFLSH
	dump("defined", 1);
	if ((NOFLSH) <= 0) {
	    long long x = (long long)(NOFLSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NOFLSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_106(void) {
#ifdef NSWTCH
	dump("defined", 1);
	if ((NSWTCH) <= 0) {
	    long long x = (long long)(NSWTCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NSWTCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_107(void) {
#ifdef N_MOUSE
	dump("defined", 1);
	if ((N_MOUSE) <= 0) {
	    long long x = (long long)(N_MOUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_MOUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_108(void) {
#ifdef N_PPP
	dump("defined", 1);
	if ((N_PPP) <= 0) {
	    long long x = (long long)(N_PPP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_PPP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_109(void) {
#ifdef N_SLIP
	dump("defined", 1);
	if ((N_SLIP) <= 0) {
	    long long x = (long long)(N_SLIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_SLIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_110(void) {
#ifdef N_STRIP
	dump("defined", 1);
	if ((N_STRIP) <= 0) {
	    long long x = (long long)(N_STRIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_STRIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_111(void) {
#ifdef N_TTY
	dump("defined", 1);
	if ((N_TTY) <= 0) {
	    long long x = (long long)(N_TTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_TTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_112(void) {
#ifdef OCRNL
	dump("defined", 1);
	if ((OCRNL) <= 0) {
	    long long x = (long long)(OCRNL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OCRNL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_113(void) {
#ifdef OFDEL
	dump("defined", 1);
	if ((OFDEL) <= 0) {
	    long long x = (long long)(OFDEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OFDEL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_114(void) {
#ifdef OFILL
	dump("defined", 1);
	if ((OFILL) <= 0) {
	    long long x = (long long)(OFILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OFILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_115(void) {
#ifdef OLCUC
	dump("defined", 1);
	if ((OLCUC) <= 0) {
	    long long x = (long long)(OLCUC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OLCUC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_116(void) {
#ifdef ONLCR
	dump("defined", 1);
	if ((ONLCR) <= 0) {
	    long long x = (long long)(ONLCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ONLCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_117(void) {
#ifdef ONLRET
	dump("defined", 1);
	if ((ONLRET) <= 0) {
	    long long x = (long long)(ONLRET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ONLRET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_118(void) {
#ifdef ONOCR
	dump("defined", 1);
	if ((ONOCR) <= 0) {
	    long long x = (long long)(ONOCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ONOCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_119(void) {
#ifdef OPOST
	dump("defined", 1);
	if ((OPOST) <= 0) {
	    long long x = (long long)(OPOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OPOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_120(void) {
#ifdef PARENB
	dump("defined", 1);
	if ((PARENB) <= 0) {
	    long long x = (long long)(PARENB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PARENB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_121(void) {
#ifdef PARMRK
	dump("defined", 1);
	if ((PARMRK) <= 0) {
	    long long x = (long long)(PARMRK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PARMRK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_122(void) {
#ifdef PARODD
	dump("defined", 1);
	if ((PARODD) <= 0) {
	    long long x = (long long)(PARODD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PARODD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_123(void) {
#ifdef PENDIN
	dump("defined", 1);
	if ((PENDIN) <= 0) {
	    long long x = (long long)(PENDIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PENDIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_124(void) {
#ifdef TAB0
	dump("defined", 1);
	if ((TAB0) <= 0) {
	    long long x = (long long)(TAB0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_125(void) {
#ifdef TAB1
	dump("defined", 1);
	if ((TAB1) <= 0) {
	    long long x = (long long)(TAB1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_126(void) {
#ifdef TAB2
	dump("defined", 1);
	if ((TAB2) <= 0) {
	    long long x = (long long)(TAB2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_127(void) {
#ifdef TAB3
	dump("defined", 1);
	if ((TAB3) <= 0) {
	    long long x = (long long)(TAB3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_128(void) {
#ifdef TABDLY
	dump("defined", 1);
	if ((TABDLY) <= 0) {
	    long long x = (long long)(TABDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TABDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_129(void) {
#ifdef TCFLSH
	dump("defined", 1);
	if ((TCFLSH) <= 0) {
	    long long x = (long long)(TCFLSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCFLSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_130(void) {
#ifdef TCGETA
	dump("defined", 1);
	if ((TCGETA) <= 0) {
	    long long x = (long long)(TCGETA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCGETA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_131(void) {
#ifdef TCGETS
	dump("defined", 1);
	if ((TCGETS) <= 0) {
	    long long x = (long long)(TCGETS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCGETS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_132(void) {
#ifdef TCIFLUSH
	dump("defined", 1);
	if ((TCIFLUSH) <= 0) {
	    long long x = (long long)(TCIFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCIFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_133(void) {
#ifdef TCIOFF
	dump("defined", 1);
	if ((TCIOFF) <= 0) {
	    long long x = (long long)(TCIOFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCIOFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_134(void) {
#ifdef TCIOFLUSH
	dump("defined", 1);
	if ((TCIOFLUSH) <= 0) {
	    long long x = (long long)(TCIOFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCIOFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_135(void) {
#ifdef TCION
	dump("defined", 1);
	if ((TCION) <= 0) {
	    long long x = (long long)(TCION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_136(void) {
#ifdef TCOFLUSH
	dump("defined", 1);
	if ((TCOFLUSH) <= 0) {
	    long long x = (long long)(TCOFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCOFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_137(void) {
#ifdef TCOOFF
	dump("defined", 1);
	if ((TCOOFF) <= 0) {
	    long long x = (long long)(TCOOFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCOOFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_138(void) {
#ifdef TCOON
	dump("defined", 1);
	if ((TCOON) <= 0) {
	    long long x = (long long)(TCOON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCOON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_139(void) {
#ifdef TCSADRAIN
	dump("defined", 1);
	if ((TCSADRAIN) <= 0) {
	    long long x = (long long)(TCSADRAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSADRAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_140(void) {
#ifdef TCSAFLUSH
	dump("defined", 1);
	if ((TCSAFLUSH) <= 0) {
	    long long x = (long long)(TCSAFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSAFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_141(void) {
#ifdef TCSANOW
	dump("defined", 1);
	if ((TCSANOW) <= 0) {
	    long long x = (long long)(TCSANOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSANOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_142(void) {
#ifdef TCSASOFT
	dump("defined", 1);
	if ((TCSASOFT) <= 0) {
	    long long x = (long long)(TCSASOFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSASOFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_143(void) {
#ifdef TCSBRK
	dump("defined", 1);
	if ((TCSBRK) <= 0) {
	    long long x = (long long)(TCSBRK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSBRK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_144(void) {
#ifdef TCSBRKP
	dump("defined", 1);
	if ((TCSBRKP) <= 0) {
	    long long x = (long long)(TCSBRKP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSBRKP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_145(void) {
#ifdef TCSETA
	dump("defined", 1);
	if ((TCSETA) <= 0) {
	    long long x = (long long)(TCSETA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_146(void) {
#ifdef TCSETAF
	dump("defined", 1);
	if ((TCSETAF) <= 0) {
	    long long x = (long long)(TCSETAF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETAF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_147(void) {
#ifdef TCSETAW
	dump("defined", 1);
	if ((TCSETAW) <= 0) {
	    long long x = (long long)(TCSETAW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETAW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_148(void) {
#ifdef TCSETS
	dump("defined", 1);
	if ((TCSETS) <= 0) {
	    long long x = (long long)(TCSETS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_149(void) {
#ifdef TCSETSF
	dump("defined", 1);
	if ((TCSETSF) <= 0) {
	    long long x = (long long)(TCSETSF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETSF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_150(void) {
#ifdef TCSETSW
	dump("defined", 1);
	if ((TCSETSW) <= 0) {
	    long long x = (long long)(TCSETSW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETSW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_151(void) {
#ifdef TCXONC
	dump("defined", 1);
	if ((TCXONC) <= 0) {
	    long long x = (long long)(TCXONC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCXONC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_152(void) {
#ifdef TIOCCONS
	dump("defined", 1);
	if ((TIOCCONS) <= 0) {
	    long long x = (long long)(TIOCCONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCCONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_153(void) {
#ifdef TIOCEXCL
	dump("defined", 1);
	if ((TIOCEXCL) <= 0) {
	    long long x = (long long)(TIOCEXCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCEXCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_154(void) {
#ifdef TIOCGETD
	dump("defined", 1);
	if ((TIOCGETD) <= 0) {
	    long long x = (long long)(TIOCGETD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGETD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_155(void) {
#ifdef TIOCGICOUNT
	dump("defined", 1);
	if ((TIOCGICOUNT) <= 0) {
	    long long x = (long long)(TIOCGICOUNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGICOUNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_156(void) {
#ifdef TIOCGLCKTRMIOS
	dump("defined", 1);
	if ((TIOCGLCKTRMIOS) <= 0) {
	    long long x = (long long)(TIOCGLCKTRMIOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGLCKTRMIOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_157(void) {
#ifdef TIOCGPGRP
	dump("defined", 1);
	if ((TIOCGPGRP) <= 0) {
	    long long x = (long long)(TIOCGPGRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGPGRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_158(void) {
#ifdef TIOCGSERIAL
	dump("defined", 1);
	if ((TIOCGSERIAL) <= 0) {
	    long long x = (long long)(TIOCGSERIAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGSERIAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_159(void) {
#ifdef TIOCGSOFTCAR
	dump("defined", 1);
	if ((TIOCGSOFTCAR) <= 0) {
	    long long x = (long long)(TIOCGSOFTCAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGSOFTCAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_160(void) {
#ifdef TIOCGWINSZ
	dump("defined", 1);
	if ((TIOCGWINSZ) <= 0) {
	    long long x = (long long)(TIOCGWINSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGWINSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_161(void) {
#ifdef TIOCINQ
	dump("defined", 1);
	if ((TIOCINQ) <= 0) {
	    long long x = (long long)(TIOCINQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCINQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_162(void) {
#ifdef TIOCLINUX
	dump("defined", 1);
	if ((TIOCLINUX) <= 0) {
	    long long x = (long long)(TIOCLINUX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCLINUX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_163(void) {
#ifdef TIOCMBIC
	dump("defined", 1);
	if ((TIOCMBIC) <= 0) {
	    long long x = (long long)(TIOCMBIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMBIC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_164(void) {
#ifdef TIOCMBIS
	dump("defined", 1);
	if ((TIOCMBIS) <= 0) {
	    long long x = (long long)(TIOCMBIS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMBIS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_165(void) {
#ifdef TIOCMGET
	dump("defined", 1);
	if ((TIOCMGET) <= 0) {
	    long long x = (long long)(TIOCMGET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMGET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_166(void) {
#ifdef TIOCMIWAIT
	dump("defined", 1);
	if ((TIOCMIWAIT) <= 0) {
	    long long x = (long long)(TIOCMIWAIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMIWAIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_167(void) {
#ifdef TIOCMSET
	dump("defined", 1);
	if ((TIOCMSET) <= 0) {
	    long long x = (long long)(TIOCMSET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMSET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_168(void) {
#ifdef TIOCM_CAR
	dump("defined", 1);
	if ((TIOCM_CAR) <= 0) {
	    long long x = (long long)(TIOCM_CAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_CAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_169(void) {
#ifdef TIOCM_CD
	dump("defined", 1);
	if ((TIOCM_CD) <= 0) {
	    long long x = (long long)(TIOCM_CD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_CD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_170(void) {
#ifdef TIOCM_CTS
	dump("defined", 1);
	if ((TIOCM_CTS) <= 0) {
	    long long x = (long long)(TIOCM_CTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_CTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_171(void) {
#ifdef TIOCM_DSR
	dump("defined", 1);
	if ((TIOCM_DSR) <= 0) {
	    long long x = (long long)(TIOCM_DSR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_DSR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_172(void) {
#ifdef TIOCM_DTR
	dump("defined", 1);
	if ((TIOCM_DTR) <= 0) {
	    long long x = (long long)(TIOCM_DTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_DTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_173(void) {
#ifdef TIOCM_LE
	dump("defined", 1);
	if ((TIOCM_LE) <= 0) {
	    long long x = (long long)(TIOCM_LE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_LE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_174(void) {
#ifdef TIOCM_RI
	dump("defined", 1);
	if ((TIOCM_RI) <= 0) {
	    long long x = (long long)(TIOCM_RI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_RI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_175(void) {
#ifdef TIOCM_RNG
	dump("defined", 1);
	if ((TIOCM_RNG) <= 0) {
	    long long x = (long long)(TIOCM_RNG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_RNG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_176(void) {
#ifdef TIOCM_RTS
	dump("defined", 1);
	if ((TIOCM_RTS) <= 0) {
	    long long x = (long long)(TIOCM_RTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_RTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_177(void) {
#ifdef TIOCM_SR
	dump("defined", 1);
	if ((TIOCM_SR) <= 0) {
	    long long x = (long long)(TIOCM_SR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_SR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_178(void) {
#ifdef TIOCM_ST
	dump("defined", 1);
	if ((TIOCM_ST) <= 0) {
	    long long x = (long long)(TIOCM_ST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_ST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_179(void) {
#ifdef TIOCNOTTY
	dump("defined", 1);
	if ((TIOCNOTTY) <= 0) {
	    long long x = (long long)(TIOCNOTTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCNOTTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_180(void) {
#ifdef TIOCNXCL
	dump("defined", 1);
	if ((TIOCNXCL) <= 0) {
	    long long x = (long long)(TIOCNXCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCNXCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_181(void) {
#ifdef TIOCOUTQ
	dump("defined", 1);
	if ((TIOCOUTQ) <= 0) {
	    long long x = (long long)(TIOCOUTQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCOUTQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_182(void) {
#ifdef TIOCPKT
	dump("defined", 1);
	if ((TIOCPKT) <= 0) {
	    long long x = (long long)(TIOCPKT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_183(void) {
#ifdef TIOCPKT_DATA
	dump("defined", 1);
	if ((TIOCPKT_DATA) <= 0) {
	    long long x = (long long)(TIOCPKT_DATA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_DATA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_184(void) {
#ifdef TIOCPKT_DOSTOP
	dump("defined", 1);
	if ((TIOCPKT_DOSTOP) <= 0) {
	    long long x = (long long)(TIOCPKT_DOSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_DOSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_185(void) {
#ifdef TIOCPKT_FLUSHREAD
	dump("defined", 1);
	if ((TIOCPKT_FLUSHREAD) <= 0) {
	    long long x = (long long)(TIOCPKT_FLUSHREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_FLUSHREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_186(void) {
#ifdef TIOCPKT_FLUSHWRITE
	dump("defined", 1);
	if ((TIOCPKT_FLUSHWRITE) <= 0) {
	    long long x = (long long)(TIOCPKT_FLUSHWRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_FLUSHWRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_187(void) {
#ifdef TIOCPKT_NOSTOP
	dump("defined", 1);
	if ((TIOCPKT_NOSTOP) <= 0) {
	    long long x = (long long)(TIOCPKT_NOSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_NOSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_188(void) {
#ifdef TIOCPKT_START
	dump("defined", 1);
	if ((TIOCPKT_START) <= 0) {
	    long long x = (long long)(TIOCPKT_START);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_START);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_189(void) {
#ifdef TIOCPKT_STOP
	dump("defined", 1);
	if ((TIOCPKT_STOP) <= 0) {
	    long long x = (long long)(TIOCPKT_STOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_STOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_190(void) {
#ifdef TIOCSCTTY
	dump("defined", 1);
	if ((TIOCSCTTY) <= 0) {
	    long long x = (long long)(TIOCSCTTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSCTTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_191(void) {
#ifdef TIOCSERCONFIG
	dump("defined", 1);
	if ((TIOCSERCONFIG) <= 0) {
	    long long x = (long long)(TIOCSERCONFIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERCONFIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_192(void) {
#ifdef TIOCSERGETLSR
	dump("defined", 1);
	if ((TIOCSERGETLSR) <= 0) {
	    long long x = (long long)(TIOCSERGETLSR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGETLSR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_193(void) {
#ifdef TIOCSERGETMULTI
	dump("defined", 1);
	if ((TIOCSERGETMULTI) <= 0) {
	    long long x = (long long)(TIOCSERGETMULTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGETMULTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_194(void) {
#ifdef TIOCSERGSTRUCT
	dump("defined", 1);
	if ((TIOCSERGSTRUCT) <= 0) {
	    long long x = (long long)(TIOCSERGSTRUCT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGSTRUCT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_195(void) {
#ifdef TIOCSERGWILD
	dump("defined", 1);
	if ((TIOCSERGWILD) <= 0) {
	    long long x = (long long)(TIOCSERGWILD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGWILD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_196(void) {
#ifdef TIOCSERSETMULTI
	dump("defined", 1);
	if ((TIOCSERSETMULTI) <= 0) {
	    long long x = (long long)(TIOCSERSETMULTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERSETMULTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_197(void) {
#ifdef TIOCSERSWILD
	dump("defined", 1);
	if ((TIOCSERSWILD) <= 0) {
	    long long x = (long long)(TIOCSERSWILD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERSWILD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_198(void) {
#ifdef TIOCSER_TEMT
	dump("defined", 1);
	if ((TIOCSER_TEMT) <= 0) {
	    long long x = (long long)(TIOCSER_TEMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSER_TEMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_199(void) {
#ifdef TIOCSETD
	dump("defined", 1);
	if ((TIOCSETD) <= 0) {
	    long long x = (long long)(TIOCSETD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSETD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_200(void) {
#ifdef TIOCSLCKTRMIOS
	dump("defined", 1);
	if ((TIOCSLCKTRMIOS) <= 0) {
	    long long x = (long long)(TIOCSLCKTRMIOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSLCKTRMIOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_201(void) {
#ifdef TIOCSPGRP
	dump("defined", 1);
	if ((TIOCSPGRP) <= 0) {
	    long long x = (long long)(TIOCSPGRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSPGRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_202(void) {
#ifdef TIOCSSERIAL
	dump("defined", 1);
	if ((TIOCSSERIAL) <= 0) {
	    long long x = (long long)(TIOCSSERIAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSSERIAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_203(void) {
#ifdef TIOCSSOFTCAR
	dump("defined", 1);
	if ((TIOCSSOFTCAR) <= 0) {
	    long long x = (long long)(TIOCSSOFTCAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSSOFTCAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_204(void) {
#ifdef TIOCSTI
	dump("defined", 1);
	if ((TIOCSTI) <= 0) {
	    long long x = (long long)(TIOCSTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_205(void) {
#ifdef TIOCSWINSZ
	dump("defined", 1);
	if ((TIOCSWINSZ) <= 0) {
	    long long x = (long long)(TIOCSWINSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSWINSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_206(void) {
#ifdef TIOCTTYGSTRUCT
	dump("defined", 1);
	if ((TIOCTTYGSTRUCT) <= 0) {
	    long long x = (long long)(TIOCTTYGSTRUCT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCTTYGSTRUCT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_207(void) {
#ifdef TOSTOP
	dump("defined", 1);
	if ((TOSTOP) <= 0) {
	    long long x = (long long)(TOSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TOSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_208(void) {
#ifdef VDISCARD
	dump("defined", 1);
	if ((VDISCARD) <= 0) {
	    long long x = (long long)(VDISCARD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VDISCARD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_209(void) {
#ifdef VEOF
	dump("defined", 1);
	if ((VEOF) <= 0) {
	    long long x = (long long)(VEOF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VEOF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_210(void) {
#ifdef VEOL
	dump("defined", 1);
	if ((VEOL) <= 0) {
	    long long x = (long long)(VEOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VEOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_211(void) {
#ifdef VEOL2
	dump("defined", 1);
	if ((VEOL2) <= 0) {
	    long long x = (long long)(VEOL2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VEOL2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_212(void) {
#ifdef VERASE
	dump("defined", 1);
	if ((VERASE) <= 0) {
	    long long x = (long long)(VERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_213(void) {
#ifdef VINTR
	dump("defined", 1);
	if ((VINTR) <= 0) {
	    long long x = (long long)(VINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_214(void) {
#ifdef VKILL
	dump("defined", 1);
	if ((VKILL) <= 0) {
	    long long x = (long long)(VKILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VKILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_215(void) {
#ifdef VLNEXT
	dump("defined", 1);
	if ((VLNEXT) <= 0) {
	    long long x = (long long)(VLNEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VLNEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_216(void) {
#ifdef VMIN
	dump("defined", 1);
	if ((VMIN) <= 0) {
	    long long x = (long long)(VMIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VMIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_217(void) {
#ifdef VQUIT
	dump("defined", 1);
	if ((VQUIT) <= 0) {
	    long long x = (long long)(VQUIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VQUIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_218(void) {
#ifdef VREPRINT
	dump("defined", 1);
	if ((VREPRINT) <= 0) {
	    long long x = (long long)(VREPRINT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VREPRINT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_219(void) {
#ifdef VSTART
	dump("defined", 1);
	if ((VSTART) <= 0) {
	    long long x = (long long)(VSTART);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSTART);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_220(void) {
#ifdef VSTOP
	dump("defined", 1);
	if ((VSTOP) <= 0) {
	    long long x = (long long)(VSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_221(void) {
#ifdef VSUSP
	dump("defined", 1);
	if ((VSUSP) <= 0) {
	    long long x = (long long)(VSUSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSUSP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_222(void) {
#ifdef VSWTC
	dump("defined", 1);
	if ((VSWTC) <= 0) {
	    long long x = (long long)(VSWTC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSWTC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_223(void) {
#ifdef VSWTCH
	dump("defined", 1);
	if ((VSWTCH) <= 0) {
	    long long x = (long long)(VSWTCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSWTCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_224(void) {
#ifdef VT0
	dump("defined", 1);
	if ((VT0) <= 0) {
	    long long x = (long long)(VT0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VT0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_225(void) {
#ifdef VT1
	dump("defined", 1);
	if ((VT1) <= 0) {
	    long long x = (long long)(VT1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VT1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_226(void) {
#ifdef VTDLY
	dump("defined", 1);
	if ((VTDLY) <= 0) {
	    long long x = (long long)(VTDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VTDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_227(void) {
#ifdef VTIME
	dump("defined", 1);
	if ((VTIME) <= 0) {
	    long long x = (long long)(VTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_228(void) {
#ifdef VWERASE
	dump("defined", 1);
	if ((VWERASE) <= 0) {
	    long long x = (long long)(VWERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VWERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_229(void) {
#ifdef XCASE
	dump("defined", 1);
	if ((XCASE) <= 0) {
	    long long x = (long long)(XCASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XCASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_230(void) {
#ifdef XTABS
	dump("defined", 1);
	if ((XTABS) <= 0) {
	    long long x = (long long)(XTABS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XTABS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	printf("-+- 68\n");
	dump_section_68();
	printf("---\n");
	printf("-+- 69\n");
	dump_section_69();
	printf("---\n");
	printf("-+- 70\n");
	dump_section_70();
	printf("---\n");
	printf("-+- 71\n");
	dump_section_71();
	printf("---\n");
	printf("-+- 72\n");
	dump_section_72();
	printf("---\n");
	printf("-+- 73\n");
	dump_section_73();
	printf("---\n");
	printf("-+- 74\n");
	dump_section_74();
	printf("---\n");
	printf("-+- 75\n");
	dump_section_75();
	printf("---\n");
	printf("-+- 76\n");
	dump_section_76();
	printf("---\n");
	printf("-+- 77\n");
	dump_section_77();
	printf("---\n");
	printf("-+- 78\n");
	dump_section_78();
	printf("---\n");
	printf("-+- 79\n");
	dump_section_79();
	printf("---\n");
	printf("-+- 80\n");
	dump_section_80();
	printf("---\n");
	printf("-+- 81\n");
	dump_section_81();
	printf("---\n");
	printf("-+- 82\n");
	dump_section_82();
	printf("---\n");
	printf("-+- 83\n");
	dump_section_83();
	printf("---\n");
	printf("-+- 84\n");
	dump_section_84();
	printf("---\n");
	printf("-+- 85\n");
	dump_section_85();
	printf("---\n");
	printf("-+- 86\n");
	dump_section_86();
	printf("---\n");
	printf("-+- 87\n");
	dump_section_87();
	printf("---\n");
	printf("-+- 88\n");
	dump_section_88();
	printf("---\n");
	printf("-+- 89\n");
	dump_section_89();
	printf("---\n");
	printf("-+- 90\n");
	dump_section_90();
	printf("---\n");
	printf("-+- 91\n");
	dump_section_91();
	printf("---\n");
	printf("-+- 92\n");
	dump_section_92();
	printf("---\n");
	printf("-+- 93\n");
	dump_section_93();
	printf("---\n");
	printf("-+- 94\n");
	dump_section_94();
	printf("---\n");
	printf("-+- 95\n");
	dump_section_95();
	printf("---\n");
	printf("-+- 96\n");
	dump_section_96();
	printf("---\n");
	printf("-+- 97\n");
	dump_section_97();
	printf("---\n");
	printf("-+- 98\n");
	dump_section_98();
	printf("---\n");
	printf("-+- 99\n");
	dump_section_99();
	printf("---\n");
	printf("-+- 100\n");
	dump_section_100();
	printf("---\n");
	printf("-+- 101\n");
	dump_section_101();
	printf("---\n");
	printf("-+- 102\n");
	dump_section_102();
	printf("---\n");
	printf("-+- 103\n");
	dump_section_103();
	printf("---\n");
	printf("-+- 104\n");
	dump_section_104();
	printf("---\n");
	printf("-+- 105\n");
	dump_section_105();
	printf("---\n");
	printf("-+- 106\n");
	dump_section_106();
	printf("---\n");
	printf("-+- 107\n");
	dump_section_107();
	printf("---\n");
	printf("-+- 108\n");
	dump_section_108();
	printf("---\n");
	printf("-+- 109\n");
	dump_section_109();
	printf("---\n");
	printf("-+- 110\n");
	dump_section_110();
	printf("---\n");
	printf("-+- 111\n");
	dump_section_111();
	printf("---\n");
	printf("-+- 112\n");
	dump_section_112();
	printf("---\n");
	printf("-+- 113\n");
	dump_section_113();
	printf("---\n");
	printf("-+- 114\n");
	dump_section_114();
	printf("---\n");
	printf("-+- 115\n");
	dump_section_115();
	printf("---\n");
	printf("-+- 116\n");
	dump_section_116();
	printf("---\n");
	printf("-+- 117\n");
	dump_section_117();
	printf("---\n");
	printf("-+- 118\n");
	dump_section_118();
	printf("---\n");
	printf("-+- 119\n");
	dump_section_119();
	printf("---\n");
	printf("-+- 120\n");
	dump_section_120();
	printf("---\n");
	printf("-+- 121\n");
	dump_section_121();
	printf("---\n");
	printf("-+- 122\n");
	dump_section_122();
	printf("---\n");
	printf("-+- 123\n");
	dump_section_123();
	printf("---\n");
	printf("-+- 124\n");
	dump_section_124();
	printf("---\n");
	printf("-+- 125\n");
	dump_section_125();
	printf("---\n");
	printf("-+- 126\n");
	dump_section_126();
	printf("---\n");
	printf("-+- 127\n");
	dump_section_127();
	printf("---\n");
	printf("-+- 128\n");
	dump_section_128();
	printf("---\n");
	printf("-+- 129\n");
	dump_section_129();
	printf("---\n");
	printf("-+- 130\n");
	dump_section_130();
	printf("---\n");
	printf("-+- 131\n");
	dump_section_131();
	printf("---\n");
	printf("-+- 132\n");
	dump_section_132();
	printf("---\n");
	printf("-+- 133\n");
	dump_section_133();
	printf("---\n");
	printf("-+- 134\n");
	dump_section_134();
	printf("---\n");
	printf("-+- 135\n");
	dump_section_135();
	printf("---\n");
	printf("-+- 136\n");
	dump_section_136();
	printf("---\n");
	printf("-+- 137\n");
	dump_section_137();
	printf("---\n");
	printf("-+- 138\n");
	dump_section_138();
	printf("---\n");
	printf("-+- 139\n");
	dump_section_139();
	printf("---\n");
	printf("-+- 140\n");
	dump_section_140();
	printf("---\n");
	printf("-+- 141\n");
	dump_section_141();
	printf("---\n");
	printf("-+- 142\n");
	dump_section_142();
	printf("---\n");
	printf("-+- 143\n");
	dump_section_143();
	printf("---\n");
	printf("-+- 144\n");
	dump_section_144();
	printf("---\n");
	printf("-+- 145\n");
	dump_section_145();
	printf("---\n");
	printf("-+- 146\n");
	dump_section_146();
	printf("---\n");
	printf("-+- 147\n");
	dump_section_147();
	printf("---\n");
	printf("-+- 148\n");
	dump_section_148();
	printf("---\n");
	printf("-+- 149\n");
	dump_section_149();
	printf("---\n");
	printf("-+- 150\n");
	dump_section_150();
	printf("---\n");
	printf("-+- 151\n");
	dump_section_151();
	printf("---\n");
	printf("-+- 152\n");
	dump_section_152();
	printf("---\n");
	printf("-+- 153\n");
	dump_section_153();
	printf("---\n");
	printf("-+- 154\n");
	dump_section_154();
	printf("---\n");
	printf("-+- 155\n");
	dump_section_155();
	printf("---\n");
	printf("-+- 156\n");
	dump_section_156();
	printf("---\n");
	printf("-+- 157\n");
	dump_section_157();
	printf("---\n");
	printf("-+- 158\n");
	dump_section_158();
	printf("---\n");
	printf("-+- 159\n");
	dump_section_159();
	printf("---\n");
	printf("-+- 160\n");
	dump_section_160();
	printf("---\n");
	printf("-+- 161\n");
	dump_section_161();
	printf("---\n");
	printf("-+- 162\n");
	dump_section_162();
	printf("---\n");
	printf("-+- 163\n");
	dump_section_163();
	printf("---\n");
	printf("-+- 164\n");
	dump_section_164();
	printf("---\n");
	printf("-+- 165\n");
	dump_section_165();
	printf("---\n");
	printf("-+- 166\n");
	dump_section_166();
	printf("---\n");
	printf("-+- 167\n");
	dump_section_167();
	printf("---\n");
	printf("-+- 168\n");
	dump_section_168();
	printf("---\n");
	printf("-+- 169\n");
	dump_section_169();
	printf("---\n");
	printf("-+- 170\n");
	dump_section_170();
	printf("---\n");
	printf("-+- 171\n");
	dump_section_171();
	printf("---\n");
	printf("-+- 172\n");
	dump_section_172();
	printf("---\n");
	printf("-+- 173\n");
	dump_section_173();
	printf("---\n");
	printf("-+- 174\n");
	dump_section_174();
	printf("---\n");
	printf("-+- 175\n");
	dump_section_175();
	printf("---\n");
	printf("-+- 176\n");
	dump_section_176();
	printf("---\n");
	printf("-+- 177\n");
	dump_section_177();
	printf("---\n");
	printf("-+- 178\n");
	dump_section_178();
	printf("---\n");
	printf("-+- 179\n");
	dump_section_179();
	printf("---\n");
	printf("-+- 180\n");
	dump_section_180();
	printf("---\n");
	printf("-+- 181\n");
	dump_section_181();
	printf("---\n");
	printf("-+- 182\n");
	dump_section_182();
	printf("---\n");
	printf("-+- 183\n");
	dump_section_183();
	printf("---\n");
	printf("-+- 184\n");
	dump_section_184();
	printf("---\n");
	printf("-+- 185\n");
	dump_section_185();
	printf("---\n");
	printf("-+- 186\n");
	dump_section_186();
	printf("---\n");
	printf("-+- 187\n");
	dump_section_187();
	printf("---\n");
	printf("-+- 188\n");
	dump_section_188();
	printf("---\n");
	printf("-+- 189\n");
	dump_section_189();
	printf("---\n");
	printf("-+- 190\n");
	dump_section_190();
	printf("---\n");
	printf("-+- 191\n");
	dump_section_191();
	printf("---\n");
	printf("-+- 192\n");
	dump_section_192();
	printf("---\n");
	printf("-+- 193\n");
	dump_section_193();
	printf("---\n");
	printf("-+- 194\n");
	dump_section_194();
	printf("---\n");
	printf("-+- 195\n");
	dump_section_195();
	printf("---\n");
	printf("-+- 196\n");
	dump_section_196();
	printf("---\n");
	printf("-+- 197\n");
	dump_section_197();
	printf("---\n");
	printf("-+- 198\n");
	dump_section_198();
	printf("---\n");
	printf("-+- 199\n");
	dump_section_199();
	printf("---\n");
	printf("-+- 200\n");
	dump_section_200();
	printf("---\n");
	printf("-+- 201\n");
	dump_section_201();
	printf("---\n");
	printf("-+- 202\n");
	dump_section_202();
	printf("---\n");
	printf("-+- 203\n");
	dump_section_203();
	printf("---\n");
	printf("-+- 204\n");
	dump_section_204();
	printf("---\n");
	printf("-+- 205\n");
	dump_section_205();
	printf("---\n");
	printf("-+- 206\n");
	dump_section_206();
	printf("---\n");
	printf("-+- 207\n");
	dump_section_207();
	printf("---\n");
	printf("-+- 208\n");
	dump_section_208();
	printf("---\n");
	printf("-+- 209\n");
	dump_section_209();
	printf("---\n");
	printf("-+- 210\n");
	dump_section_210();
	printf("---\n");
	printf("-+- 211\n");
	dump_section_211();
	printf("---\n");
	printf("-+- 212\n");
	dump_section_212();
	printf("---\n");
	printf("-+- 213\n");
	dump_section_213();
	printf("---\n");
	printf("-+- 214\n");
	dump_section_214();
	printf("---\n");
	printf("-+- 215\n");
	dump_section_215();
	printf("---\n");
	printf("-+- 216\n");
	dump_section_216();
	printf("---\n");
	printf("-+- 217\n");
	dump_section_217();
	printf("---\n");
	printf("-+- 218\n");
	dump_section_218();
	printf("---\n");
	printf("-+- 219\n");
	dump_section_219();
	printf("---\n");
	printf("-+- 220\n");
	dump_section_220();
	printf("---\n");
	printf("-+- 221\n");
	dump_section_221();
	printf("---\n");
	printf("-+- 222\n");
	dump_section_222();
	printf("---\n");
	printf("-+- 223\n");
	dump_section_223();
	printf("---\n");
	printf("-+- 224\n");
	dump_section_224();
	printf("---\n");
	printf("-+- 225\n");
	dump_section_225();
	printf("---\n");
	printf("-+- 226\n");
	dump_section_226();
	printf("---\n");
	printf("-+- 227\n");
	dump_section_227();
	printf("---\n");
	printf("-+- 228\n");
	dump_section_228();
	printf("---\n");
	printf("-+- 229\n");
	dump_section_229();
	printf("---\n");
	printf("-+- 230\n");
	dump_section_230();
	printf("---\n");
	return 0;
}
