/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <Python.h>
#include <stdarg.h>
#include <structmember.h>
#include <marshal.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	if ((METH_CLASS) <= 0) {
	    long long x = (long long)(METH_CLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_CLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_1(void) {
	if ((METH_COEXIST) <= 0) {
	    long long x = (long long)(METH_COEXIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_COEXIST);
	    printf("value: %llu\n", x);
	}
}

void dump_section_2(void) {
	if ((METH_KEYWORDS) <= 0) {
	    long long x = (long long)(METH_KEYWORDS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_KEYWORDS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_3(void) {
	if ((METH_NOARGS) <= 0) {
	    long long x = (long long)(METH_NOARGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_NOARGS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_4(void) {
	if ((METH_O) <= 0) {
	    long long x = (long long)(METH_O);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_O);
	    printf("value: %llu\n", x);
	}
}

void dump_section_5(void) {
	if ((METH_STATIC) <= 0) {
	    long long x = (long long)(METH_STATIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_STATIC);
	    printf("value: %llu\n", x);
	}
}

void dump_section_6(void) {
	if ((METH_VARARGS) <= 0) {
	    long long x = (long long)(METH_VARARGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_VARARGS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_7(void) {
	if ((PY_SSIZE_T_MAX) <= 0) {
	    long long x = (long long)(PY_SSIZE_T_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PY_SSIZE_T_MAX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_8(void) {
	if ((PY_SSIZE_T_MIN) <= 0) {
	    long long x = (long long)(PY_SSIZE_T_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PY_SSIZE_T_MIN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_9(void) {
	if ((PyBUF_FORMAT) <= 0) {
	    long long x = (long long)(PyBUF_FORMAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_FORMAT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_10(void) {
	if ((PyBUF_MAX_NDIM) <= 0) {
	    long long x = (long long)(PyBUF_MAX_NDIM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_MAX_NDIM);
	    printf("value: %llu\n", x);
	}
}

void dump_section_11(void) {
	if ((PyBUF_ND) <= 0) {
	    long long x = (long long)(PyBUF_ND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_ND);
	    printf("value: %llu\n", x);
	}
}

void dump_section_12(void) {
	if ((PyBUF_READ) <= 0) {
	    long long x = (long long)(PyBUF_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_READ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_13(void) {
	if ((PyBUF_STRIDES) <= 0) {
	    long long x = (long long)(PyBUF_STRIDES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_STRIDES);
	    printf("value: %llu\n", x);
	}
}

void dump_section_14(void) {
	if ((PyBUF_WRITABLE) <= 0) {
	    long long x = (long long)(PyBUF_WRITABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_WRITABLE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_15(void) {
	if ((PyBUF_WRITE) <= 0) {
	    long long x = (long long)(PyBUF_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PyBUF_WRITE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_16(void) {
	if ((Py_EQ) <= 0) {
	    long long x = (long long)(Py_EQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_EQ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_17(void) {
	if ((Py_GE) <= 0) {
	    long long x = (long long)(Py_GE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_GE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_18(void) {
	if ((Py_GT) <= 0) {
	    long long x = (long long)(Py_GT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_GT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_19(void) {
	if ((Py_LE) <= 0) {
	    long long x = (long long)(Py_LE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_LE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_20(void) {
	if ((Py_LT) <= 0) {
	    long long x = (long long)(Py_LT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_LT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_21(void) {
	if ((Py_NE) <= 0) {
	    long long x = (long long)(Py_NE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_NE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_22(void) {
	if ((Py_TPFLAGS_BASETYPE) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_BASETYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_BASETYPE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_23(void) {
	if ((Py_TPFLAGS_BASE_EXC_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_BASE_EXC_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_BASE_EXC_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_24(void) {
	if ((Py_TPFLAGS_CHECKTYPES) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_CHECKTYPES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_CHECKTYPES);
	    printf("value: %llu\n", x);
	}
}

void dump_section_25(void) {
	if ((Py_TPFLAGS_DICT_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_DICT_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_DICT_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_26(void) {
	if ((Py_TPFLAGS_HAVE_CLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HAVE_CLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HAVE_CLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_27(void) {
	if ((Py_TPFLAGS_HAVE_GETCHARBUFFER) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HAVE_GETCHARBUFFER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HAVE_GETCHARBUFFER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_28(void) {
	if ((Py_TPFLAGS_HAVE_INPLACEOPS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HAVE_INPLACEOPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HAVE_INPLACEOPS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_29(void) {
	if ((Py_TPFLAGS_HAVE_NEWBUFFER) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HAVE_NEWBUFFER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HAVE_NEWBUFFER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_30(void) {
	if ((Py_TPFLAGS_HEAPTYPE) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HEAPTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HEAPTYPE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_31(void) {
	if ((Py_TPFLAGS_INT_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_INT_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_INT_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_32(void) {
	if ((Py_TPFLAGS_LIST_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_LIST_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_LIST_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_33(void) {
	if ((Py_TPFLAGS_LONG_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_LONG_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_LONG_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_34(void) {
	if ((Py_TPFLAGS_READY) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_READY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_READY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_35(void) {
	if ((Py_TPFLAGS_READYING) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_READYING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_READYING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_36(void) {
	if ((Py_TPFLAGS_STRING_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_STRING_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_STRING_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_37(void) {
	if ((Py_TPFLAGS_TUPLE_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_TUPLE_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_TUPLE_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_38(void) {
	if ((Py_TPFLAGS_TYPE_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_TYPE_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_TYPE_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_39(void) {
	if ((Py_TPFLAGS_UNICODE_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_UNICODE_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_UNICODE_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_40(void) {
	if ((Py_TPPYPYFLAGS_FLOAT_SUBCLASS) <= 0) {
	    long long x = (long long)(Py_TPPYPYFLAGS_FLOAT_SUBCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPPYPYFLAGS_FLOAT_SUBCLASS);
	    printf("value: %llu\n", x);
	}
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	return 0;
}
