/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <stdarg.h>
#include <stdio.h>
#include <stddef.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_object.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_descrobject.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef struct _object platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
}

void dump_section_1(void) {
	typedef struct _typeobject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
	dump("fldofs tp_name", offsetof(platcheck_t, tp_name));
	dump("fldsize tp_name",   sizeof(s.tp_name));
	dump("fldofs tp_basicsize", offsetof(platcheck_t, tp_basicsize));
	dump("fldsize tp_basicsize",   sizeof(s.tp_basicsize));
	s.tp_basicsize = 0; s.tp_basicsize = ~s.tp_basicsize;
	dump("fldunsigned tp_basicsize", s.tp_basicsize > 0);
	dump("fldofs tp_itemsize", offsetof(platcheck_t, tp_itemsize));
	dump("fldsize tp_itemsize",   sizeof(s.tp_itemsize));
	s.tp_itemsize = 0; s.tp_itemsize = ~s.tp_itemsize;
	dump("fldunsigned tp_itemsize", s.tp_itemsize > 0);
	dump("fldofs tp_dealloc", offsetof(platcheck_t, tp_dealloc));
	dump("fldsize tp_dealloc",   sizeof(s.tp_dealloc));
	dump("fldofs tp_print", offsetof(platcheck_t, tp_print));
	dump("fldsize tp_print",   sizeof(s.tp_print));
	dump("fldofs tp_getattr", offsetof(platcheck_t, tp_getattr));
	dump("fldsize tp_getattr",   sizeof(s.tp_getattr));
	dump("fldofs tp_setattr", offsetof(platcheck_t, tp_setattr));
	dump("fldsize tp_setattr",   sizeof(s.tp_setattr));
	dump("fldofs tp_compare", offsetof(platcheck_t, tp_compare));
	dump("fldsize tp_compare",   sizeof(s.tp_compare));
	dump("fldofs tp_repr", offsetof(platcheck_t, tp_repr));
	dump("fldsize tp_repr",   sizeof(s.tp_repr));
	dump("fldofs tp_as_number", offsetof(platcheck_t, tp_as_number));
	dump("fldsize tp_as_number",   sizeof(s.tp_as_number));
	dump("fldofs tp_as_sequence", offsetof(platcheck_t, tp_as_sequence));
	dump("fldsize tp_as_sequence",   sizeof(s.tp_as_sequence));
	dump("fldofs tp_as_mapping", offsetof(platcheck_t, tp_as_mapping));
	dump("fldsize tp_as_mapping",   sizeof(s.tp_as_mapping));
	dump("fldofs tp_hash", offsetof(platcheck_t, tp_hash));
	dump("fldsize tp_hash",   sizeof(s.tp_hash));
	dump("fldofs tp_call", offsetof(platcheck_t, tp_call));
	dump("fldsize tp_call",   sizeof(s.tp_call));
	dump("fldofs tp_str", offsetof(platcheck_t, tp_str));
	dump("fldsize tp_str",   sizeof(s.tp_str));
	dump("fldofs tp_getattro", offsetof(platcheck_t, tp_getattro));
	dump("fldsize tp_getattro",   sizeof(s.tp_getattro));
	dump("fldofs tp_setattro", offsetof(platcheck_t, tp_setattro));
	dump("fldsize tp_setattro",   sizeof(s.tp_setattro));
	dump("fldofs tp_as_buffer", offsetof(platcheck_t, tp_as_buffer));
	dump("fldsize tp_as_buffer",   sizeof(s.tp_as_buffer));
	dump("fldofs tp_flags", offsetof(platcheck_t, tp_flags));
	dump("fldsize tp_flags",   sizeof(s.tp_flags));
	s.tp_flags = 0; s.tp_flags = ~s.tp_flags;
	dump("fldunsigned tp_flags", s.tp_flags > 0);
	dump("fldofs tp_doc", offsetof(platcheck_t, tp_doc));
	dump("fldsize tp_doc",   sizeof(s.tp_doc));
	dump("fldofs tp_traverse", offsetof(platcheck_t, tp_traverse));
	dump("fldsize tp_traverse",   sizeof(s.tp_traverse));
	dump("fldofs tp_clear", offsetof(platcheck_t, tp_clear));
	dump("fldsize tp_clear",   sizeof(s.tp_clear));
	dump("fldofs tp_richcompare", offsetof(platcheck_t, tp_richcompare));
	dump("fldsize tp_richcompare",   sizeof(s.tp_richcompare));
	dump("fldofs tp_weaklistoffset", offsetof(platcheck_t, tp_weaklistoffset));
	dump("fldsize tp_weaklistoffset",   sizeof(s.tp_weaklistoffset));
	s.tp_weaklistoffset = 0; s.tp_weaklistoffset = ~s.tp_weaklistoffset;
	dump("fldunsigned tp_weaklistoffset", s.tp_weaklistoffset > 0);
	dump("fldofs tp_iter", offsetof(platcheck_t, tp_iter));
	dump("fldsize tp_iter",   sizeof(s.tp_iter));
	dump("fldofs tp_iternext", offsetof(platcheck_t, tp_iternext));
	dump("fldsize tp_iternext",   sizeof(s.tp_iternext));
	dump("fldofs tp_methods", offsetof(platcheck_t, tp_methods));
	dump("fldsize tp_methods",   sizeof(s.tp_methods));
	dump("fldofs tp_members", offsetof(platcheck_t, tp_members));
	dump("fldsize tp_members",   sizeof(s.tp_members));
	dump("fldofs tp_getset", offsetof(platcheck_t, tp_getset));
	dump("fldsize tp_getset",   sizeof(s.tp_getset));
	dump("fldofs tp_base", offsetof(platcheck_t, tp_base));
	dump("fldsize tp_base",   sizeof(s.tp_base));
	dump("fldofs tp_dict", offsetof(platcheck_t, tp_dict));
	dump("fldsize tp_dict",   sizeof(s.tp_dict));
	dump("fldofs tp_descr_get", offsetof(platcheck_t, tp_descr_get));
	dump("fldsize tp_descr_get",   sizeof(s.tp_descr_get));
	dump("fldofs tp_descr_set", offsetof(platcheck_t, tp_descr_set));
	dump("fldsize tp_descr_set",   sizeof(s.tp_descr_set));
	dump("fldofs tp_dictoffset", offsetof(platcheck_t, tp_dictoffset));
	dump("fldsize tp_dictoffset",   sizeof(s.tp_dictoffset));
	s.tp_dictoffset = 0; s.tp_dictoffset = ~s.tp_dictoffset;
	dump("fldunsigned tp_dictoffset", s.tp_dictoffset > 0);
	dump("fldofs tp_init", offsetof(platcheck_t, tp_init));
	dump("fldsize tp_init",   sizeof(s.tp_init));
	dump("fldofs tp_alloc", offsetof(platcheck_t, tp_alloc));
	dump("fldsize tp_alloc",   sizeof(s.tp_alloc));
	dump("fldofs tp_new", offsetof(platcheck_t, tp_new));
	dump("fldsize tp_new",   sizeof(s.tp_new));
	dump("fldofs tp_free", offsetof(platcheck_t, tp_free));
	dump("fldsize tp_free",   sizeof(s.tp_free));
	dump("fldofs tp_is_gc", offsetof(platcheck_t, tp_is_gc));
	dump("fldsize tp_is_gc",   sizeof(s.tp_is_gc));
	dump("fldofs tp_bases", offsetof(platcheck_t, tp_bases));
	dump("fldsize tp_bases",   sizeof(s.tp_bases));
	dump("fldofs tp_mro", offsetof(platcheck_t, tp_mro));
	dump("fldsize tp_mro",   sizeof(s.tp_mro));
	dump("fldofs tp_cache", offsetof(platcheck_t, tp_cache));
	dump("fldsize tp_cache",   sizeof(s.tp_cache));
	dump("fldofs tp_subclasses", offsetof(platcheck_t, tp_subclasses));
	dump("fldsize tp_subclasses",   sizeof(s.tp_subclasses));
	dump("fldofs tp_weaklist", offsetof(platcheck_t, tp_weaklist));
	dump("fldsize tp_weaklist",   sizeof(s.tp_weaklist));
	dump("fldofs tp_del", offsetof(platcheck_t, tp_del));
	dump("fldsize tp_del",   sizeof(s.tp_del));
	dump("fldofs tp_version_tag", offsetof(platcheck_t, tp_version_tag));
	dump("fldsize tp_version_tag",   sizeof(s.tp_version_tag));
	s.tp_version_tag = 0; s.tp_version_tag = ~s.tp_version_tag;
	dump("fldunsigned tp_version_tag", s.tp_version_tag > 0);
	dump("fldofs tp_pypy_flags", offsetof(platcheck_t, tp_pypy_flags));
	dump("fldsize tp_pypy_flags",   sizeof(s.tp_pypy_flags));
	s.tp_pypy_flags = 0; s.tp_pypy_flags = ~s.tp_pypy_flags;
	dump("fldunsigned tp_pypy_flags", s.tp_pypy_flags > 0);
}

void dump_section_2(void) {
	typedef PyVarObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
}

void dump_section_3(void) {
	typedef struct bufferinfo platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs buf", offsetof(platcheck_t, buf));
	dump("fldsize buf",   sizeof(s.buf));
	dump("fldofs obj", offsetof(platcheck_t, obj));
	dump("fldsize obj",   sizeof(s.obj));
	dump("fldofs len", offsetof(platcheck_t, len));
	dump("fldsize len",   sizeof(s.len));
	s.len = 0; s.len = ~s.len;
	dump("fldunsigned len", s.len > 0);
	dump("fldofs itemsize", offsetof(platcheck_t, itemsize));
	dump("fldsize itemsize",   sizeof(s.itemsize));
	s.itemsize = 0; s.itemsize = ~s.itemsize;
	dump("fldunsigned itemsize", s.itemsize > 0);
	dump("fldofs readonly", offsetof(platcheck_t, readonly));
	dump("fldsize readonly",   sizeof(s.readonly));
	dump("fldofs ndim", offsetof(platcheck_t, ndim));
	dump("fldsize ndim",   sizeof(s.ndim));
	dump("fldofs format", offsetof(platcheck_t, format));
	dump("fldsize format",   sizeof(s.format));
	dump("fldofs shape", offsetof(platcheck_t, shape));
	dump("fldsize shape",   sizeof(s.shape));
	dump("fldofs strides", offsetof(platcheck_t, strides));
	dump("fldsize strides",   sizeof(s.strides));
	dump("fldofs suboffsets", offsetof(platcheck_t, suboffsets));
	dump("fldsize suboffsets",   sizeof(s.suboffsets));
	dump("fldofs internal", offsetof(platcheck_t, internal));
	dump("fldsize internal",   sizeof(s.internal));
	dump("fldofs flags", offsetof(platcheck_t, flags));
	dump("fldsize flags",   sizeof(s.flags));
	dump("fldofs _strides", offsetof(platcheck_t, _strides));
	dump("fldsize _strides",   sizeof(s._strides));
	dump("fldofs _shape", offsetof(platcheck_t, _shape));
	dump("fldsize _shape",   sizeof(s._shape));
}

void dump_section_4(void) {
	typedef PyNumberMethods platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs nb_add", offsetof(platcheck_t, nb_add));
	dump("fldsize nb_add",   sizeof(s.nb_add));
	dump("fldofs nb_subtract", offsetof(platcheck_t, nb_subtract));
	dump("fldsize nb_subtract",   sizeof(s.nb_subtract));
	dump("fldofs nb_multiply", offsetof(platcheck_t, nb_multiply));
	dump("fldsize nb_multiply",   sizeof(s.nb_multiply));
	dump("fldofs nb_divide", offsetof(platcheck_t, nb_divide));
	dump("fldsize nb_divide",   sizeof(s.nb_divide));
	dump("fldofs nb_remainder", offsetof(platcheck_t, nb_remainder));
	dump("fldsize nb_remainder",   sizeof(s.nb_remainder));
	dump("fldofs nb_divmod", offsetof(platcheck_t, nb_divmod));
	dump("fldsize nb_divmod",   sizeof(s.nb_divmod));
	dump("fldofs nb_power", offsetof(platcheck_t, nb_power));
	dump("fldsize nb_power",   sizeof(s.nb_power));
	dump("fldofs nb_negative", offsetof(platcheck_t, nb_negative));
	dump("fldsize nb_negative",   sizeof(s.nb_negative));
	dump("fldofs nb_positive", offsetof(platcheck_t, nb_positive));
	dump("fldsize nb_positive",   sizeof(s.nb_positive));
	dump("fldofs nb_absolute", offsetof(platcheck_t, nb_absolute));
	dump("fldsize nb_absolute",   sizeof(s.nb_absolute));
	dump("fldofs nb_nonzero", offsetof(platcheck_t, nb_nonzero));
	dump("fldsize nb_nonzero",   sizeof(s.nb_nonzero));
	dump("fldofs nb_invert", offsetof(platcheck_t, nb_invert));
	dump("fldsize nb_invert",   sizeof(s.nb_invert));
	dump("fldofs nb_lshift", offsetof(platcheck_t, nb_lshift));
	dump("fldsize nb_lshift",   sizeof(s.nb_lshift));
	dump("fldofs nb_rshift", offsetof(platcheck_t, nb_rshift));
	dump("fldsize nb_rshift",   sizeof(s.nb_rshift));
	dump("fldofs nb_and", offsetof(platcheck_t, nb_and));
	dump("fldsize nb_and",   sizeof(s.nb_and));
	dump("fldofs nb_xor", offsetof(platcheck_t, nb_xor));
	dump("fldsize nb_xor",   sizeof(s.nb_xor));
	dump("fldofs nb_or", offsetof(platcheck_t, nb_or));
	dump("fldsize nb_or",   sizeof(s.nb_or));
	dump("fldofs nb_coerce", offsetof(platcheck_t, nb_coerce));
	dump("fldsize nb_coerce",   sizeof(s.nb_coerce));
	dump("fldofs nb_int", offsetof(platcheck_t, nb_int));
	dump("fldsize nb_int",   sizeof(s.nb_int));
	dump("fldofs nb_long", offsetof(platcheck_t, nb_long));
	dump("fldsize nb_long",   sizeof(s.nb_long));
	dump("fldofs nb_float", offsetof(platcheck_t, nb_float));
	dump("fldsize nb_float",   sizeof(s.nb_float));
	dump("fldofs nb_oct", offsetof(platcheck_t, nb_oct));
	dump("fldsize nb_oct",   sizeof(s.nb_oct));
	dump("fldofs nb_hex", offsetof(platcheck_t, nb_hex));
	dump("fldsize nb_hex",   sizeof(s.nb_hex));
	dump("fldofs nb_inplace_add", offsetof(platcheck_t, nb_inplace_add));
	dump("fldsize nb_inplace_add",   sizeof(s.nb_inplace_add));
	dump("fldofs nb_inplace_subtract", offsetof(platcheck_t, nb_inplace_subtract));
	dump("fldsize nb_inplace_subtract",   sizeof(s.nb_inplace_subtract));
	dump("fldofs nb_inplace_multiply", offsetof(platcheck_t, nb_inplace_multiply));
	dump("fldsize nb_inplace_multiply",   sizeof(s.nb_inplace_multiply));
	dump("fldofs nb_inplace_divide", offsetof(platcheck_t, nb_inplace_divide));
	dump("fldsize nb_inplace_divide",   sizeof(s.nb_inplace_divide));
	dump("fldofs nb_inplace_remainder", offsetof(platcheck_t, nb_inplace_remainder));
	dump("fldsize nb_inplace_remainder",   sizeof(s.nb_inplace_remainder));
	dump("fldofs nb_inplace_power", offsetof(platcheck_t, nb_inplace_power));
	dump("fldsize nb_inplace_power",   sizeof(s.nb_inplace_power));
	dump("fldofs nb_inplace_lshift", offsetof(platcheck_t, nb_inplace_lshift));
	dump("fldsize nb_inplace_lshift",   sizeof(s.nb_inplace_lshift));
	dump("fldofs nb_inplace_rshift", offsetof(platcheck_t, nb_inplace_rshift));
	dump("fldsize nb_inplace_rshift",   sizeof(s.nb_inplace_rshift));
	dump("fldofs nb_inplace_and", offsetof(platcheck_t, nb_inplace_and));
	dump("fldsize nb_inplace_and",   sizeof(s.nb_inplace_and));
	dump("fldofs nb_inplace_xor", offsetof(platcheck_t, nb_inplace_xor));
	dump("fldsize nb_inplace_xor",   sizeof(s.nb_inplace_xor));
	dump("fldofs nb_inplace_or", offsetof(platcheck_t, nb_inplace_or));
	dump("fldsize nb_inplace_or",   sizeof(s.nb_inplace_or));
	dump("fldofs nb_floor_divide", offsetof(platcheck_t, nb_floor_divide));
	dump("fldsize nb_floor_divide",   sizeof(s.nb_floor_divide));
	dump("fldofs nb_true_divide", offsetof(platcheck_t, nb_true_divide));
	dump("fldsize nb_true_divide",   sizeof(s.nb_true_divide));
	dump("fldofs nb_inplace_floor_divide", offsetof(platcheck_t, nb_inplace_floor_divide));
	dump("fldsize nb_inplace_floor_divide",   sizeof(s.nb_inplace_floor_divide));
	dump("fldofs nb_inplace_true_divide", offsetof(platcheck_t, nb_inplace_true_divide));
	dump("fldsize nb_inplace_true_divide",   sizeof(s.nb_inplace_true_divide));
	dump("fldofs nb_index", offsetof(platcheck_t, nb_index));
	dump("fldsize nb_index",   sizeof(s.nb_index));
}

void dump_section_5(void) {
	typedef PySequenceMethods platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sq_length", offsetof(platcheck_t, sq_length));
	dump("fldsize sq_length",   sizeof(s.sq_length));
	dump("fldofs sq_concat", offsetof(platcheck_t, sq_concat));
	dump("fldsize sq_concat",   sizeof(s.sq_concat));
	dump("fldofs sq_repeat", offsetof(platcheck_t, sq_repeat));
	dump("fldsize sq_repeat",   sizeof(s.sq_repeat));
	dump("fldofs sq_item", offsetof(platcheck_t, sq_item));
	dump("fldsize sq_item",   sizeof(s.sq_item));
	dump("fldofs sq_slice", offsetof(platcheck_t, sq_slice));
	dump("fldsize sq_slice",   sizeof(s.sq_slice));
	dump("fldofs sq_ass_item", offsetof(platcheck_t, sq_ass_item));
	dump("fldsize sq_ass_item",   sizeof(s.sq_ass_item));
	dump("fldofs sq_ass_slice", offsetof(platcheck_t, sq_ass_slice));
	dump("fldsize sq_ass_slice",   sizeof(s.sq_ass_slice));
	dump("fldofs sq_contains", offsetof(platcheck_t, sq_contains));
	dump("fldsize sq_contains",   sizeof(s.sq_contains));
	dump("fldofs sq_inplace_concat", offsetof(platcheck_t, sq_inplace_concat));
	dump("fldsize sq_inplace_concat",   sizeof(s.sq_inplace_concat));
	dump("fldofs sq_inplace_repeat", offsetof(platcheck_t, sq_inplace_repeat));
	dump("fldsize sq_inplace_repeat",   sizeof(s.sq_inplace_repeat));
}

void dump_section_6(void) {
	typedef PyMappingMethods platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs mp_length", offsetof(platcheck_t, mp_length));
	dump("fldsize mp_length",   sizeof(s.mp_length));
	dump("fldofs mp_subscript", offsetof(platcheck_t, mp_subscript));
	dump("fldsize mp_subscript",   sizeof(s.mp_subscript));
	dump("fldofs mp_ass_subscript", offsetof(platcheck_t, mp_ass_subscript));
	dump("fldsize mp_ass_subscript",   sizeof(s.mp_ass_subscript));
}

void dump_section_7(void) {
	typedef PyBufferProcs platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs bf_getreadbuffer", offsetof(platcheck_t, bf_getreadbuffer));
	dump("fldsize bf_getreadbuffer",   sizeof(s.bf_getreadbuffer));
	dump("fldofs bf_getwritebuffer", offsetof(platcheck_t, bf_getwritebuffer));
	dump("fldsize bf_getwritebuffer",   sizeof(s.bf_getwritebuffer));
	dump("fldofs bf_getsegcount", offsetof(platcheck_t, bf_getsegcount));
	dump("fldsize bf_getsegcount",   sizeof(s.bf_getsegcount));
	dump("fldofs bf_getcharbuffer", offsetof(platcheck_t, bf_getcharbuffer));
	dump("fldsize bf_getcharbuffer",   sizeof(s.bf_getcharbuffer));
	dump("fldofs bf_getbuffer", offsetof(platcheck_t, bf_getbuffer));
	dump("fldsize bf_getbuffer",   sizeof(s.bf_getbuffer));
	dump("fldofs bf_releasebuffer", offsetof(platcheck_t, bf_releasebuffer));
	dump("fldsize bf_releasebuffer",   sizeof(s.bf_releasebuffer));
}

void dump_section_8(void) {
	typedef struct PyMethodDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ml_name", offsetof(platcheck_t, ml_name));
	dump("fldsize ml_name",   sizeof(s.ml_name));
	dump("fldofs ml_meth", offsetof(platcheck_t, ml_meth));
	dump("fldsize ml_meth",   sizeof(s.ml_meth));
	dump("fldofs ml_flags", offsetof(platcheck_t, ml_flags));
	dump("fldsize ml_flags",   sizeof(s.ml_flags));
	dump("fldofs ml_doc", offsetof(platcheck_t, ml_doc));
	dump("fldsize ml_doc",   sizeof(s.ml_doc));
}

void dump_section_9(void) {
	typedef PyCFunctionObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs m_ml", offsetof(platcheck_t, m_ml));
	dump("fldsize m_ml",   sizeof(s.m_ml));
	dump("fldofs m_self", offsetof(platcheck_t, m_self));
	dump("fldsize m_self",   sizeof(s.m_self));
	dump("fldofs m_module", offsetof(platcheck_t, m_module));
	dump("fldsize m_module",   sizeof(s.m_module));
}

void dump_section_10(void) {
	typedef struct PyMemberDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	dump("fldofs offset", offsetof(platcheck_t, offset));
	dump("fldsize offset",   sizeof(s.offset));
	s.offset = 0; s.offset = ~s.offset;
	dump("fldunsigned offset", s.offset > 0);
	dump("fldofs flags", offsetof(platcheck_t, flags));
	dump("fldsize flags",   sizeof(s.flags));
	dump("fldofs doc", offsetof(platcheck_t, doc));
	dump("fldsize doc",   sizeof(s.doc));
}

void dump_section_11(void) {
	typedef struct PyGetSetDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs get", offsetof(platcheck_t, get));
	dump("fldsize get",   sizeof(s.get));
	dump("fldofs set", offsetof(platcheck_t, set));
	dump("fldsize set",   sizeof(s.set));
	dump("fldofs doc", offsetof(platcheck_t, doc));
	dump("fldsize doc",   sizeof(s.doc));
	dump("fldofs closure", offsetof(platcheck_t, closure));
	dump("fldsize closure",   sizeof(s.closure));
}

void dump_section_12(void) {
	typedef struct wrapperbase platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs offset", offsetof(platcheck_t, offset));
	dump("fldsize offset",   sizeof(s.offset));
	dump("fldofs function", offsetof(platcheck_t, function));
	dump("fldsize function",   sizeof(s.function));
	dump("fldofs wrapper", offsetof(platcheck_t, wrapper));
	dump("fldsize wrapper",   sizeof(s.wrapper));
	dump("fldofs doc", offsetof(platcheck_t, doc));
	dump("fldsize doc",   sizeof(s.doc));
	dump("fldofs flags", offsetof(platcheck_t, flags));
	dump("fldsize flags",   sizeof(s.flags));
	dump("fldofs name_strobj", offsetof(platcheck_t, name_strobj));
	dump("fldsize name_strobj",   sizeof(s.name_strobj));
}

void dump_section_13(void) {
	typedef PyDescrObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs d_type", offsetof(platcheck_t, d_type));
	dump("fldsize d_type",   sizeof(s.d_type));
	dump("fldofs d_name", offsetof(platcheck_t, d_name));
	dump("fldsize d_name",   sizeof(s.d_name));
}

void dump_section_14(void) {
	typedef PyMethodDescrObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs d_type", offsetof(platcheck_t, d_type));
	dump("fldsize d_type",   sizeof(s.d_type));
	dump("fldofs d_name", offsetof(platcheck_t, d_name));
	dump("fldsize d_name",   sizeof(s.d_name));
	dump("fldofs d_method", offsetof(platcheck_t, d_method));
	dump("fldsize d_method",   sizeof(s.d_method));
}

void dump_section_15(void) {
	typedef PyMemberDescrObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs d_type", offsetof(platcheck_t, d_type));
	dump("fldsize d_type",   sizeof(s.d_type));
	dump("fldofs d_name", offsetof(platcheck_t, d_name));
	dump("fldsize d_name",   sizeof(s.d_name));
	dump("fldofs d_member", offsetof(platcheck_t, d_member));
	dump("fldsize d_member",   sizeof(s.d_member));
}

void dump_section_16(void) {
	typedef PyGetSetDescrObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs d_type", offsetof(platcheck_t, d_type));
	dump("fldsize d_type",   sizeof(s.d_type));
	dump("fldofs d_name", offsetof(platcheck_t, d_name));
	dump("fldsize d_name",   sizeof(s.d_name));
	dump("fldofs d_getset", offsetof(platcheck_t, d_getset));
	dump("fldsize d_getset",   sizeof(s.d_getset));
}

void dump_section_17(void) {
	typedef PyWrapperDescrObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs d_type", offsetof(platcheck_t, d_type));
	dump("fldsize d_type",   sizeof(s.d_type));
	dump("fldofs d_name", offsetof(platcheck_t, d_name));
	dump("fldsize d_name",   sizeof(s.d_name));
	dump("fldofs d_base", offsetof(platcheck_t, d_base));
	dump("fldsize d_base",   sizeof(s.d_base));
	dump("fldofs d_wrapped", offsetof(platcheck_t, d_wrapped));
	dump("fldsize d_wrapped",   sizeof(s.d_wrapped));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	return 0;
}
