/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/


        #include <sys/types.h>
        #ifdef _MSC_VER
        #define _Bool char
        #ifdef _WIN64
        typedef long long ssize_t;
        typedef unsigned long long size_t;
        #else
        typedef int ssize_t;
        typedef unsigned int size_t;
        #endif
        #endif

            struct about_signed_char {
                char pad;
                signed char field;
            };
        

            struct about_signed_short {
                char pad;
                signed short field;
            };
        

            struct about_signed_int {
                char pad;
                signed int field;
            };
        

            struct about_signed_long {
                char pad;
                signed long field;
            };
        

            struct about_signed_long_long {
                char pad;
                signed long long field;
            };
        

            struct about_ssize_t {
                char pad;
                ssize_t field;
            };
        

            struct about_unsigned_char {
                char pad;
                unsigned char field;
            };
        

            struct about_unsigned_short {
                char pad;
                unsigned short field;
            };
        

            struct about_unsigned_int {
                char pad;
                unsigned int field;
            };
        

            struct about_unsigned_long {
                char pad;
                unsigned long field;
            };
        

            struct about_unsigned_long_long {
                char pad;
                unsigned long long field;
            };
        

            struct about_size_t {
                char pad;
                size_t field;
            };
        

            struct about_char_star {
                char pad;
                char * field;
            };
        

            struct about_float {
                char pad;
                float field;
            };
        

            struct about_double {
                char pad;
                double field;
            };
        

            struct about__Bool {
                char pad;
                _Bool field;
            };
        

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef struct about__Bool platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_1(void) {
	typedef struct about_char_star platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_2(void) {
	typedef struct about_double platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_3(void) {
	typedef struct about_float platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_4(void) {
	typedef struct about_signed_char platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_5(void) {
	typedef struct about_signed_int platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_6(void) {
	typedef struct about_signed_long platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_7(void) {
	typedef struct about_signed_long_long platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_8(void) {
	typedef struct about_signed_short platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_9(void) {
	typedef struct about_size_t platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_10(void) {
	typedef struct about_ssize_t platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_11(void) {
	typedef struct about_unsigned_char platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_12(void) {
	typedef struct about_unsigned_int platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_13(void) {
	typedef struct about_unsigned_long platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_14(void) {
	typedef struct about_unsigned_long_long platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

void dump_section_15(void) {
	typedef struct about_unsigned_short platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs field", offsetof(platcheck_t, field));
	dump("fldsize field",   sizeof(s.field));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	return 0;
}
