/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <stdarg.h>
#include <stdio.h>
#include <stddef.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_object.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_descrobject.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_memoryobject.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_unicodeobject.h>
#include </builddir/build/BUILD/pypy-7.3.16-build/pypy2.7-v7.3.16-src/pypy/module/cpyext/parse/cpyext_datetime.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef PyDateTime_CAPI platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs DateType", offsetof(platcheck_t, DateType));
	dump("fldsize DateType",   sizeof(s.DateType));
	dump("fldofs DateTimeType", offsetof(platcheck_t, DateTimeType));
	dump("fldsize DateTimeType",   sizeof(s.DateTimeType));
	dump("fldofs TimeType", offsetof(platcheck_t, TimeType));
	dump("fldsize TimeType",   sizeof(s.TimeType));
	dump("fldofs DeltaType", offsetof(platcheck_t, DeltaType));
	dump("fldsize DeltaType",   sizeof(s.DeltaType));
	dump("fldofs TZInfoType", offsetof(platcheck_t, TZInfoType));
	dump("fldsize TZInfoType",   sizeof(s.TZInfoType));
	dump("fldofs Date_FromDate", offsetof(platcheck_t, Date_FromDate));
	dump("fldsize Date_FromDate",   sizeof(s.Date_FromDate));
	dump("fldofs DateTime_FromDateAndTime", offsetof(platcheck_t, DateTime_FromDateAndTime));
	dump("fldsize DateTime_FromDateAndTime",   sizeof(s.DateTime_FromDateAndTime));
	dump("fldofs Time_FromTime", offsetof(platcheck_t, Time_FromTime));
	dump("fldsize Time_FromTime",   sizeof(s.Time_FromTime));
	dump("fldofs Delta_FromDelta", offsetof(platcheck_t, Delta_FromDelta));
	dump("fldsize Delta_FromDelta",   sizeof(s.Delta_FromDelta));
	dump("fldofs DateTime_FromTimestamp", offsetof(platcheck_t, DateTime_FromTimestamp));
	dump("fldsize DateTime_FromTimestamp",   sizeof(s.DateTime_FromTimestamp));
	dump("fldofs Date_FromTimestamp", offsetof(platcheck_t, Date_FromTimestamp));
	dump("fldsize Date_FromTimestamp",   sizeof(s.Date_FromTimestamp));
}

void dump_section_1(void) {
	typedef PyDateTime_Delta platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs days", offsetof(platcheck_t, days));
	dump("fldsize days",   sizeof(s.days));
	dump("fldofs seconds", offsetof(platcheck_t, seconds));
	dump("fldsize seconds",   sizeof(s.seconds));
	dump("fldofs microseconds", offsetof(platcheck_t, microseconds));
	dump("fldsize microseconds",   sizeof(s.microseconds));
}

void dump_section_2(void) {
	typedef PyDateTime_Time platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs hastzinfo", offsetof(platcheck_t, hastzinfo));
	dump("fldsize hastzinfo",   sizeof(s.hastzinfo));
	s.hastzinfo = 0; s.hastzinfo = ~s.hastzinfo;
	dump("fldunsigned hastzinfo", s.hastzinfo > 0);
	dump("fldofs tzinfo", offsetof(platcheck_t, tzinfo));
	dump("fldsize tzinfo",   sizeof(s.tzinfo));
}

void dump_section_3(void) {
	typedef PyDateTime_DateTime platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs hastzinfo", offsetof(platcheck_t, hastzinfo));
	dump("fldsize hastzinfo",   sizeof(s.hastzinfo));
	s.hastzinfo = 0; s.hastzinfo = ~s.hastzinfo;
	dump("fldunsigned hastzinfo", s.hastzinfo > 0);
	dump("fldofs tzinfo", offsetof(platcheck_t, tzinfo));
	dump("fldsize tzinfo",   sizeof(s.tzinfo));
}

void dump_section_4(void) {
	typedef PyDateTime_Date platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
}

void dump_section_5(void) {
	typedef PyDateTime_TZInfo platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	return 0;
}
