/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <Python.h>
#include <stdarg.h>
#include <structmember.h>
#include <marshal.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef PyBufferObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs b_base", offsetof(platcheck_t, b_base));
	dump("fldsize b_base",   sizeof(s.b_base));
	dump("fldofs b_ptr", offsetof(platcheck_t, b_ptr));
	dump("fldsize b_ptr",   sizeof(s.b_ptr));
	dump("fldofs b_size", offsetof(platcheck_t, b_size));
	dump("fldsize b_size",   sizeof(s.b_size));
	s.b_size = 0; s.b_size = ~s.b_size;
	dump("fldunsigned b_size", s.b_size > 0);
	dump("fldofs b_offset", offsetof(platcheck_t, b_offset));
	dump("fldsize b_offset",   sizeof(s.b_offset));
	s.b_offset = 0; s.b_offset = ~s.b_offset;
	dump("fldunsigned b_offset", s.b_offset > 0);
	dump("fldofs b_readonly", offsetof(platcheck_t, b_readonly));
	dump("fldsize b_readonly",   sizeof(s.b_readonly));
	s.b_readonly = 0; s.b_readonly = ~s.b_readonly;
	dump("fldunsigned b_readonly", s.b_readonly > 0);
	dump("fldofs b_hash", offsetof(platcheck_t, b_hash));
	dump("fldsize b_hash",   sizeof(s.b_hash));
	s.b_hash = 0; s.b_hash = ~s.b_hash;
	dump("fldunsigned b_hash", s.b_hash > 0);
}

void dump_section_1(void) {
	typedef PyByteArrayObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
}

void dump_section_2(void) {
	typedef PyCodeObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs co_name", offsetof(platcheck_t, co_name));
	dump("fldsize co_name",   sizeof(s.co_name));
	dump("fldofs co_filename", offsetof(platcheck_t, co_filename));
	dump("fldsize co_filename",   sizeof(s.co_filename));
	dump("fldofs co_flags", offsetof(platcheck_t, co_flags));
	dump("fldsize co_flags",   sizeof(s.co_flags));
	s.co_flags = 0; s.co_flags = ~s.co_flags;
	dump("fldunsigned co_flags", s.co_flags > 0);
	dump("fldofs co_argcount", offsetof(platcheck_t, co_argcount));
	dump("fldsize co_argcount",   sizeof(s.co_argcount));
	s.co_argcount = 0; s.co_argcount = ~s.co_argcount;
	dump("fldunsigned co_argcount", s.co_argcount > 0);
}

void dump_section_3(void) {
	typedef PyCompilerFlags platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs cf_flags", offsetof(platcheck_t, cf_flags));
	dump("fldsize cf_flags",   sizeof(s.cf_flags));
	s.cf_flags = 0; s.cf_flags = ~s.cf_flags;
	dump("fldunsigned cf_flags", s.cf_flags > 0);
}

void dump_section_4(void) {
	typedef PyComplexObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs cval", offsetof(platcheck_t, cval));
	dump("fldsize cval",   sizeof(s.cval));
}

void dump_section_5(void) {
	typedef PyDictObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs _tmpkeys", offsetof(platcheck_t, _tmpkeys));
	dump("fldsize _tmpkeys",   sizeof(s._tmpkeys));
}

void dump_section_6(void) {
	typedef PyFloatObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_fval", offsetof(platcheck_t, ob_fval));
	dump("fldsize ob_fval",   sizeof(s.ob_fval));
}

void dump_section_7(void) {
	typedef PyFrameObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs f_code", offsetof(platcheck_t, f_code));
	dump("fldsize f_code",   sizeof(s.f_code));
	dump("fldofs f_globals", offsetof(platcheck_t, f_globals));
	dump("fldsize f_globals",   sizeof(s.f_globals));
	dump("fldofs f_locals", offsetof(platcheck_t, f_locals));
	dump("fldsize f_locals",   sizeof(s.f_locals));
	dump("fldofs f_lineno", offsetof(platcheck_t, f_lineno));
	dump("fldsize f_lineno",   sizeof(s.f_lineno));
	s.f_lineno = 0; s.f_lineno = ~s.f_lineno;
	dump("fldunsigned f_lineno", s.f_lineno > 0);
}

void dump_section_8(void) {
	typedef PyFunctionObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs func_name", offsetof(platcheck_t, func_name));
	dump("fldsize func_name",   sizeof(s.func_name));
}

void dump_section_9(void) {
	typedef PyIntObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_ival", offsetof(platcheck_t, ob_ival));
	dump("fldsize ob_ival",   sizeof(s.ob_ival));
	s.ob_ival = 0; s.ob_ival = ~s.ob_ival;
	dump("fldunsigned ob_ival", s.ob_ival > 0);
}

void dump_section_10(void) {
	typedef PyInterpreterState platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs next", offsetof(platcheck_t, next));
	dump("fldsize next",   sizeof(s.next));
}

void dump_section_11(void) {
	typedef PySetObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs _tmplist", offsetof(platcheck_t, _tmplist));
	dump("fldsize _tmplist",   sizeof(s._tmplist));
}

void dump_section_12(void) {
	typedef PySliceObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs start", offsetof(platcheck_t, start));
	dump("fldsize start",   sizeof(s.start));
	dump("fldofs step", offsetof(platcheck_t, step));
	dump("fldsize step",   sizeof(s.step));
	dump("fldofs stop", offsetof(platcheck_t, stop));
	dump("fldsize stop",   sizeof(s.stop));
}

void dump_section_13(void) {
	typedef PyStringObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
	dump("fldofs ob_shash", offsetof(platcheck_t, ob_shash));
	dump("fldsize ob_shash",   sizeof(s.ob_shash));
	s.ob_shash = 0; s.ob_shash = ~s.ob_shash;
	dump("fldunsigned ob_shash", s.ob_shash > 0);
	dump("fldofs ob_sstate", offsetof(platcheck_t, ob_sstate));
	dump("fldsize ob_sstate",   sizeof(s.ob_sstate));
	s.ob_sstate = 0; s.ob_sstate = ~s.ob_sstate;
	dump("fldunsigned ob_sstate", s.ob_sstate > 0);
	dump("fldofs ob_sval", offsetof(platcheck_t, ob_sval));
	dump("fldsize ob_sval",   sizeof(s.ob_sval));
}

void dump_section_14(void) {
	typedef PyThreadState platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs interp", offsetof(platcheck_t, interp));
	dump("fldsize interp",   sizeof(s.interp));
	dump("fldofs dict", offsetof(platcheck_t, dict));
	dump("fldsize dict",   sizeof(s.dict));
}

void dump_section_15(void) {
	typedef PyTracebackObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs tb_next", offsetof(platcheck_t, tb_next));
	dump("fldsize tb_next",   sizeof(s.tb_next));
	dump("fldofs tb_frame", offsetof(platcheck_t, tb_frame));
	dump("fldsize tb_frame",   sizeof(s.tb_frame));
	dump("fldofs tb_lasti", offsetof(platcheck_t, tb_lasti));
	dump("fldsize tb_lasti",   sizeof(s.tb_lasti));
	s.tb_lasti = 0; s.tb_lasti = ~s.tb_lasti;
	dump("fldunsigned tb_lasti", s.tb_lasti > 0);
	dump("fldofs tb_lineno", offsetof(platcheck_t, tb_lineno));
	dump("fldsize tb_lineno",   sizeof(s.tb_lineno));
	s.tb_lineno = 0; s.tb_lineno = ~s.tb_lineno;
	dump("fldunsigned tb_lineno", s.tb_lineno > 0);
}

void dump_section_16(void) {
	typedef PyTupleObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
	dump("fldofs ob_item", offsetof(platcheck_t, ob_item));
	dump("fldsize ob_item",   sizeof(s.ob_item));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	return 0;
}
