/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008, except on
   macOS where it hides a lot symbols */
#ifndef __APPLE__
#  ifndef _POSIX_C_SOURCE
#    define _POSIX_C_SOURCE 200809L
#  endif
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#if defined(_MSC_VER)
  #define INLINE __inline
#elif defined(__GNUC__)
  #define INLINE __inline__
#else
  #error define inline for this compiler
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <zlib.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef Bytef platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_1(void) {
	if ((MAX_MEM_LEVEL) <= 0) {
	    long long x = (long long)(MAX_MEM_LEVEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAX_MEM_LEVEL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_2(void) {
	if ((MAX_WBITS) <= 0) {
	    long long x = (long long)(MAX_WBITS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAX_WBITS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_3(void) {
#ifdef ZLIB_VERNUM
	dump("defined", 1);
	if ((ZLIB_VERNUM) <= 0) {
	    long long x = (long long)(ZLIB_VERNUM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ZLIB_VERNUM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef ZLIB_VERSION
	int i;
	const char *p = ZLIB_VERSION;
	dump("defined", 1);
	for (i = 0; p[i] != 0; i++ ) {
	  printf("value_%d: %d\n", i, (int)(unsigned char)p[i]);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
	if ((Z_BEST_COMPRESSION) <= 0) {
	    long long x = (long long)(Z_BEST_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_BEST_COMPRESSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_6(void) {
	if ((Z_BEST_SPEED) <= 0) {
	    long long x = (long long)(Z_BEST_SPEED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_BEST_SPEED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_7(void) {
	if ((Z_BUF_ERROR) <= 0) {
	    long long x = (long long)(Z_BUF_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_BUF_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_8(void) {
	if ((Z_DATA_ERROR) <= 0) {
	    long long x = (long long)(Z_DATA_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DATA_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_9(void) {
	if ((Z_DEFAULT_COMPRESSION) <= 0) {
	    long long x = (long long)(Z_DEFAULT_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DEFAULT_COMPRESSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_10(void) {
	if ((Z_DEFAULT_STRATEGY) <= 0) {
	    long long x = (long long)(Z_DEFAULT_STRATEGY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DEFAULT_STRATEGY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_11(void) {
	if ((Z_DEFLATED) <= 0) {
	    long long x = (long long)(Z_DEFLATED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DEFLATED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_12(void) {
	if ((Z_FILTERED) <= 0) {
	    long long x = (long long)(Z_FILTERED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_FILTERED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_13(void) {
	if ((Z_FINISH) <= 0) {
	    long long x = (long long)(Z_FINISH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_FINISH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_14(void) {
	if ((Z_FULL_FLUSH) <= 0) {
	    long long x = (long long)(Z_FULL_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_FULL_FLUSH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_15(void) {
	if ((Z_HUFFMAN_ONLY) <= 0) {
	    long long x = (long long)(Z_HUFFMAN_ONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_HUFFMAN_ONLY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_16(void) {
	if ((Z_MEM_ERROR) <= 0) {
	    long long x = (long long)(Z_MEM_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_MEM_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_17(void) {
	if ((Z_NEED_DICT) <= 0) {
	    long long x = (long long)(Z_NEED_DICT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_NEED_DICT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_18(void) {
	if ((Z_NO_FLUSH) <= 0) {
	    long long x = (long long)(Z_NO_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_NO_FLUSH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_19(void) {
	if ((Z_NULL) <= 0) {
	    long long x = (long long)(Z_NULL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_NULL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_20(void) {
	if ((Z_OK) <= 0) {
	    long long x = (long long)(Z_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_OK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_21(void) {
	if ((Z_STREAM_END) <= 0) {
	    long long x = (long long)(Z_STREAM_END);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_STREAM_END);
	    printf("value: %llu\n", x);
	}
}

void dump_section_22(void) {
	if ((Z_STREAM_ERROR) <= 0) {
	    long long x = (long long)(Z_STREAM_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_STREAM_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_23(void) {
	if ((Z_SYNC_FLUSH) <= 0) {
	    long long x = (long long)(Z_SYNC_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_SYNC_FLUSH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_24(void) {
	typedef uInt platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_25(void) {
	typedef uLong platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_26(void) {
	typedef voidpf platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	return 0;
}
